library ieee;
use ieee.std_logic_1164.all;
use IEEE.std_logic_arith.all;
use ieee.std_logic_unsigned.all;
use ieee.numeric_std.all;

entity de2_vga_raster is
  port (
    avs_s1_clk        : in  std_logic;
    avs_s1_reset_n    : in  std_logic;
    avs_s1_read       : in  std_logic;
    avs_s1_write      : in  std_logic;
    avs_s1_chipselect : in  std_logic;
    avs_s1_address    : in  std_logic_vector(6 downto 0);
    avs_s1_readdata   : out std_logic_vector(31 downto 0);
    avs_s1_writedata  : in  std_logic_vector(31 downto 0);
	
	reset_n	  : in std_logic;					  -- More reset!
	CLK_25	  : in std_logic;
    VGA_CLK   : out std_logic;                    -- Clock
    VGA_HS    : out std_logic;                    -- H_SYNC
    VGA_VS    : out std_logic;                    -- V_SYNC
    VGA_BLANK : out std_logic;                    -- BLANK
    VGA_SYNC  : out std_logic;                    -- SYNC
    VGA_R     : out std_logic_vector(9 downto 0); -- Red[9:0]
    VGA_G     : out std_logic_vector(9 downto 0); -- Green[9:0]
    VGA_B     : out std_logic_vector(9 downto 0)  -- Blue[9:0]
  );
end de2_vga_raster;

architecture rtl of  de2_vga_raster is

signal clk : std_logic:='0';

--Declare our various RAMs and ROMs
-----------------------------------------------------------------------
-----------------------------------------------------------------------
--type wall_ram_line_type is array(40 downto -1) of std_logic;
--type wall_ram_line_type is foo;
--type wall_ram_type is array(-1 to 30) of wall_ram_line_type;
--type wall_ram_line_type is std_logic_vector(40 downto -1);
type wall_ram_type is array(0 to 31) of std_logic_vector(41 downto 0);
-----------------------------------------------------------------------
-----------------------------------------------------------------------

--type maze_sprite_ram_type is array(0 to 7) of std_logic_vector(255 downto 0);
--type show_square_ram_type is array(31 downto 0) of std_logic_vector(21 downto 0);
type color_ram_type is array (6 downto 0) of std_logic_vector(29 downto 0);
type sprite_ram_line_type is array(0 to 15) of std_logic_vector(0 to 15);
--type sprite_ram_type is array(0 to 15) of sprite_ram_line_type;

type pacman_sprite_ram_line_type is array(0 to 15) of std_logic_vector(0 to 2);
type pacman_sprite_ram_type is array(0 to 15) of pacman_sprite_ram_line_type;
--type ghost_sprite_ram_type is array(0 to 15) of player_sprite_ram_line_type;

--type score_ram_line_type is array(2 downto 0) of std_logic_vector(3 downto 0);
--type score_ram_type is array(1 downto 0) of score_ram_line_type;
--type score_ram_type is array(2 downto 0) of std_logic_vector(3 downto 0);
--type score_ram_type is std_logic_vector(3 downto 0);


--type square_sprite_ram_type is array(0 to 1) of sprite_ram_line_type;
type num_sprite_ram_type is array(0 to 11) of sprite_ram_line_type;

--signal wall_sprite_ram: wall_sprite_ram_type;
signal num_sprite_ram: num_sprite_ram_type := (("0000000000000000","0000011111100000","0000011111100000","0001100001111000","0001100001111000","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0001111000011000","0001111000011000","0000011111100000","0000011111100000","0000000000000000"),
                                               ("0000000000000000","0000001111000000","0000001111000000","0000111111000000","0000111111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0011111111111100","0011111111111100","0000000000000000"),
                                               ("0000000000000000","0001111111111000","0001111111111000","0111100000011110","0111100000011110","0000000001111110","0000000001111110","0000011111111000","0000011111111000","0001111111100000","0001111111100000","0111111000000000","0111111000000000","0111111111111110","0111111111111110","0000000000000000"),
                                               ("0000000000000000","0000011111111000","0000011111111000","0001100001111000","0001100001111000","0000000001111000","0000000001111000","0000000111100000","0000000111100000","0000000001111110","0000000001111110","0110000000011110","0110000000011110","0001111111111000","0001111111111000","0000000000000000"),
                                               ("0000000000000000","0000000111111000","0000000111111000","0000011111111000","0000011111111000","0001111001111000","0001111001111000","0111100001111000","0111100001111000","0111111111111110","0000000001111000","0000000001111000","0000000001111000","0000000001111000","0000000001111000","0000000000000000"),
                                               ("0000000000000000","0111111111111000","0111111111111000","0111100000000000","0111100000000000","0111111111111000","0111111111111000","0000000000011110","0000000000011110","0000000000011110","0000000000011110","0111100000011110","0111100000011110","0001111111111000","0001111111111000","0000000000000000"),
                                               ("0000000000000000","0001111111111000","0001111111111000","0111100000000000","0111100000000000","0111111111111000","0111111111111000","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0001111111111000","0001111111111000","0000000000000000"),
                                               ("0000000000000000","0111111111111110","0111111111111110","0111100000011110","0111100000011110","0000000001111000","0000000001111000","0000000111100000","0000000111100000","0000011110000000","0000011110000000","0000011110000000","0000011110000000","0000011110000000","0000011110000000","0000000000000000"),
                                               ("0000000000000000","0001111111100000","0001111111100000","0111100000011000","0111100000011000","0111111000011000","0111111000011000","0001111111100000","0001111111100000","0110000111111110","0110000111111110","0110000000011110","0110000000011110","0001111111111000","0001111111111000","0000000000000000"),
                                               ("0000000000000000","0001111111111000","0001111111111000","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0001111111111110","0001111111111110","0000000000011110","0000000000011110","0000000001111000","0000000001111000","0001111111100000","0001111111100000","0000000000000000"),
                                               ("0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000"),
                                               ("0000000000000000","0011000000000010","0100100000000100","0100100000001000","0011000000010000","0000000000100000","0000000001000000","0000000010000000","0000000100000000","0000001000000000","0000010000000000","0000100000001100","0001000000010010","0010000000010010","0100000000001100","0000000000000000"));


signal char_sprite_ram: num_sprite_ram_type := (("0000000000000000","0000011111100000","0000011111100000","0001100001111000","0001100001111000","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0001111000011000","0001111000011000","0000011111100000","0000011111100000","0000000000000000"),
                                               ("0000000000000000","0000001111000000","0000001111000000","0000111111000000","0000111111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0011111111111100","0011111111111100","0000000000000000"),
                                               ("0000000000000000","0001111111111000","0001111111111000","0111100000011110","0111100000011110","0000000001111110","0000000001111110","0000011111111000","0000011111111000","0001111111100000","0001111111100000","0111111000000000","0111111000000000","0111111111111110","0111111111111110","0000000000000000"),
                                               ("0000000000000000","0000011111111000","0000011111111000","0001100001111000","0001100001111000","0000000001111000","0000000001111000","0000000111100000","0000000111100000","0000000001111110","0000000001111110","0110000000011110","0110000000011110","0001111111111000","0001111111111000","0000000000000000"),
                                               ("0000000000000000","0000000111111000","0000000111111000","0000011111111000","0000011111111000","0001111001111000","0001111001111000","0111100001111000","0111100001111000","0111111111111110","0000000001111000","0000000001111000","0000000001111000","0000000001111000","0000000001111000","0000000000000000"),
                                               ("0000000000000000","0111111111111000","0111111111111000","0111100000000000","0111100000000000","0111111111111000","0111111111111000","0000000000011110","0000000000011110","0000000000011110","0000000000011110","0111100000011110","0111100000011110","0001111111111000","0001111111111000","0000000000000000"),
                                               ("0000000000000000","0001111111111000","0001111111111000","0111100000000000","0111100000000000","0111111111111000","0111111111111000","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0001111111111000","0001111111111000","0000000000000000"),
                                               ("0000000000000000","0111111111111110","0111111111111110","0111100000011110","0111100000011110","0000000001111000","0000000001111000","0000000111100000","0000000111100000","0000011110000000","0000011110000000","0000011110000000","0000011110000000","0000011110000000","0000011110000000","0000000000000000"),
                                               ("0000000000000000","0001111111100000","0001111111100000","0111100000011000","0111100000011000","0111111000011000","0111111000011000","0001111111100000","0001111111100000","0110000111111110","0110000111111110","0110000000011110","0110000000011110","0001111111111000","0001111111111000","0000000000000000"),
                                               ("0000000000000000","0001111111111000","0001111111111000","0111100000011110","0111100000011110","0111100000011110","0111100000011110","0001111111111110","0001111111111110","0000000000011110","0000000000011110","0000000001111000","0000000001111000","0001111111100000","0001111111100000","0000000000000000"),
                                               ("0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000","0000000000000000"),
                                               ("0000000000000000","0011000000000010","0100100000000100","0100100000001000","0011000000010000","0000000000100000","0000000001000000","0000000010000000","0000000100000000","0000001000000000","0000010000000000","0000100000001100","0001000000010010","0010000000010010","0100000000001100","0000000000000000"));





      
--signal score_ram: score_ram_type := ("0011","0111","1011");
--signal score_ram_temp: score_ram_type:= ("0000","0000","1011");
signal score_ram_1, score_ram_2, score_ram_temp_1, score_ram_temp_2, record_ram_1, record_ram_2, record_ram_temp_1, record_ram_temp_2: std_logic_vector(3 downto 0) := "0000";
--signal show_wall_ram: show_dot_ram_type;
signal RAM : wall_ram_type := ("000000000000000000000000000000000000000000",
							   "000000000000000000000000000000000000000000",
							   "000000000000000000000000000000000000000000",
							   "000000000000000000000000000000000000000000",
							   "000000000000000000000000000000000000000000",
							   "000001111111111111111111111111111111111000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001000000000000000000000000000000001000",
							   "000001111111111111111111111111111111111000",
							   "000000000000000000000000000000000000000000",
							   "000000000000000000000000000000000000000000",
							   "000000000000000000000000000000000000000000");
-----------------------------------------------------------
-----------------------------------------------------------
signal RAM_temp : wall_ram_type := ("000000000000000000000000000000000000000000",
									"000000000000000000000000000000000000000000",
									"000000000000000000000000000000000000000000",
									"000000000000000000000000000000000000000000",
									"000000000000000000000000000000000000000000",
									"000001111111111111111111111111111111111000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001000000000000000000000000000000001000",
									"000001111111111111111111111111111111111000",
									"000000000000000000000000000000000000000000",
									"000000000000000000000000000000000000000000",
									"000000000000000000000000000000000000000000");
-----------------------------------------------------------
-----------------------------------------------------------
--signal color_ram_1, color_ram_2, color_ram_dot: color_ram_type;
--signal color_ram_1, color_ram_2: color_ram_type;
signal color_ram: color_ram_type;

signal square_sprite_ram: pacman_sprite_ram_type;
signal black_sprite_ram: pacman_sprite_ram_type;
signal pacman_sprite_0_ram: pacman_sprite_ram_type;
signal pacman_sprite_up_ram: pacman_sprite_ram_type;
signal pacman_sprite_down_ram: pacman_sprite_ram_type;
signal pacman_sprite_left_ram: pacman_sprite_ram_type;
signal pacman_sprite_right_ram: pacman_sprite_ram_type;
signal ghost_sprite_1_ram: pacman_sprite_ram_type;
signal ghost_sprite_2_ram: pacman_sprite_ram_type;
--signal bigdot_sprite_ram: player_sprite_ram_type;

signal ram_address, display_address : std_logic_vector(6 downto 0):="0000000";
signal show_square: std_logic:='0';


constant HTOTAL       : integer := 800;
constant HSYNC        : integer := 96;
constant HBACK_PORCH  : integer := 48;
constant HACTIVE      : integer := 640;
constant HFRONT_PORCH : integer := 16;
  
constant VTOTAL       : integer := 525;
constant VSYNC        : integer := 2;
constant VBACK_PORCH  : integer := 33;
constant VACTIVE      : integer := 480;
constant VFRONT_PORCH : integer := 10;

-- Signals for the video controller
signal Hcount : std_logic_vector(9 downto 0);  -- Horizontal position (0-800)
signal Vcount : std_logic_vector(9 downto 0);  -- Vertical position (0-524)
signal EndOfLine, EndOfField : std_logic;

signal vga_hblank, vga_hsync,
 vga_vblank, vga_vsync : std_logic;  -- Sync. signals

signal visible_xpos: std_logic_vector(9 downto 0):="0000000000";
signal visible_ypos: std_logic_vector(9 downto 0):="0000000000";

signal square_sprite_x: std_logic_vector(3 downto 0):="0000";
signal square_sprite_y: std_logic_vector(3 downto 0):="0000";

signal pacman_x: std_logic_vector(9 downto 0):="0000011001";
signal pacman_y: std_logic_vector(9 downto 0):="0000100101";
signal ghost_1_x: std_logic_vector(9 downto 0):="0000110010";
signal ghost_1_y: std_logic_vector(9 downto 0):="0000111001";
signal ghost_2_x: std_logic_vector(9 downto 0):="0000111001";
signal ghost_2_y: std_logic_vector(9 downto 0):="0000111101";
signal pacman_direction : std_logic_vector(2 downto 0):="000";

signal square_x: std_logic_vector(5 downto 0):="000000";
signal square_y: std_logic_vector(5 downto 0):="000000";
--signal maze : std_logic;
signal show_wall_square : std_logic:='0';
signal print_char : std_logic:='0';
signal draw_pacman_0, draw_ghost_1, draw_ghost_2 : std_logic:='0';
--signal wall_line_from_RAM : wall_ram_line_type;
--signal left_square, right_square, up_square, down_square, downleft_maze, upleft_maze, upright_maze, downright_maze: std_logic;
--signal left_square, right_square, up_square, down_square : std_logic;
--signal current_sqrite_state: unsigned(2 downto 0);
signal wall_square_sprite_from_RAM : pacman_sprite_ram_type;
signal wall_square_state_from_RAM : std_logic:='0';
--signal current_char_sprite_from_RAM : sprite_ram_line_type;




--------------------------SCORE CHAR INITIALIZATION : 0----------------------
-----------------------------------------------------------------------------
signal current_char_sprite_from_RAM : sprite_ram_line_type := ("0000000000000000","0000001111000000","0000001111000000","0000111111000000","0000111111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0000001111000000","0011111111111100","0011111111111100","0000000000000000");
                                                                                     
-----------------------------------------------------------------------------
-----------------------------------------------------------------------------



-----------------------------------------------------------------------------------
-----------------------------------------------------------------------------------
  signal rhs : std_logic_vector(9 downto 0):="0000000000";
  signal rvs : std_logic_vector(9 downto 0):="0000000000";
  signal ghost1_rhs : std_logic_vector(9 downto 0):="0000000000";
  signal ghost1_rvs : std_logic_vector(9 downto 0):="0000000000";
  signal ghost2_rhs : std_logic_vector(9 downto 0):="0000000000";
  signal ghost2_rvs : std_logic_vector(9 downto 0):="0000000000";
  signal pacman_direction_temp : std_logic_vector(2 downto 0):="000";
-----------------------------------------------------------------------------------
-----------------------------------------------------------------------------------

begin

  clk <= avs_s1_clk;
  ram_address <= avs_s1_address;
  visible_xpos <= Hcount - HSYNC - HBACK_PORCH;
  square_x <= visible_xpos(9 downto 4);
  square_sprite_x <= visible_xpos(3 downto 0);
--  wall_square_state_from_RAM <= RAM(conv_integer(square_y))(conv_integer(square_x));

--  DrawWall_and_score: process(clk)
--  begin
--     --if visible_xpos < (square_x<<4)+16 and visible_xpos >= (square_x<<4) and visible_ypos <(square_y<<4)+16 and visible_ypos >= (square_y<<4) then
--      --wall_square_state_from_RAM <= RAM(conv_integer(square_y))(conv_integer(square_x));
--    if wall_square_state_from_RAM = '1' then
--       show_wall_square <= '1';
----       wall_square_sprite_from_RAM <= square_sprite_ram;
----    else wall_square_sprite_from_RAM <= black_sprite_ram;
--    end if;
--
--
--    if square_x = "000011" and square_y = "100001" then
--       print_char <= '1';
--       --current_char_sprite_from_RAM <= num_sprite_ram(conv_integer(score_ram(2)));
--    elsif square_x = "000011" and square_y = "100010" then
--       print_char <= '1';
--       --current_char_sprite_from_RAM <= num_sprite_ram(conv_integer(score_ram(1)));
--    elsif square_x = "000011" and square_y = "100011" then
--       print_char <= '1';
--       --current_char_sprite_from_RAM <= num_sprite_ram(11);
--    else
--		print_char <= '0';
--	end if; 
--end process;	

  DrawWall: process(clk)
  begin
     --if visible_xpos < (square_x<<4)+16 and visible_xpos >= (square_x<<4) and visible_ypos <(square_y<<4)+16 and visible_ypos >= (square_y<<4) then
      --wall_square_state_from_RAM <= RAM(conv_integer(square_y))(conv_integer(square_x));
    if wall_square_state_from_RAM = '1' then
       show_wall_square <= '1';
	   --print_char <= '0';
--       wall_square_sprite_from_RAM <= square_sprite_ram;
--    else wall_square_sprite_from_RAM <= black_sprite_ram;
	else 
		show_wall_square <= '0';
		--print_char <= '1';
    end if;
end process;

--  Drawscore: process(clk)
--  begin
--    if wall_square_state_from_RAM = '0' then
--    if square_x = "000011" and square_y = "100001" then
--       print_char <= '1';
--       --current_char_sprite_from_RAM <= num_sprite_ram(conv_integer(score_ram(2)));
--    elsif square_x = "000011" and square_y = "100010" then
--       print_char <= '1';
--       --current_char_sprite_from_RAM <= num_sprite_ram(conv_integer(score_ram(1)));
--    elsif square_x = "000011" and square_y = "100011" then
--       print_char <= '1';
--       --current_char_sprite_from_RAM <= num_sprite_ram(11);
--    else
--		print_char <= '0';
--	end if; 
--	end if;
--end process;

  Drawscore: process(clk)
  begin
    if square_x = "100001" and square_y = "000011" then
       print_char <= '1';
       current_char_sprite_from_RAM <= num_sprite_ram(conv_integer(score_ram_2));
	   --current_char_sprite_from_RAM <= num_sprite_ram(8);
    elsif square_x = "100010" and square_y = "000011" then
       print_char <= '1';
       current_char_sprite_from_RAM <= num_sprite_ram(conv_integer(score_ram_1));
	   --current_char_sprite_from_RAM <= num_sprite_ram(0);
    elsif square_x = "100011" and square_y = "000011" then
       print_char <= '1';
       current_char_sprite_from_RAM <= num_sprite_ram(11);
	elsif square_x = "000011" and square_y = "000011" then
       print_char <= '1';
       current_char_sprite_from_RAM <= char_sprite_ram(0);
	elsif square_x = "000100" and square_y = "000011" then
       print_char <= '1';
       current_char_sprite_from_RAM <= char_sprite_ram(1);
	elsif square_x = "000101" and square_y = "000011" then
       print_char <= '1';
       current_char_sprite_from_RAM <= char_sprite_ram(2);
	elsif square_x = "000110" and square_y = "000011" then
       print_char <= '1';
       current_char_sprite_from_RAM <= char_sprite_ram(3);
	elsif square_x = "000111" and square_y = "000011" then
       print_char <= '1';
       current_char_sprite_from_RAM <= char_sprite_ram(0);
	elsif square_x = "001000" and square_y = "000011" then
       print_char <= '1';
       current_char_sprite_from_RAM <= char_sprite_ram(4);
	elsif square_x = "001100" and square_y = "000011" then
       print_char <= '1';
       current_char_sprite_from_RAM <= num_sprite_ram(conv_integer(record_ram_2));
	elsif square_x = "001101" and square_y = "000011" then
       print_char <= '1';
       current_char_sprite_from_RAM <= num_sprite_ram(conv_integer(record_ram_1));
    else
	   print_char <= '0';
	end if; 
end process;


----------------------------------------------------------------------------
----------------------------------------------------------------------------
--    if square_x = "000011" and square_y = "100001" then
--       print_char <= '1';
--       current_char_sprite_from_RAM <= num_sprite_ram(conv_integer(score_ram(2)));
--    elsif square_x = "000011" and square_y = "100010" then
--       print_char <= '1';
--       current_char_sprite_from_RAM <= num_sprite_ram(conv_integer(score_ram(1)));
--    elsif square_x = "000011" and square_y = "100011" then
--       print_char <= '1';
--       current_char_sprite_from_RAM <= num_sprite_ram(11);
--    else
--		print_char <= '0';
--	end if; 
--end process;	    
----------------------------------------------------------------------------
----------------------------------------------------------------------------
 CheckDrawPacman: process (clk)
  begin
	if visible_xpos < pacman_x+16 and visible_xpos >= pacman_x and visible_ypos < pacman_y+16 and visible_ypos >= pacman_y then
		draw_pacman_0 <= '1';
		--draw_player_2 <= '0';
	--elsif visible_xpos < player_2_xpos+16 and visible_xpos >= player_2_xpos and visible_ypos < player_2_ypos+16 and visible_ypos >= player_2_ypos then
		--draw_player_1 <= '0';
		--draw_player_2 <= '1';
	else
		draw_pacman_0 <= '0';
		--draw_player_2 <= '0';
	end if;
  end process;

CheckDrawGhost_1: process (clk)
 begin
 if visible_xpos < ghost_1_x+16 and visible_xpos >= ghost_1_x and visible_ypos < ghost_1_y+16 and visible_ypos >= ghost_1_y then
		draw_ghost_1 <= '1';
		--draw_player_2 <= '0';
	--elsif visible_xpos < player_2_xpos+16 and visible_xpos >= player_2_xpos and visible_ypos < player_2_ypos+16 and visible_ypos >= player_2_ypos then
		--draw_player_1 <= '0';
		--draw_player_2 <= '1';
	else
		draw_ghost_1 <= '0';
		--draw_player_2 <= '0';
	end if;
  end process;

CheckDrawGhost_2: process (clk)
 begin
 if visible_xpos < ghost_2_x+16 and visible_xpos >= ghost_2_x and visible_ypos < ghost_2_y+16 and visible_ypos >= ghost_2_y then
		draw_ghost_2 <= '1';
		--draw_player_2 <= '0';
	--elsif visible_xpos < player_2_xpos+16 and visible_xpos >= player_2_xpos and visible_ypos < player_2_ypos+16 and visible_ypos >= player_2_ypos then
		--draw_player_1 <= '0';
		--draw_player_2 <= '1';
	else
		draw_ghost_2 <= '0';
		--draw_player_2 <= '0';
	end if;
  end process;

  process (clk)
  begin
	--all of these registers end up being reduced, so no worries :-)  I'll try to clean it up later, though.
    if clk'event and clk = '1' then

--      RAM(0) <= "000000000000000000000000000000000000000000";
--      RAM(1) <=	"000000000000000000000000000000000000000000";
--      RAM(2) <=	"000000000000000000000000000000000000000000";
--      RAM(3) <=	"000000000000000000000000000000000000000000";
--      RAM(4) <=	"000000000000000000000000000000000000000000";
--      RAM(5) <=	"000001111111111111111111111111111111111000";
--	  RAM(6) <=	"000001000000000000000000000000000000001000";
--	  RAM(7) <= "000001000000000000000000000000000000001000";
--	  RAM(8) <=	"000001000000000000000000000000000000001000";
--	  RAM(9) <= "000001000000000000000000000000000000001000";
--	  RAM(10)<= "000001000000000000000000000000000000001000";
--	  RAM(11)<= "000001000000000000000000000000000000001000";
--	  RAM(12)<= "000001000000000000000000000000000000001000";
--	  RAM(13)<= "000001000000000000000000000000000000001000";
--	  RAM(14)<= "000001000000000000000000000000000000001000";
--	  RAM(15)<=	"000001000000000000000000000000000000001000";
--	  RAM(16)<= "000001000000000000000000000000000000001000";
--	  RAM(17)<= "000001000000000000000000000000000000001000";
--	  RAM(18)<= "000001000000000000000000000000000000001000";
--	  RAM(19)<= "000001000000000000000000000000000000001000";
--	  RAM(20)<= "000001000000000000000000000000000000001000";
--	  RAM(21)<= "000001000000000000000000000000000000001000";
--	  RAM(22)<=	"000001000000000000000000000000000000001000";
--	  RAM(23)<=	"000001000000000000000000000000000000001000";
--	  RAM(24)<= "000001000000000000000000000000000000001000";
--	  RAM(25)<= "000001000000000000000000000000000000001000";
--	  RAM(26)<= "000001000000000000000000000000000000001000";
--	  RAM(27)<= "000001000000000000000000000000000000001000";
--	  RAM(28)<=	"000001111111111111111111111111111111111000";
--	  RAM(29)<= "000000000000000000000000000000000000000000";
--	  RAM(30)<= "000000000000000000000000000000000000000000";
--      RAM(31)<= "000000000000000000000000000000000000000000";
----RAM(29)<= "000000000000000000000000000000000000000000";




	  num_sprite_ram(0)(0) <= "0000000000000000";	
	  num_sprite_ram(0)(1) <= "0000011111100000";
	  num_sprite_ram(0)(2) <= "0000011111100000";
	  num_sprite_ram(0)(3) <= "0001100001111000";
	  num_sprite_ram(0)(4) <= "0001100001111000";
	  num_sprite_ram(0)(5) <= "0111100000011110";
	  num_sprite_ram(0)(6) <= "0111100000011110";
	  num_sprite_ram(0)(7) <= "0111100000011110";
	  num_sprite_ram(0)(8) <= "0111100000011110";
	  num_sprite_ram(0)(9) <= "0111100000011110";
	  num_sprite_ram(0)(10) <="0111100000011110";
	  num_sprite_ram(0)(11) <="0001111000011000";
	  num_sprite_ram(0)(12) <="0001111000011000";
	  num_sprite_ram(0)(13) <="0000011111100000";
	  num_sprite_ram(0)(14) <="0000011111100000";
	  num_sprite_ram(0)(15) <="0000000000000000";


	  num_sprite_ram(1)(0) <= "0000000000000000";	
	  num_sprite_ram(1)(1) <= "0000001111000000";
	  num_sprite_ram(1)(2) <= "0000001111000000";
	  num_sprite_ram(1)(3) <= "0000111111000000";
	  num_sprite_ram(1)(4) <= "0000111111000000";
	  num_sprite_ram(1)(5) <= "0000001111000000";
	  num_sprite_ram(1)(6) <= "0000001111000000";
	  num_sprite_ram(1)(7) <= "0000001111000000";
	  num_sprite_ram(1)(8) <= "0000001111000000";
	  num_sprite_ram(1)(9) <= "0000001111000000";
	  num_sprite_ram(1)(10) <="0000001111000000";
	  num_sprite_ram(1)(11) <="0000001111000000";
	  num_sprite_ram(1)(12) <="0000001111000000";
	  num_sprite_ram(1)(13) <="0011111111111100";
	  num_sprite_ram(1)(14) <="0011111111111100";
	  num_sprite_ram(1)(15) <="0000000000000000";

	  num_sprite_ram(2)(0) <= "0000000000000000";
	  num_sprite_ram(2)(1) <= "0001111111111000";	
	  num_sprite_ram(2)(2) <= "0001111111111000";
	  num_sprite_ram(2)(3) <= "0111100000011110";
	  num_sprite_ram(2)(4) <= "0111100000011110";
	  num_sprite_ram(2)(5) <= "0000000001111110";
	  num_sprite_ram(2)(6) <= "0000000001111110";
	  num_sprite_ram(2)(7) <= "0000011111111000";
	  num_sprite_ram(2)(8) <= "0000011111111000";
	  num_sprite_ram(2)(9) <= "0001111111100000";
	  num_sprite_ram(2)(10) <="0001111111100000";
	  num_sprite_ram(2)(11) <="0111111000000000";
	  num_sprite_ram(2)(12) <="0111111000000000";
	  num_sprite_ram(2)(13) <="0111111111111110";
	  num_sprite_ram(2)(14) <="0111111111111110";
	  num_sprite_ram(2)(15) <="0000000000000000";

	  num_sprite_ram(3)(0) <= "0000000000000000";
	  num_sprite_ram(3)(1) <= "0000011111111000";
	  num_sprite_ram(3)(2) <= "0000011111111000";
	  num_sprite_ram(3)(3) <= "0001100001111000";
	  num_sprite_ram(3)(4) <= "0001100001111000";
	  num_sprite_ram(3)(5) <= "0000000001111000";
	  num_sprite_ram(3)(6) <= "0000000001111000";
	  num_sprite_ram(3)(7) <= "0000000111100000";
	  num_sprite_ram(3)(8) <= "0000000111100000";
	  num_sprite_ram(3)(9) <= "0000000001111110";
	  num_sprite_ram(3)(10) <="0000000001111110";
	  num_sprite_ram(3)(11) <="0110000000011110";
	  num_sprite_ram(3)(12) <="0110000000011110";
	  num_sprite_ram(3)(13) <="0001111111111000";
	  num_sprite_ram(3)(14) <="0001111111111000";
	  num_sprite_ram(3)(15) <="0000000000000000";

	  num_sprite_ram(4)(0) <= "0000000000000000";
	  num_sprite_ram(4)(1) <= "0000000111111000";
	  num_sprite_ram(4)(2) <= "0000000111111000";
	  num_sprite_ram(4)(3) <= "0000011111111000";
	  num_sprite_ram(4)(4) <= "0000011111111000";
	  num_sprite_ram(4)(5) <= "0001111001111000";
	  num_sprite_ram(4)(6) <= "0001111001111000";
	  num_sprite_ram(4)(7) <= "0111100001111000";
	  num_sprite_ram(4)(8) <= "0111100001111000";
	  num_sprite_ram(4)(9) <= "0111111111111110";
	  num_sprite_ram(4)(10) <="0000000001111000";
	  num_sprite_ram(4)(11) <="0000000001111000";
	  num_sprite_ram(4)(12) <="0000000001111000";
	  num_sprite_ram(4)(13) <="0000000001111000";
	  num_sprite_ram(4)(14) <="0000000001111000";
	  num_sprite_ram(4)(15) <="0000000000000000";

	  num_sprite_ram(5)(0) <= "0000000000000000";
	  num_sprite_ram(5)(1) <= "0111111111111000";
	  num_sprite_ram(5)(2) <= "0111111111111000";
	  num_sprite_ram(5)(3) <= "0111100000000000";
	  num_sprite_ram(5)(4) <= "0111100000000000";
	  num_sprite_ram(5)(5) <= "0111111111111000";
	  num_sprite_ram(5)(6) <= "0111111111111000";
	  num_sprite_ram(5)(7) <= "0000000000011110";
	  num_sprite_ram(5)(8) <= "0000000000011110";
	  num_sprite_ram(5)(9) <= "0000000000011110";
	  num_sprite_ram(5)(10) <="0000000000011110";
	  num_sprite_ram(5)(11) <="0111100000011110";
	  num_sprite_ram(5)(12) <="0111100000011110";
	  num_sprite_ram(5)(13) <="0001111111111000";
	  num_sprite_ram(5)(14) <="0001111111111000";
	  num_sprite_ram(5)(15) <="0000000000000000";

	  num_sprite_ram(6)(0) <= "0000000000000000";
	  num_sprite_ram(6)(1) <= "0001111111111000";
	  num_sprite_ram(6)(2) <= "0001111111111000";
	  num_sprite_ram(6)(3) <= "0111100000000000";
	  num_sprite_ram(6)(4) <= "0111100000000000";
	  num_sprite_ram(6)(5) <= "0111111111111000";
	  num_sprite_ram(6)(6) <= "0111111111111000";
	  num_sprite_ram(6)(7) <= "0111100000011110";
	  num_sprite_ram(6)(8) <= "0111100000011110";
	  num_sprite_ram(6)(9) <= "0111100000011110";
	  num_sprite_ram(6)(10) <="0111100000011110";
	  num_sprite_ram(6)(11) <="0111100000011110";
	  num_sprite_ram(6)(12) <="0111100000011110";
	  num_sprite_ram(6)(13) <="0001111111111000";
	  num_sprite_ram(6)(14) <="0001111111111000";
	  num_sprite_ram(6)(15) <="0000000000000000";

	  num_sprite_ram(7)(0) <= "0000000000000000";
	  num_sprite_ram(7)(1) <= "0111111111111110";
	  num_sprite_ram(7)(2) <= "0111111111111110";
	  num_sprite_ram(7)(3) <= "0111100000011110";
	  num_sprite_ram(7)(4) <= "0111100000011110";
	  num_sprite_ram(7)(5) <= "0000000001111000";
	  num_sprite_ram(7)(6) <= "0000000001111000";
	  num_sprite_ram(7)(7) <= "0000000111100000";
	  num_sprite_ram(7)(8) <= "0000000111100000";
	  num_sprite_ram(7)(9) <= "0000011110000000";
	  num_sprite_ram(7)(10) <="0000011110000000";
	  num_sprite_ram(7)(11) <="0000011110000000";
	  num_sprite_ram(7)(12) <="0000011110000000";
	  num_sprite_ram(7)(13) <="0000011110000000";
	  num_sprite_ram(7)(14) <="0000011110000000";
	  num_sprite_ram(7)(15) <="0000000000000000";

	  num_sprite_ram(8)(0) <= "0000000000000000";
	  num_sprite_ram(8)(1) <= "0001111111100000";
	  num_sprite_ram(8)(2) <= "0001111111100000";
	  num_sprite_ram(8)(3) <= "0111100000011000";
	  num_sprite_ram(8)(4) <= "0111100000011000";
	  num_sprite_ram(8)(5) <= "0111111000011000";
	  num_sprite_ram(8)(6) <= "0111111000011000";
	  num_sprite_ram(8)(7) <= "0001111111100000";
	  num_sprite_ram(8)(8) <= "0001111111100000";
	  num_sprite_ram(8)(9) <= "0110000111111110";
	  num_sprite_ram(8)(10) <="0110000111111110";
	  num_sprite_ram(8)(11) <="0110000000011110";
	  num_sprite_ram(8)(12) <="0110000000011110";
	  num_sprite_ram(8)(13) <="0001111111111000";
	  num_sprite_ram(8)(14) <="0001111111111000";
	  num_sprite_ram(8)(15) <="0000000000000000";

	  num_sprite_ram(9)(0) <= "0000000000000000";
	  num_sprite_ram(9)(1) <= "0001111111111000";
	  num_sprite_ram(9)(2) <= "0001111111111000";
	  num_sprite_ram(9)(3) <= "0111100000011110";
	  num_sprite_ram(9)(4) <= "0111100000011110";
	  num_sprite_ram(9)(5) <= "0111100000011110";
	  num_sprite_ram(9)(6) <= "0111100000011110";
	  num_sprite_ram(9)(7) <= "0001111111111110";
	  num_sprite_ram(9)(8) <= "0001111111111110";
	  num_sprite_ram(9)(9) <= "0000000000011110";
	  num_sprite_ram(9)(10) <="0000000000011110";
	  num_sprite_ram(9)(11) <="0000000001111000";
	  num_sprite_ram(9)(12) <="0000000001111000";
	  num_sprite_ram(9)(13) <="0001111111100000";
	  num_sprite_ram(9)(14) <="0001111111100000";
	  num_sprite_ram(9)(15) <="0000000000000000";

	  num_sprite_ram(10)(0) <= "0000000000000000";
	  num_sprite_ram(10)(1) <= "0000000000000000";
	  num_sprite_ram(10)(2) <= "0000000000000000";
	  num_sprite_ram(10)(3) <= "0000000000000000";
	  num_sprite_ram(10)(4) <= "0000000000000000";
	  num_sprite_ram(10)(5) <= "0000000000000000";
	  num_sprite_ram(10)(6) <= "0000000000000000";
	  num_sprite_ram(10)(7) <= "0000000000000000";
	  num_sprite_ram(10)(8) <= "0000000000000000";
	  num_sprite_ram(10)(9) <= "0000000000000000";
	  num_sprite_ram(10)(10) <="0000000000000000";
	  num_sprite_ram(10)(11) <="0000000000000000";
	  num_sprite_ram(10)(12) <="0000000000000000";
	  num_sprite_ram(10)(13) <="0000000000000000";
	  num_sprite_ram(10)(14) <="0000000000000000";
	  num_sprite_ram(10)(15) <="0000000000000000";
	
	  num_sprite_ram(11)(0) <= "0011000000000000";
	  num_sprite_ram(11)(1) <= "0111100000000111";
	  num_sprite_ram(11)(2) <= "1100110000001110";
	  num_sprite_ram(11)(3) <= "1100110000011100";
	  num_sprite_ram(11)(4) <= "0111100000111000";
	  num_sprite_ram(11)(5) <= "0011000001110000";
	  num_sprite_ram(11)(6) <= "0000000011100000";
	  num_sprite_ram(11)(7) <= "0000000111000000";
	  num_sprite_ram(11)(8) <= "0000001110000000";
	  num_sprite_ram(11)(9) <= "0000011100000000";
	  num_sprite_ram(11)(10) <="0000111000001100";
	  num_sprite_ram(11)(11) <="0001110000011110";
	  num_sprite_ram(11)(12) <="0011100000110011";
	  num_sprite_ram(11)(13) <="0111000000110011";
	  num_sprite_ram(11)(14) <="1110000000011110";
	  num_sprite_ram(11)(15) <="0000000000001100";
	
	  char_sprite_ram(0)(0) <= "0000000000000000";
	  char_sprite_ram(0)(1) <= "0001111111111000";
	  char_sprite_ram(0)(2) <= "0011111111111100";
	  char_sprite_ram(0)(3) <= "0111111001111110";
	  char_sprite_ram(0)(4) <= "0111110000111110";
	  char_sprite_ram(0)(5) <= "0111110000111100";
	  char_sprite_ram(0)(6) <= "0111111001111000";
	  char_sprite_ram(0)(7) <= "0111111111110000";
	  char_sprite_ram(0)(8) <= "0111111111111000";
	  char_sprite_ram(0)(9) <= "0111100000111100";
	  char_sprite_ram(0)(10) <="0111100000011110";
	  char_sprite_ram(0)(11) <="0111100000011110";
	  char_sprite_ram(0)(12) <="0111100000011110";
	  char_sprite_ram(0)(13) <="0111100000011110";
	  char_sprite_ram(0)(14) <="0111100000011110";
	  char_sprite_ram(0)(15) <="0000000000000000";
	
	  char_sprite_ram(1)(0) <= "0000000000000000";
	  char_sprite_ram(1)(1) <= "0011111111111110";
	  char_sprite_ram(1)(2) <= "0111111111111110";
	  char_sprite_ram(1)(3) <= "0111100000000000";
	  char_sprite_ram(1)(4) <= "0111100000000000";
	  char_sprite_ram(1)(5) <= "0111100000000000";
	  char_sprite_ram(1)(6) <= "0111100000000000";
	  char_sprite_ram(1)(7) <= "0111111111111110";
	  char_sprite_ram(1)(8) <= "0111111111111110";
	  char_sprite_ram(1)(9) <= "0111100000000000";
	  char_sprite_ram(1)(10) <="0111100000000000";
	  char_sprite_ram(1)(11) <="0111100000000000";
	  char_sprite_ram(1)(12) <="0111100000000000";
	  char_sprite_ram(1)(13) <="0111111111111110";
	  char_sprite_ram(1)(14) <="0011111111111110";
	  char_sprite_ram(1)(15) <="0000000000000000";
	
	  char_sprite_ram(2)(0) <= "0000000000000000";
	  char_sprite_ram(2)(1) <= "0001111111111100";
	  char_sprite_ram(2)(2) <= "0011111111111110";
	  char_sprite_ram(2)(3) <= "0111111000000000";
	  char_sprite_ram(2)(4) <= "0111110000000000";
	  char_sprite_ram(2)(5) <= "0111100000000000";
	  char_sprite_ram(2)(6) <= "0111100000000000";
	  char_sprite_ram(2)(7) <= "0111100000000000";
	  char_sprite_ram(2)(8) <= "0111100000000000";
	  char_sprite_ram(2)(9) <= "0111100000000000";
	  char_sprite_ram(2)(10) <="0111100000000000";
	  char_sprite_ram(2)(11) <="0111110000000000";
	  char_sprite_ram(2)(12) <="0111111000000000";
	  char_sprite_ram(2)(13) <="0011111111111110";
	  char_sprite_ram(2)(14) <="0001111111111100";
	  char_sprite_ram(2)(15) <="0000000000000000";
	
	  char_sprite_ram(3)(0) <= "0000000000000000";
	  char_sprite_ram(3)(1) <= "0001111111111000";
	  char_sprite_ram(3)(2) <= "0011111111111100";
	  char_sprite_ram(3)(3) <= "0111111001111110";
	  char_sprite_ram(3)(4) <= "0111110000111110";
	  char_sprite_ram(3)(5) <= "0111100000011110";
	  char_sprite_ram(3)(6) <= "0111100000011110";
	  char_sprite_ram(3)(7) <= "0111100000011110";
	  char_sprite_ram(3)(8) <= "0111100000011110";
	  char_sprite_ram(3)(9) <= "0111100000011110";
	  char_sprite_ram(3)(10) <="0111100000011110";
	  char_sprite_ram(3)(11) <="0111110000111110";
	  char_sprite_ram(3)(12) <="0111111001111110";
	  char_sprite_ram(3)(13) <="0011111111111100";
	  char_sprite_ram(3)(14) <="0001111111111000";
	  char_sprite_ram(3)(15) <="0000000000000000";
	
	  char_sprite_ram(4)(0) <= "0000000000000000";
	  char_sprite_ram(4)(1) <= "0111111111111000";
	  char_sprite_ram(4)(2) <= "0111111111111100";
	  char_sprite_ram(4)(3) <= "0111100001111110";
	  char_sprite_ram(4)(4) <= "0111100000111110";
	  char_sprite_ram(4)(5) <= "0111100000011110";
	  char_sprite_ram(4)(6) <= "0111100000011110";
	  char_sprite_ram(4)(7) <= "0111100000011110";
	  char_sprite_ram(4)(8) <= "0111100000011110";
	  char_sprite_ram(4)(9) <= "0111100000011110";
	  char_sprite_ram(4)(10) <="0111100000011110";
	  char_sprite_ram(4)(11) <="0111100000111110";
	  char_sprite_ram(4)(12) <="0111100001111110";
	  char_sprite_ram(4)(13) <="0111111111111100";
	  char_sprite_ram(4)(14) <="0111111111111000";
	  char_sprite_ram(4)(15) <="0000000000000000";
		
	  color_ram(0) <= "000000000000000000000000000000";
	  color_ram(1) <= "111111111111111111111000000000";
	  color_ram(2) <= "111111111100000000000000000000";
	  color_ram(3) <= "000000000010000000000000000000";
	  color_ram(4) <= "111111111110000000000100000000";
	  color_ram(5) <= "100000000000000000000000000000";
	  color_ram(6) <= "111111111111111111111111111111";

      pacman_sprite_0_ram(0)(0)<="110";pacman_sprite_0_ram(0)(1)<="110";pacman_sprite_0_ram(0)(2)<="110";pacman_sprite_0_ram(0)(3)<="110";pacman_sprite_0_ram(0)(4)<="110";pacman_sprite_0_ram(0)(5)<="110";pacman_sprite_0_ram(0)(6)<="110";pacman_sprite_0_ram(0)(7)<="110";pacman_sprite_0_ram(0)(8)<="110";pacman_sprite_0_ram(0)(9)<="110";pacman_sprite_0_ram(0)(10)<="110";pacman_sprite_0_ram(0)(11)<="110";pacman_sprite_0_ram(0)(12)<="110";pacman_sprite_0_ram(0)(13)<="110";pacman_sprite_0_ram(0)(14)<="110";pacman_sprite_0_ram(0)(15)<="110";
	  pacman_sprite_0_ram(1)(0)<="110";pacman_sprite_0_ram(1)(1)<="011";pacman_sprite_0_ram(1)(2)<="011";pacman_sprite_0_ram(1)(3)<="011";pacman_sprite_0_ram(1)(4)<="011";pacman_sprite_0_ram(1)(5)<="011";pacman_sprite_0_ram(1)(6)<="001";pacman_sprite_0_ram(1)(7)<="001";pacman_sprite_0_ram(1)(8)<="001";pacman_sprite_0_ram(1)(9)<="001";pacman_sprite_0_ram(1)(10)<="011";pacman_sprite_0_ram(1)(11)<="011";pacman_sprite_0_ram(1)(12)<="011";pacman_sprite_0_ram(1)(13)<="011";pacman_sprite_0_ram(1)(14)<="011";pacman_sprite_0_ram(1)(15)<="011";
	  pacman_sprite_0_ram(2)(0)<="110";pacman_sprite_0_ram(2)(1)<="011";pacman_sprite_0_ram(2)(2)<="011";pacman_sprite_0_ram(2)(3)<="011";pacman_sprite_0_ram(2)(4)<="001";pacman_sprite_0_ram(2)(5)<="001";pacman_sprite_0_ram(2)(6)<="001";pacman_sprite_0_ram(2)(7)<="001";pacman_sprite_0_ram(2)(8)<="001";pacman_sprite_0_ram(2)(9)<="001";pacman_sprite_0_ram(2)(10)<="001";pacman_sprite_0_ram(2)(11)<="001";pacman_sprite_0_ram(2)(12)<="011";pacman_sprite_0_ram(2)(13)<="011";pacman_sprite_0_ram(2)(14)<="011";pacman_sprite_0_ram(2)(15)<="011";
	  pacman_sprite_0_ram(3)(0)<="110";pacman_sprite_0_ram(3)(1)<="011";pacman_sprite_0_ram(3)(2)<="011";pacman_sprite_0_ram(3)(3)<="001";pacman_sprite_0_ram(3)(4)<="001";pacman_sprite_0_ram(3)(5)<="001";pacman_sprite_0_ram(3)(6)<="001";pacman_sprite_0_ram(3)(7)<="001";pacman_sprite_0_ram(3)(8)<="001";pacman_sprite_0_ram(3)(9)<="001";pacman_sprite_0_ram(3)(10)<="001";pacman_sprite_0_ram(3)(11)<="001";pacman_sprite_0_ram(3)(12)<="001";pacman_sprite_0_ram(3)(13)<="011";pacman_sprite_0_ram(3)(14)<="011";pacman_sprite_0_ram(3)(15)<="011";
	  pacman_sprite_0_ram(4)(0)<="110";pacman_sprite_0_ram(4)(1)<="011";pacman_sprite_0_ram(4)(2)<="001";pacman_sprite_0_ram(4)(3)<="001";pacman_sprite_0_ram(4)(4)<="001";pacman_sprite_0_ram(4)(5)<="001";pacman_sprite_0_ram(4)(6)<="001";pacman_sprite_0_ram(4)(7)<="001";pacman_sprite_0_ram(4)(8)<="001";pacman_sprite_0_ram(4)(9)<="001";pacman_sprite_0_ram(4)(10)<="001";pacman_sprite_0_ram(4)(11)<="001";pacman_sprite_0_ram(4)(12)<="001";pacman_sprite_0_ram(4)(13)<="001";pacman_sprite_0_ram(4)(14)<="011";pacman_sprite_0_ram(4)(15)<="011";
	  pacman_sprite_0_ram(5)(0)<="110";pacman_sprite_0_ram(5)(1)<="001";pacman_sprite_0_ram(5)(2)<="001";pacman_sprite_0_ram(5)(3)<="001";pacman_sprite_0_ram(5)(4)<="001";pacman_sprite_0_ram(5)(5)<="001";pacman_sprite_0_ram(5)(6)<="001";pacman_sprite_0_ram(5)(7)<="001";pacman_sprite_0_ram(5)(8)<="001";pacman_sprite_0_ram(5)(9)<="001";pacman_sprite_0_ram(5)(10)<="001";pacman_sprite_0_ram(5)(11)<="001";pacman_sprite_0_ram(5)(12)<="001";pacman_sprite_0_ram(5)(13)<="001";pacman_sprite_0_ram(5)(14)<="001";pacman_sprite_0_ram(5)(15)<="011";
	  pacman_sprite_0_ram(6)(0)<="110";pacman_sprite_0_ram(6)(1)<="001";pacman_sprite_0_ram(6)(2)<="001";pacman_sprite_0_ram(6)(3)<="001";pacman_sprite_0_ram(6)(4)<="001";pacman_sprite_0_ram(6)(5)<="001";pacman_sprite_0_ram(6)(6)<="001";pacman_sprite_0_ram(6)(7)<="001";pacman_sprite_0_ram(6)(8)<="001";pacman_sprite_0_ram(6)(9)<="001";pacman_sprite_0_ram(6)(10)<="001";pacman_sprite_0_ram(6)(11)<="001";pacman_sprite_0_ram(6)(12)<="001";pacman_sprite_0_ram(6)(13)<="001";pacman_sprite_0_ram(6)(14)<="001";pacman_sprite_0_ram(6)(15)<="011";
	  pacman_sprite_0_ram(7)(0)<="110";pacman_sprite_0_ram(7)(1)<="001";pacman_sprite_0_ram(7)(2)<="001";pacman_sprite_0_ram(7)(3)<="001";pacman_sprite_0_ram(7)(4)<="001";pacman_sprite_0_ram(7)(5)<="001";pacman_sprite_0_ram(7)(6)<="001";pacman_sprite_0_ram(7)(7)<="001";pacman_sprite_0_ram(7)(8)<="001";pacman_sprite_0_ram(7)(9)<="001";pacman_sprite_0_ram(7)(10)<="001";pacman_sprite_0_ram(7)(11)<="001";pacman_sprite_0_ram(7)(12)<="001";pacman_sprite_0_ram(7)(13)<="001";pacman_sprite_0_ram(7)(14)<="001";pacman_sprite_0_ram(7)(15)<="011";
	  pacman_sprite_0_ram(8)(0)<="110";pacman_sprite_0_ram(8)(1)<="001";pacman_sprite_0_ram(8)(2)<="001";pacman_sprite_0_ram(8)(3)<="001";pacman_sprite_0_ram(8)(4)<="001";pacman_sprite_0_ram(8)(5)<="001";pacman_sprite_0_ram(8)(6)<="001";pacman_sprite_0_ram(8)(7)<="001";pacman_sprite_0_ram(8)(8)<="001";pacman_sprite_0_ram(8)(9)<="001";pacman_sprite_0_ram(8)(10)<="001";pacman_sprite_0_ram(8)(11)<="001";pacman_sprite_0_ram(8)(12)<="001";pacman_sprite_0_ram(8)(13)<="001";pacman_sprite_0_ram(8)(14)<="001";pacman_sprite_0_ram(8)(15)<="011";
	  pacman_sprite_0_ram(9)(0)<="110";pacman_sprite_0_ram(9)(1)<="001";pacman_sprite_0_ram(9)(2)<="001";pacman_sprite_0_ram(9)(3)<="001";pacman_sprite_0_ram(9)(4)<="001";pacman_sprite_0_ram(9)(5)<="001";pacman_sprite_0_ram(9)(6)<="001";pacman_sprite_0_ram(9)(7)<="001";pacman_sprite_0_ram(9)(8)<="001";pacman_sprite_0_ram(9)(9)<="001";pacman_sprite_0_ram(9)(10)<="001";pacman_sprite_0_ram(9)(11)<="001";pacman_sprite_0_ram(9)(12)<="001";pacman_sprite_0_ram(9)(13)<="001";pacman_sprite_0_ram(9)(14)<="001";pacman_sprite_0_ram(9)(15)<="011";
	  pacman_sprite_0_ram(10)(0)<="110";pacman_sprite_0_ram(10)(1)<="001";pacman_sprite_0_ram(10)(2)<="001";pacman_sprite_0_ram(10)(3)<="001";pacman_sprite_0_ram(10)(4)<="001";pacman_sprite_0_ram(10)(5)<="001";pacman_sprite_0_ram(10)(6)<="001";pacman_sprite_0_ram(10)(7)<="001";pacman_sprite_0_ram(10)(8)<="001";pacman_sprite_0_ram(10)(9)<="001";pacman_sprite_0_ram(10)(10)<="001";pacman_sprite_0_ram(10)(11)<="001";pacman_sprite_0_ram(10)(12)<="001";pacman_sprite_0_ram(10)(13)<="001";pacman_sprite_0_ram(10)(14)<="001";pacman_sprite_0_ram(10)(15)<="011";
	  pacman_sprite_0_ram(11)(0)<="110";pacman_sprite_0_ram(11)(1)<="011";pacman_sprite_0_ram(11)(2)<="001";pacman_sprite_0_ram(11)(3)<="001";pacman_sprite_0_ram(11)(4)<="001";pacman_sprite_0_ram(11)(5)<="001";pacman_sprite_0_ram(11)(6)<="001";pacman_sprite_0_ram(11)(7)<="001";pacman_sprite_0_ram(11)(8)<="001";pacman_sprite_0_ram(11)(9)<="001";pacman_sprite_0_ram(11)(10)<="001";pacman_sprite_0_ram(11)(11)<="001";pacman_sprite_0_ram(11)(12)<="001";pacman_sprite_0_ram(11)(13)<="001";pacman_sprite_0_ram(11)(14)<="011";pacman_sprite_0_ram(11)(15)<="011";
	  pacman_sprite_0_ram(12)(0)<="110";pacman_sprite_0_ram(12)(1)<="011";pacman_sprite_0_ram(12)(2)<="011";pacman_sprite_0_ram(12)(3)<="001";pacman_sprite_0_ram(12)(4)<="001";pacman_sprite_0_ram(12)(5)<="001";pacman_sprite_0_ram(12)(6)<="001";pacman_sprite_0_ram(12)(7)<="001";pacman_sprite_0_ram(12)(8)<="001";pacman_sprite_0_ram(12)(9)<="001";pacman_sprite_0_ram(12)(10)<="001";pacman_sprite_0_ram(12)(11)<="001";pacman_sprite_0_ram(12)(12)<="001";pacman_sprite_0_ram(12)(13)<="011";pacman_sprite_0_ram(12)(14)<="011";pacman_sprite_0_ram(12)(15)<="011";
	  pacman_sprite_0_ram(13)(0)<="110";pacman_sprite_0_ram(13)(1)<="011";pacman_sprite_0_ram(13)(2)<="011";pacman_sprite_0_ram(13)(3)<="011";pacman_sprite_0_ram(13)(4)<="001";pacman_sprite_0_ram(13)(5)<="001";pacman_sprite_0_ram(13)(6)<="001";pacman_sprite_0_ram(13)(7)<="001";pacman_sprite_0_ram(13)(8)<="001";pacman_sprite_0_ram(13)(9)<="001";pacman_sprite_0_ram(13)(10)<="001";pacman_sprite_0_ram(13)(11)<="001";pacman_sprite_0_ram(13)(12)<="011";pacman_sprite_0_ram(13)(13)<="011";pacman_sprite_0_ram(13)(14)<="011";pacman_sprite_0_ram(13)(15)<="011";
	  pacman_sprite_0_ram(14)(0)<="110";pacman_sprite_0_ram(14)(1)<="011";pacman_sprite_0_ram(14)(2)<="011";pacman_sprite_0_ram(14)(3)<="011";pacman_sprite_0_ram(14)(4)<="011";pacman_sprite_0_ram(14)(5)<="011";pacman_sprite_0_ram(14)(6)<="001";pacman_sprite_0_ram(14)(7)<="001";pacman_sprite_0_ram(14)(8)<="001";pacman_sprite_0_ram(14)(9)<="001";pacman_sprite_0_ram(14)(10)<="011";pacman_sprite_0_ram(14)(11)<="011";pacman_sprite_0_ram(14)(12)<="011";pacman_sprite_0_ram(14)(13)<="011";pacman_sprite_0_ram(14)(14)<="011";pacman_sprite_0_ram(14)(15)<="011";
	  pacman_sprite_0_ram(15)(0)<="110";pacman_sprite_0_ram(15)(1)<="011";pacman_sprite_0_ram(15)(2)<="011";pacman_sprite_0_ram(15)(3)<="011";pacman_sprite_0_ram(15)(4)<="011";pacman_sprite_0_ram(15)(5)<="011";pacman_sprite_0_ram(15)(6)<="011";pacman_sprite_0_ram(15)(7)<="011";pacman_sprite_0_ram(15)(8)<="011";pacman_sprite_0_ram(15)(9)<="011";pacman_sprite_0_ram(15)(10)<="011";pacman_sprite_0_ram(15)(11)<="011";pacman_sprite_0_ram(15)(12)<="011";pacman_sprite_0_ram(15)(13)<="011";pacman_sprite_0_ram(15)(14)<="011";pacman_sprite_0_ram(15)(15)<="011";

      pacman_sprite_right_ram(0)(0)<="110";pacman_sprite_right_ram(0)(1)<="110";pacman_sprite_right_ram(0)(2)<="110";pacman_sprite_right_ram(0)(3)<="110";pacman_sprite_right_ram(0)(4)<="110";pacman_sprite_right_ram(0)(5)<="110";pacman_sprite_right_ram(0)(6)<="110";pacman_sprite_right_ram(0)(7)<="110";pacman_sprite_right_ram(0)(8)<="110";pacman_sprite_right_ram(0)(9)<="110";pacman_sprite_right_ram(0)(10)<="110";pacman_sprite_right_ram(0)(11)<="110";pacman_sprite_right_ram(0)(12)<="110";pacman_sprite_right_ram(0)(13)<="110";pacman_sprite_right_ram(0)(14)<="110";pacman_sprite_right_ram(0)(15)<="011";
	  pacman_sprite_right_ram(1)(0)<="110";pacman_sprite_right_ram(1)(1)<="011";pacman_sprite_right_ram(1)(2)<="011";pacman_sprite_right_ram(1)(3)<="011";pacman_sprite_right_ram(1)(4)<="011";pacman_sprite_right_ram(1)(5)<="011";pacman_sprite_right_ram(1)(6)<="001";pacman_sprite_right_ram(1)(7)<="001";pacman_sprite_right_ram(1)(8)<="001";pacman_sprite_right_ram(1)(9)<="001";pacman_sprite_right_ram(1)(10)<="011";pacman_sprite_right_ram(1)(11)<="011";pacman_sprite_right_ram(1)(12)<="011";pacman_sprite_right_ram(1)(13)<="011";pacman_sprite_right_ram(1)(14)<="011";pacman_sprite_right_ram(1)(15)<="011";
	  pacman_sprite_right_ram(2)(0)<="110";pacman_sprite_right_ram(2)(1)<="011";pacman_sprite_right_ram(2)(2)<="011";pacman_sprite_right_ram(2)(3)<="011";pacman_sprite_right_ram(2)(4)<="001";pacman_sprite_right_ram(2)(5)<="001";pacman_sprite_right_ram(2)(6)<="001";pacman_sprite_right_ram(2)(7)<="001";pacman_sprite_right_ram(2)(8)<="001";pacman_sprite_right_ram(2)(9)<="001";pacman_sprite_right_ram(2)(10)<="001";pacman_sprite_right_ram(2)(11)<="001";pacman_sprite_right_ram(2)(12)<="011";pacman_sprite_right_ram(2)(13)<="011";pacman_sprite_right_ram(2)(14)<="011";pacman_sprite_right_ram(2)(15)<="011";
	  pacman_sprite_right_ram(3)(0)<="110";pacman_sprite_right_ram(3)(1)<="011";pacman_sprite_right_ram(3)(2)<="011";pacman_sprite_right_ram(3)(3)<="001";pacman_sprite_right_ram(3)(4)<="001";pacman_sprite_right_ram(3)(5)<="001";pacman_sprite_right_ram(3)(6)<="001";pacman_sprite_right_ram(3)(7)<="001";pacman_sprite_right_ram(3)(8)<="001";pacman_sprite_right_ram(3)(9)<="001";pacman_sprite_right_ram(3)(10)<="001";pacman_sprite_right_ram(3)(11)<="001";pacman_sprite_right_ram(3)(12)<="001";pacman_sprite_right_ram(3)(13)<="011";pacman_sprite_right_ram(3)(14)<="011";pacman_sprite_right_ram(3)(15)<="011";
	  pacman_sprite_right_ram(4)(0)<="110";pacman_sprite_right_ram(4)(1)<="011";pacman_sprite_right_ram(4)(2)<="001";pacman_sprite_right_ram(4)(3)<="001";pacman_sprite_right_ram(4)(4)<="001";pacman_sprite_right_ram(4)(5)<="001";pacman_sprite_right_ram(4)(6)<="001";pacman_sprite_right_ram(4)(7)<="001";pacman_sprite_right_ram(4)(8)<="001";pacman_sprite_right_ram(4)(9)<="001";pacman_sprite_right_ram(4)(10)<="001";pacman_sprite_right_ram(4)(11)<="001";pacman_sprite_right_ram(4)(12)<="001";pacman_sprite_right_ram(4)(13)<="001";pacman_sprite_right_ram(4)(14)<="011";pacman_sprite_right_ram(4)(15)<="011";
	  pacman_sprite_right_ram(5)(0)<="110";pacman_sprite_right_ram(5)(1)<="001";pacman_sprite_right_ram(5)(2)<="001";pacman_sprite_right_ram(5)(3)<="001";pacman_sprite_right_ram(5)(4)<="001";pacman_sprite_right_ram(5)(5)<="001";pacman_sprite_right_ram(5)(6)<="001";pacman_sprite_right_ram(5)(7)<="001";pacman_sprite_right_ram(5)(8)<="001";pacman_sprite_right_ram(5)(9)<="001";pacman_sprite_right_ram(5)(10)<="001";pacman_sprite_right_ram(5)(11)<="011";pacman_sprite_right_ram(5)(12)<="011";pacman_sprite_right_ram(5)(13)<="011";pacman_sprite_right_ram(5)(14)<="011";pacman_sprite_right_ram(5)(15)<="011";
	  pacman_sprite_right_ram(6)(0)<="110";pacman_sprite_right_ram(6)(1)<="001";pacman_sprite_right_ram(6)(2)<="001";pacman_sprite_right_ram(6)(3)<="001";pacman_sprite_right_ram(6)(4)<="001";pacman_sprite_right_ram(6)(5)<="001";pacman_sprite_right_ram(6)(6)<="001";pacman_sprite_right_ram(6)(7)<="001";pacman_sprite_right_ram(6)(8)<="001";pacman_sprite_right_ram(6)(9)<="011";pacman_sprite_right_ram(6)(10)<="011";pacman_sprite_right_ram(6)(11)<="011";pacman_sprite_right_ram(6)(12)<="011";pacman_sprite_right_ram(6)(13)<="011";pacman_sprite_right_ram(6)(14)<="011";pacman_sprite_right_ram(6)(15)<="011";
	  pacman_sprite_right_ram(7)(0)<="110";pacman_sprite_right_ram(7)(1)<="001";pacman_sprite_right_ram(7)(2)<="001";pacman_sprite_right_ram(7)(3)<="001";pacman_sprite_right_ram(7)(4)<="001";pacman_sprite_right_ram(7)(5)<="001";pacman_sprite_right_ram(7)(6)<="001";pacman_sprite_right_ram(7)(7)<="011";pacman_sprite_right_ram(7)(8)<="011";pacman_sprite_right_ram(7)(9)<="011";pacman_sprite_right_ram(7)(10)<="011";pacman_sprite_right_ram(7)(11)<="011";pacman_sprite_right_ram(7)(12)<="011";pacman_sprite_right_ram(7)(13)<="011";pacman_sprite_right_ram(7)(14)<="011";pacman_sprite_right_ram(7)(15)<="011";
	  pacman_sprite_right_ram(8)(0)<="110";pacman_sprite_right_ram(8)(1)<="001";pacman_sprite_right_ram(8)(2)<="001";pacman_sprite_right_ram(8)(3)<="001";pacman_sprite_right_ram(8)(4)<="001";pacman_sprite_right_ram(8)(5)<="001";pacman_sprite_right_ram(8)(6)<="001";pacman_sprite_right_ram(8)(7)<="001";pacman_sprite_right_ram(8)(8)<="011";pacman_sprite_right_ram(8)(9)<="011";pacman_sprite_right_ram(8)(10)<="011";pacman_sprite_right_ram(8)(11)<="011";pacman_sprite_right_ram(8)(12)<="011";pacman_sprite_right_ram(8)(13)<="011";pacman_sprite_right_ram(8)(14)<="011";pacman_sprite_right_ram(8)(15)<="011";
	  pacman_sprite_right_ram(9)(0)<="110";pacman_sprite_right_ram(9)(1)<="001";pacman_sprite_right_ram(9)(2)<="001";pacman_sprite_right_ram(9)(3)<="001";pacman_sprite_right_ram(9)(4)<="001";pacman_sprite_right_ram(9)(5)<="001";pacman_sprite_right_ram(9)(6)<="001";pacman_sprite_right_ram(9)(7)<="001";pacman_sprite_right_ram(9)(8)<="001";pacman_sprite_right_ram(9)(9)<="001";pacman_sprite_right_ram(9)(10)<="011";pacman_sprite_right_ram(9)(11)<="011";pacman_sprite_right_ram(9)(12)<="011";pacman_sprite_right_ram(9)(13)<="011";pacman_sprite_right_ram(9)(14)<="011";pacman_sprite_right_ram(9)(15)<="011";
	  pacman_sprite_right_ram(10)(0)<="110";pacman_sprite_right_ram(10)(1)<="001";pacman_sprite_right_ram(10)(2)<="001";pacman_sprite_right_ram(10)(3)<="001";pacman_sprite_right_ram(10)(4)<="001";pacman_sprite_right_ram(10)(5)<="001";pacman_sprite_right_ram(10)(6)<="001";pacman_sprite_right_ram(10)(7)<="001";pacman_sprite_right_ram(10)(8)<="001";pacman_sprite_right_ram(10)(9)<="001";pacman_sprite_right_ram(10)(10)<="001";pacman_sprite_right_ram(10)(11)<="001";pacman_sprite_right_ram(10)(12)<="011";pacman_sprite_right_ram(10)(13)<="011";pacman_sprite_right_ram(10)(14)<="011";pacman_sprite_right_ram(10)(15)<="011";
	  pacman_sprite_right_ram(11)(0)<="110";pacman_sprite_right_ram(11)(1)<="011";pacman_sprite_right_ram(11)(2)<="001";pacman_sprite_right_ram(11)(3)<="001";pacman_sprite_right_ram(11)(4)<="001";pacman_sprite_right_ram(11)(5)<="001";pacman_sprite_right_ram(11)(6)<="001";pacman_sprite_right_ram(11)(7)<="001";pacman_sprite_right_ram(11)(8)<="001";pacman_sprite_right_ram(11)(9)<="001";pacman_sprite_right_ram(11)(10)<="001";pacman_sprite_right_ram(11)(11)<="001";pacman_sprite_right_ram(11)(12)<="001";pacman_sprite_right_ram(11)(13)<="001";pacman_sprite_right_ram(11)(14)<="011";pacman_sprite_right_ram(11)(15)<="011";
	  pacman_sprite_right_ram(12)(0)<="110";pacman_sprite_right_ram(12)(1)<="011";pacman_sprite_right_ram(12)(2)<="011";pacman_sprite_right_ram(12)(3)<="001";pacman_sprite_right_ram(12)(4)<="001";pacman_sprite_right_ram(12)(5)<="001";pacman_sprite_right_ram(12)(6)<="001";pacman_sprite_right_ram(12)(7)<="001";pacman_sprite_right_ram(12)(8)<="001";pacman_sprite_right_ram(12)(9)<="001";pacman_sprite_right_ram(12)(10)<="001";pacman_sprite_right_ram(12)(11)<="001";pacman_sprite_right_ram(12)(12)<="001";pacman_sprite_right_ram(12)(13)<="011";pacman_sprite_right_ram(12)(14)<="011";pacman_sprite_right_ram(12)(15)<="011";
	  pacman_sprite_right_ram(13)(0)<="110";pacman_sprite_right_ram(13)(1)<="011";pacman_sprite_right_ram(13)(2)<="011";pacman_sprite_right_ram(13)(3)<="011";pacman_sprite_right_ram(13)(4)<="001";pacman_sprite_right_ram(13)(5)<="001";pacman_sprite_right_ram(13)(6)<="001";pacman_sprite_right_ram(13)(7)<="001";pacman_sprite_right_ram(13)(8)<="001";pacman_sprite_right_ram(13)(9)<="001";pacman_sprite_right_ram(13)(10)<="001";pacman_sprite_right_ram(13)(11)<="001";pacman_sprite_right_ram(13)(12)<="011";pacman_sprite_right_ram(13)(13)<="011";pacman_sprite_right_ram(13)(14)<="011";pacman_sprite_right_ram(13)(15)<="011";
	  pacman_sprite_right_ram(14)(0)<="110";pacman_sprite_right_ram(14)(1)<="011";pacman_sprite_right_ram(14)(2)<="011";pacman_sprite_right_ram(14)(3)<="011";pacman_sprite_right_ram(14)(4)<="011";pacman_sprite_right_ram(14)(5)<="011";pacman_sprite_right_ram(14)(6)<="001";pacman_sprite_right_ram(14)(7)<="001";pacman_sprite_right_ram(14)(8)<="001";pacman_sprite_right_ram(14)(9)<="001";pacman_sprite_right_ram(14)(10)<="011";pacman_sprite_right_ram(14)(11)<="011";pacman_sprite_right_ram(14)(12)<="011";pacman_sprite_right_ram(14)(13)<="011";pacman_sprite_right_ram(14)(14)<="011";pacman_sprite_right_ram(14)(15)<="011";
	  pacman_sprite_right_ram(15)(0)<="110";pacman_sprite_right_ram(15)(1)<="011";pacman_sprite_right_ram(15)(2)<="011";pacman_sprite_right_ram(15)(3)<="011";pacman_sprite_right_ram(15)(4)<="011";pacman_sprite_right_ram(15)(5)<="011";pacman_sprite_right_ram(15)(6)<="011";pacman_sprite_right_ram(15)(7)<="011";pacman_sprite_right_ram(15)(8)<="011";pacman_sprite_right_ram(15)(9)<="011";pacman_sprite_right_ram(15)(10)<="011";pacman_sprite_right_ram(15)(11)<="011";pacman_sprite_right_ram(15)(12)<="011";pacman_sprite_right_ram(15)(13)<="011";pacman_sprite_right_ram(15)(14)<="011";pacman_sprite_right_ram(15)(15)<="011";

      pacman_sprite_down_ram(0)(0)<="110";pacman_sprite_down_ram(0)(1)<="110";pacman_sprite_down_ram(0)(2)<="110";pacman_sprite_down_ram(0)(3)<="110";pacman_sprite_down_ram(0)(4)<="110";pacman_sprite_down_ram(0)(5)<="110";pacman_sprite_down_ram(0)(6)<="110";pacman_sprite_down_ram(0)(7)<="110";pacman_sprite_down_ram(0)(8)<="110";pacman_sprite_down_ram(0)(9)<="110";pacman_sprite_down_ram(0)(10)<="110";pacman_sprite_down_ram(0)(11)<="110";pacman_sprite_down_ram(0)(12)<="110";pacman_sprite_down_ram(0)(13)<="110";pacman_sprite_down_ram(0)(14)<="110";pacman_sprite_down_ram(0)(15)<="110";
	  pacman_sprite_down_ram(1)(0)<="110";pacman_sprite_down_ram(1)(1)<="011";pacman_sprite_down_ram(1)(2)<="011";pacman_sprite_down_ram(1)(3)<="011";pacman_sprite_down_ram(1)(4)<="011";pacman_sprite_down_ram(1)(5)<="011";pacman_sprite_down_ram(1)(6)<="001";pacman_sprite_down_ram(1)(7)<="001";pacman_sprite_down_ram(1)(8)<="001";pacman_sprite_down_ram(1)(9)<="001";pacman_sprite_down_ram(1)(10)<="011";pacman_sprite_down_ram(1)(11)<="011";pacman_sprite_down_ram(1)(12)<="011";pacman_sprite_down_ram(1)(13)<="011";pacman_sprite_down_ram(1)(14)<="011";pacman_sprite_down_ram(1)(15)<="011";
	  pacman_sprite_down_ram(2)(0)<="110";pacman_sprite_down_ram(2)(1)<="011";pacman_sprite_down_ram(2)(2)<="011";pacman_sprite_down_ram(2)(3)<="011";pacman_sprite_down_ram(2)(4)<="001";pacman_sprite_down_ram(2)(5)<="001";pacman_sprite_down_ram(2)(6)<="001";pacman_sprite_down_ram(2)(7)<="001";pacman_sprite_down_ram(2)(8)<="001";pacman_sprite_down_ram(2)(9)<="001";pacman_sprite_down_ram(2)(10)<="001";pacman_sprite_down_ram(2)(11)<="001";pacman_sprite_down_ram(2)(12)<="011";pacman_sprite_down_ram(2)(13)<="011";pacman_sprite_down_ram(2)(14)<="011";pacman_sprite_down_ram(2)(15)<="011";
	  pacman_sprite_down_ram(3)(0)<="110";pacman_sprite_down_ram(3)(1)<="011";pacman_sprite_down_ram(3)(2)<="011";pacman_sprite_down_ram(3)(3)<="001";pacman_sprite_down_ram(3)(4)<="001";pacman_sprite_down_ram(3)(5)<="001";pacman_sprite_down_ram(3)(6)<="001";pacman_sprite_down_ram(3)(7)<="001";pacman_sprite_down_ram(3)(8)<="001";pacman_sprite_down_ram(3)(9)<="001";pacman_sprite_down_ram(3)(10)<="001";pacman_sprite_down_ram(3)(11)<="001";pacman_sprite_down_ram(3)(12)<="001";pacman_sprite_down_ram(3)(13)<="011";pacman_sprite_down_ram(3)(14)<="011";pacman_sprite_down_ram(3)(15)<="011";
	  pacman_sprite_down_ram(4)(0)<="110";pacman_sprite_down_ram(4)(1)<="011";pacman_sprite_down_ram(4)(2)<="001";pacman_sprite_down_ram(4)(3)<="001";pacman_sprite_down_ram(4)(4)<="001";pacman_sprite_down_ram(4)(5)<="001";pacman_sprite_down_ram(4)(6)<="001";pacman_sprite_down_ram(4)(7)<="001";pacman_sprite_down_ram(4)(8)<="001";pacman_sprite_down_ram(4)(9)<="001";pacman_sprite_down_ram(4)(10)<="001";pacman_sprite_down_ram(4)(11)<="001";pacman_sprite_down_ram(4)(12)<="001";pacman_sprite_down_ram(4)(13)<="001";pacman_sprite_down_ram(4)(14)<="011";pacman_sprite_down_ram(4)(15)<="011";
	  pacman_sprite_down_ram(5)(0)<="110";pacman_sprite_down_ram(5)(1)<="001";pacman_sprite_down_ram(5)(2)<="001";pacman_sprite_down_ram(5)(3)<="001";pacman_sprite_down_ram(5)(4)<="001";pacman_sprite_down_ram(5)(5)<="001";pacman_sprite_down_ram(5)(6)<="001";pacman_sprite_down_ram(5)(7)<="001";pacman_sprite_down_ram(5)(8)<="001";pacman_sprite_down_ram(5)(9)<="001";pacman_sprite_down_ram(5)(10)<="001";pacman_sprite_down_ram(5)(11)<="001";pacman_sprite_down_ram(5)(12)<="001";pacman_sprite_down_ram(5)(13)<="001";pacman_sprite_down_ram(5)(14)<="001";pacman_sprite_down_ram(5)(15)<="011";
	  pacman_sprite_down_ram(6)(0)<="110";pacman_sprite_down_ram(6)(1)<="001";pacman_sprite_down_ram(6)(2)<="001";pacman_sprite_down_ram(6)(3)<="001";pacman_sprite_down_ram(6)(4)<="001";pacman_sprite_down_ram(6)(5)<="001";pacman_sprite_down_ram(6)(6)<="001";pacman_sprite_down_ram(6)(7)<="001";pacman_sprite_down_ram(6)(8)<="001";pacman_sprite_down_ram(6)(9)<="001";pacman_sprite_down_ram(6)(10)<="001";pacman_sprite_down_ram(6)(11)<="001";pacman_sprite_down_ram(6)(12)<="001";pacman_sprite_down_ram(6)(13)<="001";pacman_sprite_down_ram(6)(14)<="001";pacman_sprite_down_ram(6)(15)<="011";
	  pacman_sprite_down_ram(7)(0)<="110";pacman_sprite_down_ram(7)(1)<="001";pacman_sprite_down_ram(7)(2)<="001";pacman_sprite_down_ram(7)(3)<="001";pacman_sprite_down_ram(7)(4)<="001";pacman_sprite_down_ram(7)(5)<="001";pacman_sprite_down_ram(7)(6)<="001";pacman_sprite_down_ram(7)(7)<="011";pacman_sprite_down_ram(7)(8)<="001";pacman_sprite_down_ram(7)(9)<="001";pacman_sprite_down_ram(7)(10)<="001";pacman_sprite_down_ram(7)(11)<="001";pacman_sprite_down_ram(7)(12)<="001";pacman_sprite_down_ram(7)(13)<="001";pacman_sprite_down_ram(7)(14)<="001";pacman_sprite_down_ram(7)(15)<="011";
	  pacman_sprite_down_ram(8)(0)<="110";pacman_sprite_down_ram(8)(1)<="001";pacman_sprite_down_ram(8)(2)<="001";pacman_sprite_down_ram(8)(3)<="001";pacman_sprite_down_ram(8)(4)<="001";pacman_sprite_down_ram(8)(5)<="001";pacman_sprite_down_ram(8)(6)<="001";pacman_sprite_down_ram(8)(7)<="011";pacman_sprite_down_ram(8)(8)<="011";pacman_sprite_down_ram(8)(9)<="001";pacman_sprite_down_ram(8)(10)<="001";pacman_sprite_down_ram(8)(11)<="001";pacman_sprite_down_ram(8)(12)<="001";pacman_sprite_down_ram(8)(13)<="001";pacman_sprite_down_ram(8)(14)<="001";pacman_sprite_down_ram(8)(15)<="011";
	  pacman_sprite_down_ram(9)(0)<="110";pacman_sprite_down_ram(9)(1)<="001";pacman_sprite_down_ram(9)(2)<="001";pacman_sprite_down_ram(9)(3)<="001";pacman_sprite_down_ram(9)(4)<="001";pacman_sprite_down_ram(9)(5)<="001";pacman_sprite_down_ram(9)(6)<="011";pacman_sprite_down_ram(9)(7)<="011";pacman_sprite_down_ram(9)(8)<="011";pacman_sprite_down_ram(9)(9)<="001";pacman_sprite_down_ram(9)(10)<="001";pacman_sprite_down_ram(9)(11)<="001";pacman_sprite_down_ram(9)(12)<="001";pacman_sprite_down_ram(9)(13)<="001";pacman_sprite_down_ram(9)(14)<="001";pacman_sprite_down_ram(9)(15)<="011";
	  pacman_sprite_down_ram(10)(0)<="110";pacman_sprite_down_ram(10)(1)<="001";pacman_sprite_down_ram(10)(2)<="001";pacman_sprite_down_ram(10)(3)<="001";pacman_sprite_down_ram(10)(4)<="001";pacman_sprite_down_ram(10)(5)<="001";pacman_sprite_down_ram(10)(6)<="011";pacman_sprite_down_ram(10)(7)<="011";pacman_sprite_down_ram(10)(8)<="011";pacman_sprite_down_ram(10)(9)<="011";pacman_sprite_down_ram(10)(10)<="001";pacman_sprite_down_ram(10)(11)<="001";pacman_sprite_down_ram(10)(12)<="001";pacman_sprite_down_ram(10)(13)<="001";pacman_sprite_down_ram(10)(14)<="001";pacman_sprite_down_ram(10)(15)<="011";
	  pacman_sprite_down_ram(11)(0)<="110";pacman_sprite_down_ram(11)(1)<="011";pacman_sprite_down_ram(11)(2)<="001";pacman_sprite_down_ram(11)(3)<="001";pacman_sprite_down_ram(11)(4)<="001";pacman_sprite_down_ram(11)(5)<="011";pacman_sprite_down_ram(11)(6)<="011";pacman_sprite_down_ram(11)(7)<="011";pacman_sprite_down_ram(11)(8)<="011";pacman_sprite_down_ram(11)(9)<="011";pacman_sprite_down_ram(11)(10)<="001";pacman_sprite_down_ram(11)(11)<="001";pacman_sprite_down_ram(11)(12)<="001";pacman_sprite_down_ram(11)(13)<="001";pacman_sprite_down_ram(11)(14)<="011";pacman_sprite_down_ram(11)(15)<="011";
	  pacman_sprite_down_ram(12)(0)<="110";pacman_sprite_down_ram(12)(1)<="011";pacman_sprite_down_ram(12)(2)<="011";pacman_sprite_down_ram(12)(3)<="001";pacman_sprite_down_ram(12)(4)<="001";pacman_sprite_down_ram(12)(5)<="011";pacman_sprite_down_ram(12)(6)<="011";pacman_sprite_down_ram(12)(7)<="011";pacman_sprite_down_ram(12)(8)<="011";pacman_sprite_down_ram(12)(9)<="011";pacman_sprite_down_ram(12)(10)<="011";pacman_sprite_down_ram(12)(11)<="001";pacman_sprite_down_ram(12)(12)<="001";pacman_sprite_down_ram(12)(13)<="011";pacman_sprite_down_ram(12)(14)<="011";pacman_sprite_down_ram(12)(15)<="011";
	  pacman_sprite_down_ram(13)(0)<="110";pacman_sprite_down_ram(13)(1)<="011";pacman_sprite_down_ram(13)(2)<="011";pacman_sprite_down_ram(13)(3)<="011";pacman_sprite_down_ram(13)(4)<="011";pacman_sprite_down_ram(13)(5)<="011";pacman_sprite_down_ram(13)(6)<="011";pacman_sprite_down_ram(13)(7)<="011";pacman_sprite_down_ram(13)(8)<="011";pacman_sprite_down_ram(13)(9)<="011";pacman_sprite_down_ram(13)(10)<="011";pacman_sprite_down_ram(13)(11)<="001";pacman_sprite_down_ram(13)(12)<="011";pacman_sprite_down_ram(13)(13)<="011";pacman_sprite_down_ram(13)(14)<="011";pacman_sprite_down_ram(13)(15)<="011";
	  pacman_sprite_down_ram(14)(0)<="110";pacman_sprite_down_ram(14)(1)<="011";pacman_sprite_down_ram(14)(2)<="011";pacman_sprite_down_ram(14)(3)<="011";pacman_sprite_down_ram(14)(4)<="011";pacman_sprite_down_ram(14)(5)<="011";pacman_sprite_down_ram(14)(6)<="011";pacman_sprite_down_ram(14)(7)<="011";pacman_sprite_down_ram(14)(8)<="011";pacman_sprite_down_ram(14)(9)<="011";pacman_sprite_down_ram(14)(10)<="011";pacman_sprite_down_ram(14)(11)<="001";pacman_sprite_down_ram(14)(12)<="011";pacman_sprite_down_ram(14)(13)<="011";pacman_sprite_down_ram(14)(14)<="011";pacman_sprite_down_ram(14)(15)<="011";
	  pacman_sprite_down_ram(15)(0)<="110";pacman_sprite_down_ram(15)(1)<="011";pacman_sprite_down_ram(15)(2)<="011";pacman_sprite_down_ram(15)(3)<="011";pacman_sprite_down_ram(15)(4)<="011";pacman_sprite_down_ram(15)(5)<="011";pacman_sprite_down_ram(15)(6)<="011";pacman_sprite_down_ram(15)(7)<="011";pacman_sprite_down_ram(15)(8)<="011";pacman_sprite_down_ram(15)(9)<="011";pacman_sprite_down_ram(15)(10)<="011";pacman_sprite_down_ram(15)(11)<="011";pacman_sprite_down_ram(15)(12)<="011";pacman_sprite_down_ram(15)(13)<="011";pacman_sprite_down_ram(15)(14)<="011";pacman_sprite_down_ram(15)(15)<="011";

      pacman_sprite_up_ram(0)(0)<="110";pacman_sprite_up_ram(0)(1)<="110";pacman_sprite_up_ram(0)(2)<="110";pacman_sprite_up_ram(0)(3)<="110";pacman_sprite_up_ram(0)(4)<="110";pacman_sprite_up_ram(0)(5)<="110";pacman_sprite_up_ram(0)(6)<="110";pacman_sprite_up_ram(0)(7)<="110";pacman_sprite_up_ram(0)(8)<="110";pacman_sprite_up_ram(0)(9)<="110";pacman_sprite_up_ram(0)(10)<="110";pacman_sprite_up_ram(0)(11)<="110";pacman_sprite_up_ram(0)(12)<="110";pacman_sprite_up_ram(0)(13)<="110";pacman_sprite_up_ram(0)(14)<="110";pacman_sprite_up_ram(0)(15)<="110";
	  pacman_sprite_up_ram(1)(0)<="110";pacman_sprite_up_ram(1)(1)<="011";pacman_sprite_up_ram(1)(2)<="011";pacman_sprite_up_ram(1)(3)<="011";pacman_sprite_up_ram(1)(4)<="011";pacman_sprite_up_ram(1)(5)<="011";pacman_sprite_up_ram(1)(6)<="011";pacman_sprite_up_ram(1)(7)<="011";pacman_sprite_up_ram(1)(8)<="001";pacman_sprite_up_ram(1)(9)<="011";pacman_sprite_up_ram(1)(10)<="011";pacman_sprite_up_ram(1)(11)<="011";pacman_sprite_up_ram(1)(12)<="011";pacman_sprite_up_ram(1)(13)<="011";pacman_sprite_up_ram(1)(14)<="011";pacman_sprite_up_ram(1)(15)<="011";
	  pacman_sprite_up_ram(2)(0)<="110";pacman_sprite_up_ram(2)(1)<="011";pacman_sprite_up_ram(2)(2)<="011";pacman_sprite_up_ram(2)(3)<="011";pacman_sprite_up_ram(2)(4)<="011";pacman_sprite_up_ram(2)(5)<="011";pacman_sprite_up_ram(2)(6)<="011";pacman_sprite_up_ram(2)(7)<="011";pacman_sprite_up_ram(2)(8)<="001";pacman_sprite_up_ram(2)(9)<="011";pacman_sprite_up_ram(2)(10)<="011";pacman_sprite_up_ram(2)(11)<="001";pacman_sprite_up_ram(2)(12)<="011";pacman_sprite_up_ram(2)(13)<="011";pacman_sprite_up_ram(2)(14)<="011";pacman_sprite_up_ram(2)(15)<="011";
	  pacman_sprite_up_ram(3)(0)<="110";pacman_sprite_up_ram(3)(1)<="011";pacman_sprite_up_ram(3)(2)<="011";pacman_sprite_up_ram(3)(3)<="001";pacman_sprite_up_ram(3)(4)<="001";pacman_sprite_up_ram(3)(5)<="011";pacman_sprite_up_ram(3)(6)<="011";pacman_sprite_up_ram(3)(7)<="011";pacman_sprite_up_ram(3)(8)<="001";pacman_sprite_up_ram(3)(9)<="011";pacman_sprite_up_ram(3)(10)<="001";pacman_sprite_up_ram(3)(11)<="001";pacman_sprite_up_ram(3)(12)<="001";pacman_sprite_up_ram(3)(13)<="011";pacman_sprite_up_ram(3)(14)<="011";pacman_sprite_up_ram(3)(15)<="011";
	  pacman_sprite_up_ram(4)(0)<="110";pacman_sprite_up_ram(4)(1)<="011";pacman_sprite_up_ram(4)(2)<="001";pacman_sprite_up_ram(4)(3)<="001";pacman_sprite_up_ram(4)(4)<="001";pacman_sprite_up_ram(4)(5)<="001";pacman_sprite_up_ram(4)(6)<="011";pacman_sprite_up_ram(4)(7)<="011";pacman_sprite_up_ram(4)(8)<="011";pacman_sprite_up_ram(4)(9)<="011";pacman_sprite_up_ram(4)(10)<="001";pacman_sprite_up_ram(4)(11)<="001";pacman_sprite_up_ram(4)(12)<="001";pacman_sprite_up_ram(4)(13)<="001";pacman_sprite_up_ram(4)(14)<="011";pacman_sprite_up_ram(4)(15)<="011";
	  pacman_sprite_up_ram(5)(0)<="110";pacman_sprite_up_ram(5)(1)<="001";pacman_sprite_up_ram(5)(2)<="001";pacman_sprite_up_ram(5)(3)<="001";pacman_sprite_up_ram(5)(4)<="001";pacman_sprite_up_ram(5)(5)<="001";pacman_sprite_up_ram(5)(6)<="011";pacman_sprite_up_ram(5)(7)<="011";pacman_sprite_up_ram(5)(8)<="011";pacman_sprite_up_ram(5)(9)<="001";pacman_sprite_up_ram(5)(10)<="001";pacman_sprite_up_ram(5)(11)<="001";pacman_sprite_up_ram(5)(12)<="001";pacman_sprite_up_ram(5)(13)<="001";pacman_sprite_up_ram(5)(14)<="001";pacman_sprite_up_ram(5)(15)<="011";
	  pacman_sprite_up_ram(6)(0)<="110";pacman_sprite_up_ram(6)(1)<="001";pacman_sprite_up_ram(6)(2)<="001";pacman_sprite_up_ram(6)(3)<="001";pacman_sprite_up_ram(6)(4)<="001";pacman_sprite_up_ram(6)(5)<="001";pacman_sprite_up_ram(6)(6)<="001";pacman_sprite_up_ram(6)(7)<="011";pacman_sprite_up_ram(6)(8)<="011";pacman_sprite_up_ram(6)(9)<="001";pacman_sprite_up_ram(6)(10)<="001";pacman_sprite_up_ram(6)(11)<="001";pacman_sprite_up_ram(6)(12)<="001";pacman_sprite_up_ram(6)(13)<="001";pacman_sprite_up_ram(6)(14)<="001";pacman_sprite_up_ram(6)(15)<="011";
	  pacman_sprite_up_ram(7)(0)<="110";pacman_sprite_up_ram(7)(1)<="001";pacman_sprite_up_ram(7)(2)<="001";pacman_sprite_up_ram(7)(3)<="001";pacman_sprite_up_ram(7)(4)<="001";pacman_sprite_up_ram(7)(5)<="001";pacman_sprite_up_ram(7)(6)<="001";pacman_sprite_up_ram(7)(7)<="011";pacman_sprite_up_ram(7)(8)<="001";pacman_sprite_up_ram(7)(9)<="001";pacman_sprite_up_ram(7)(10)<="001";pacman_sprite_up_ram(7)(11)<="001";pacman_sprite_up_ram(7)(12)<="001";pacman_sprite_up_ram(7)(13)<="001";pacman_sprite_up_ram(7)(14)<="001";pacman_sprite_up_ram(7)(15)<="011";
	  pacman_sprite_up_ram(8)(0)<="110";pacman_sprite_up_ram(8)(1)<="001";pacman_sprite_up_ram(8)(2)<="001";pacman_sprite_up_ram(8)(3)<="001";pacman_sprite_up_ram(8)(4)<="001";pacman_sprite_up_ram(8)(5)<="001";pacman_sprite_up_ram(8)(6)<="001";pacman_sprite_up_ram(8)(7)<="001";pacman_sprite_up_ram(8)(8)<="001";pacman_sprite_up_ram(8)(9)<="001";pacman_sprite_up_ram(8)(10)<="001";pacman_sprite_up_ram(8)(11)<="001";pacman_sprite_up_ram(8)(12)<="001";pacman_sprite_up_ram(8)(13)<="001";pacman_sprite_up_ram(8)(14)<="001";pacman_sprite_up_ram(8)(15)<="011";
	  pacman_sprite_up_ram(9)(0)<="110";pacman_sprite_up_ram(9)(1)<="001";pacman_sprite_up_ram(9)(2)<="001";pacman_sprite_up_ram(9)(3)<="001";pacman_sprite_up_ram(9)(4)<="001";pacman_sprite_up_ram(9)(5)<="001";pacman_sprite_up_ram(9)(6)<="001";pacman_sprite_up_ram(9)(7)<="001";pacman_sprite_up_ram(9)(8)<="001";pacman_sprite_up_ram(9)(9)<="001";pacman_sprite_up_ram(9)(10)<="001";pacman_sprite_up_ram(9)(11)<="001";pacman_sprite_up_ram(9)(12)<="001";pacman_sprite_up_ram(9)(13)<="001";pacman_sprite_up_ram(9)(14)<="001";pacman_sprite_up_ram(9)(15)<="011";
	  pacman_sprite_up_ram(10)(0)<="110";pacman_sprite_up_ram(10)(1)<="001";pacman_sprite_up_ram(10)(2)<="001";pacman_sprite_up_ram(10)(3)<="001";pacman_sprite_up_ram(10)(4)<="001";pacman_sprite_up_ram(10)(5)<="001";pacman_sprite_up_ram(10)(6)<="001";pacman_sprite_up_ram(10)(7)<="001";pacman_sprite_up_ram(10)(8)<="001";pacman_sprite_up_ram(10)(9)<="001";pacman_sprite_up_ram(10)(10)<="001";pacman_sprite_up_ram(10)(11)<="001";pacman_sprite_up_ram(10)(12)<="001";pacman_sprite_up_ram(10)(13)<="001";pacman_sprite_up_ram(10)(14)<="001";pacman_sprite_up_ram(10)(15)<="011";
	  pacman_sprite_up_ram(11)(0)<="110";pacman_sprite_up_ram(11)(1)<="011";pacman_sprite_up_ram(11)(2)<="001";pacman_sprite_up_ram(11)(3)<="001";pacman_sprite_up_ram(11)(4)<="001";pacman_sprite_up_ram(11)(5)<="001";pacman_sprite_up_ram(11)(6)<="001";pacman_sprite_up_ram(11)(7)<="001";pacman_sprite_up_ram(11)(8)<="001";pacman_sprite_up_ram(11)(9)<="001";pacman_sprite_up_ram(11)(10)<="001";pacman_sprite_up_ram(11)(11)<="001";pacman_sprite_up_ram(11)(12)<="001";pacman_sprite_up_ram(11)(13)<="001";pacman_sprite_up_ram(11)(14)<="011";pacman_sprite_up_ram(11)(15)<="011";
	  pacman_sprite_up_ram(12)(0)<="110";pacman_sprite_up_ram(12)(1)<="011";pacman_sprite_up_ram(12)(2)<="011";pacman_sprite_up_ram(12)(3)<="001";pacman_sprite_up_ram(12)(4)<="001";pacman_sprite_up_ram(12)(5)<="001";pacman_sprite_up_ram(12)(6)<="001";pacman_sprite_up_ram(12)(7)<="001";pacman_sprite_up_ram(12)(8)<="001";pacman_sprite_up_ram(12)(9)<="001";pacman_sprite_up_ram(12)(10)<="001";pacman_sprite_up_ram(12)(11)<="001";pacman_sprite_up_ram(12)(12)<="001";pacman_sprite_up_ram(12)(13)<="011";pacman_sprite_up_ram(12)(14)<="011";pacman_sprite_up_ram(12)(15)<="011";
	  pacman_sprite_up_ram(13)(0)<="110";pacman_sprite_up_ram(13)(1)<="011";pacman_sprite_up_ram(13)(2)<="011";pacman_sprite_up_ram(13)(3)<="011";pacman_sprite_up_ram(13)(4)<="001";pacman_sprite_up_ram(13)(5)<="001";pacman_sprite_up_ram(13)(6)<="001";pacman_sprite_up_ram(13)(7)<="001";pacman_sprite_up_ram(13)(8)<="001";pacman_sprite_up_ram(13)(9)<="001";pacman_sprite_up_ram(13)(10)<="001";pacman_sprite_up_ram(13)(11)<="001";pacman_sprite_up_ram(13)(12)<="011";pacman_sprite_up_ram(13)(13)<="011";pacman_sprite_up_ram(13)(14)<="011";pacman_sprite_up_ram(13)(15)<="011";
	  pacman_sprite_up_ram(14)(0)<="110";pacman_sprite_up_ram(14)(1)<="011";pacman_sprite_up_ram(14)(2)<="011";pacman_sprite_up_ram(14)(3)<="011";pacman_sprite_up_ram(14)(4)<="011";pacman_sprite_up_ram(14)(5)<="011";pacman_sprite_up_ram(14)(6)<="001";pacman_sprite_up_ram(14)(7)<="001";pacman_sprite_up_ram(14)(8)<="001";pacman_sprite_up_ram(14)(9)<="001";pacman_sprite_up_ram(14)(10)<="011";pacman_sprite_up_ram(14)(11)<="011";pacman_sprite_up_ram(14)(12)<="011";pacman_sprite_up_ram(14)(13)<="011";pacman_sprite_up_ram(14)(14)<="011";pacman_sprite_up_ram(14)(15)<="011";
	  pacman_sprite_up_ram(15)(0)<="110";pacman_sprite_up_ram(15)(1)<="011";pacman_sprite_up_ram(15)(2)<="011";pacman_sprite_up_ram(15)(3)<="011";pacman_sprite_up_ram(15)(4)<="011";pacman_sprite_up_ram(15)(5)<="011";pacman_sprite_up_ram(15)(6)<="011";pacman_sprite_up_ram(15)(7)<="011";pacman_sprite_up_ram(15)(8)<="011";pacman_sprite_up_ram(15)(9)<="011";pacman_sprite_up_ram(15)(10)<="011";pacman_sprite_up_ram(15)(11)<="011";pacman_sprite_up_ram(15)(12)<="011";pacman_sprite_up_ram(15)(13)<="011";pacman_sprite_up_ram(15)(14)<="011";pacman_sprite_up_ram(15)(15)<="011";

      pacman_sprite_left_ram(0)(0)<="110";pacman_sprite_left_ram(0)(1)<="110";pacman_sprite_left_ram(0)(2)<="110";pacman_sprite_left_ram(0)(3)<="110";pacman_sprite_left_ram(0)(4)<="110";pacman_sprite_left_ram(0)(5)<="110";pacman_sprite_left_ram(0)(6)<="110";pacman_sprite_left_ram(0)(7)<="110";pacman_sprite_left_ram(0)(8)<="110";pacman_sprite_left_ram(0)(9)<="110";pacman_sprite_left_ram(0)(10)<="110";pacman_sprite_left_ram(0)(11)<="110";pacman_sprite_left_ram(0)(12)<="110";pacman_sprite_left_ram(0)(13)<="110";pacman_sprite_left_ram(0)(14)<="110";pacman_sprite_left_ram(0)(15)<="110";
	  pacman_sprite_left_ram(1)(0)<="110";pacman_sprite_left_ram(1)(1)<="011";pacman_sprite_left_ram(1)(2)<="011";pacman_sprite_left_ram(1)(3)<="011";pacman_sprite_left_ram(1)(4)<="011";pacman_sprite_left_ram(1)(5)<="011";pacman_sprite_left_ram(1)(6)<="001";pacman_sprite_left_ram(1)(7)<="001";pacman_sprite_left_ram(1)(8)<="001";pacman_sprite_left_ram(1)(9)<="001";pacman_sprite_left_ram(1)(10)<="011";pacman_sprite_left_ram(1)(11)<="011";pacman_sprite_left_ram(1)(12)<="011";pacman_sprite_left_ram(1)(13)<="011";pacman_sprite_left_ram(1)(14)<="011";pacman_sprite_left_ram(1)(15)<="011";
	  pacman_sprite_left_ram(2)(0)<="110";pacman_sprite_left_ram(2)(1)<="011";pacman_sprite_left_ram(2)(2)<="011";pacman_sprite_left_ram(2)(3)<="011";pacman_sprite_left_ram(2)(4)<="001";pacman_sprite_left_ram(2)(5)<="001";pacman_sprite_left_ram(2)(6)<="001";pacman_sprite_left_ram(2)(7)<="001";pacman_sprite_left_ram(2)(8)<="001";pacman_sprite_left_ram(2)(9)<="001";pacman_sprite_left_ram(2)(10)<="001";pacman_sprite_left_ram(2)(11)<="001";pacman_sprite_left_ram(2)(12)<="011";pacman_sprite_left_ram(2)(13)<="011";pacman_sprite_left_ram(2)(14)<="011";pacman_sprite_left_ram(2)(15)<="011";
	  pacman_sprite_left_ram(3)(0)<="110";pacman_sprite_left_ram(3)(1)<="011";pacman_sprite_left_ram(3)(2)<="011";pacman_sprite_left_ram(3)(3)<="001";pacman_sprite_left_ram(3)(4)<="001";pacman_sprite_left_ram(3)(5)<="001";pacman_sprite_left_ram(3)(6)<="001";pacman_sprite_left_ram(3)(7)<="001";pacman_sprite_left_ram(3)(8)<="001";pacman_sprite_left_ram(3)(9)<="001";pacman_sprite_left_ram(3)(10)<="001";pacman_sprite_left_ram(3)(11)<="001";pacman_sprite_left_ram(3)(12)<="001";pacman_sprite_left_ram(3)(13)<="011";pacman_sprite_left_ram(3)(14)<="011";pacman_sprite_left_ram(3)(15)<="011";
	  pacman_sprite_left_ram(4)(0)<="110";pacman_sprite_left_ram(4)(1)<="011";pacman_sprite_left_ram(4)(2)<="011";pacman_sprite_left_ram(4)(3)<="011";pacman_sprite_left_ram(4)(4)<="001";pacman_sprite_left_ram(4)(5)<="001";pacman_sprite_left_ram(4)(6)<="001";pacman_sprite_left_ram(4)(7)<="001";pacman_sprite_left_ram(4)(8)<="001";pacman_sprite_left_ram(4)(9)<="001";pacman_sprite_left_ram(4)(10)<="001";pacman_sprite_left_ram(4)(11)<="001";pacman_sprite_left_ram(4)(12)<="001";pacman_sprite_left_ram(4)(13)<="001";pacman_sprite_left_ram(4)(14)<="011";pacman_sprite_left_ram(4)(15)<="011";
	  pacman_sprite_left_ram(5)(0)<="110";pacman_sprite_left_ram(5)(1)<="011";pacman_sprite_left_ram(5)(2)<="011";pacman_sprite_left_ram(5)(3)<="011";pacman_sprite_left_ram(5)(4)<="011";pacman_sprite_left_ram(5)(5)<="011";pacman_sprite_left_ram(5)(6)<="001";pacman_sprite_left_ram(5)(7)<="001";pacman_sprite_left_ram(5)(8)<="001";pacman_sprite_left_ram(5)(9)<="001";pacman_sprite_left_ram(5)(10)<="001";pacman_sprite_left_ram(5)(11)<="001";pacman_sprite_left_ram(5)(12)<="001";pacman_sprite_left_ram(5)(13)<="001";pacman_sprite_left_ram(5)(14)<="001";pacman_sprite_left_ram(5)(15)<="011";
	  pacman_sprite_left_ram(6)(0)<="110";pacman_sprite_left_ram(6)(1)<="011";pacman_sprite_left_ram(6)(2)<="011";pacman_sprite_left_ram(6)(3)<="011";pacman_sprite_left_ram(6)(4)<="011";pacman_sprite_left_ram(6)(5)<="011";pacman_sprite_left_ram(6)(6)<="011";pacman_sprite_left_ram(6)(7)<="011";pacman_sprite_left_ram(6)(8)<="001";pacman_sprite_left_ram(6)(9)<="001";pacman_sprite_left_ram(6)(10)<="001";pacman_sprite_left_ram(6)(11)<="001";pacman_sprite_left_ram(6)(12)<="001";pacman_sprite_left_ram(6)(13)<="001";pacman_sprite_left_ram(6)(14)<="001";pacman_sprite_left_ram(6)(15)<="011";
	  pacman_sprite_left_ram(7)(0)<="110";pacman_sprite_left_ram(7)(1)<="011";pacman_sprite_left_ram(7)(2)<="011";pacman_sprite_left_ram(7)(3)<="011";pacman_sprite_left_ram(7)(4)<="011";pacman_sprite_left_ram(7)(5)<="011";pacman_sprite_left_ram(7)(6)<="011";pacman_sprite_left_ram(7)(7)<="011";pacman_sprite_left_ram(7)(8)<="001";pacman_sprite_left_ram(7)(9)<="001";pacman_sprite_left_ram(7)(10)<="001";pacman_sprite_left_ram(7)(11)<="001";pacman_sprite_left_ram(7)(12)<="001";pacman_sprite_left_ram(7)(13)<="001";pacman_sprite_left_ram(7)(14)<="001";pacman_sprite_left_ram(7)(15)<="011";
	  pacman_sprite_left_ram(8)(0)<="110";pacman_sprite_left_ram(8)(1)<="011";pacman_sprite_left_ram(8)(2)<="011";pacman_sprite_left_ram(8)(3)<="011";pacman_sprite_left_ram(8)(4)<="011";pacman_sprite_left_ram(8)(5)<="011";pacman_sprite_left_ram(8)(6)<="011";pacman_sprite_left_ram(8)(7)<="001";pacman_sprite_left_ram(8)(8)<="001";pacman_sprite_left_ram(8)(9)<="001";pacman_sprite_left_ram(8)(10)<="001";pacman_sprite_left_ram(8)(11)<="001";pacman_sprite_left_ram(8)(12)<="001";pacman_sprite_left_ram(8)(13)<="001";pacman_sprite_left_ram(8)(14)<="001";pacman_sprite_left_ram(8)(15)<="011";
	  pacman_sprite_left_ram(9)(0)<="110";pacman_sprite_left_ram(9)(1)<="011";pacman_sprite_left_ram(9)(2)<="011";pacman_sprite_left_ram(9)(3)<="011";pacman_sprite_left_ram(9)(4)<="011";pacman_sprite_left_ram(9)(5)<="001";pacman_sprite_left_ram(9)(6)<="001";pacman_sprite_left_ram(9)(7)<="001";pacman_sprite_left_ram(9)(8)<="001";pacman_sprite_left_ram(9)(9)<="001";pacman_sprite_left_ram(9)(10)<="001";pacman_sprite_left_ram(9)(11)<="001";pacman_sprite_left_ram(9)(12)<="001";pacman_sprite_left_ram(9)(13)<="001";pacman_sprite_left_ram(9)(14)<="001";pacman_sprite_left_ram(9)(15)<="011";
	  pacman_sprite_left_ram(10)(0)<="110";pacman_sprite_left_ram(10)(1)<="011";pacman_sprite_left_ram(10)(2)<="011";pacman_sprite_left_ram(10)(3)<="001";pacman_sprite_left_ram(10)(4)<="001";pacman_sprite_left_ram(10)(5)<="001";pacman_sprite_left_ram(10)(6)<="001";pacman_sprite_left_ram(10)(7)<="001";pacman_sprite_left_ram(10)(8)<="001";pacman_sprite_left_ram(10)(9)<="001";pacman_sprite_left_ram(10)(10)<="001";pacman_sprite_left_ram(10)(11)<="001";pacman_sprite_left_ram(10)(12)<="001";pacman_sprite_left_ram(10)(13)<="001";pacman_sprite_left_ram(10)(14)<="001";pacman_sprite_left_ram(10)(15)<="011";
	  pacman_sprite_left_ram(11)(0)<="110";pacman_sprite_left_ram(11)(1)<="011";pacman_sprite_left_ram(11)(2)<="001";pacman_sprite_left_ram(11)(3)<="001";pacman_sprite_left_ram(11)(4)<="001";pacman_sprite_left_ram(11)(5)<="001";pacman_sprite_left_ram(11)(6)<="001";pacman_sprite_left_ram(11)(7)<="001";pacman_sprite_left_ram(11)(8)<="001";pacman_sprite_left_ram(11)(9)<="001";pacman_sprite_left_ram(11)(10)<="001";pacman_sprite_left_ram(11)(11)<="001";pacman_sprite_left_ram(11)(12)<="001";pacman_sprite_left_ram(11)(13)<="001";pacman_sprite_left_ram(11)(14)<="011";pacman_sprite_left_ram(11)(15)<="011";
	  pacman_sprite_left_ram(12)(0)<="110";pacman_sprite_left_ram(12)(1)<="011";pacman_sprite_left_ram(12)(2)<="011";pacman_sprite_left_ram(12)(3)<="001";pacman_sprite_left_ram(12)(4)<="001";pacman_sprite_left_ram(12)(5)<="001";pacman_sprite_left_ram(12)(6)<="001";pacman_sprite_left_ram(12)(7)<="001";pacman_sprite_left_ram(12)(8)<="001";pacman_sprite_left_ram(12)(9)<="001";pacman_sprite_left_ram(12)(10)<="001";pacman_sprite_left_ram(12)(11)<="001";pacman_sprite_left_ram(12)(12)<="001";pacman_sprite_left_ram(12)(13)<="011";pacman_sprite_left_ram(12)(14)<="011";pacman_sprite_left_ram(12)(15)<="011";
	  pacman_sprite_left_ram(13)(0)<="110";pacman_sprite_left_ram(13)(1)<="011";pacman_sprite_left_ram(13)(2)<="011";pacman_sprite_left_ram(13)(3)<="011";pacman_sprite_left_ram(13)(4)<="001";pacman_sprite_left_ram(13)(5)<="001";pacman_sprite_left_ram(13)(6)<="001";pacman_sprite_left_ram(13)(7)<="001";pacman_sprite_left_ram(13)(8)<="001";pacman_sprite_left_ram(13)(9)<="001";pacman_sprite_left_ram(13)(10)<="001";pacman_sprite_left_ram(13)(11)<="001";pacman_sprite_left_ram(13)(12)<="011";pacman_sprite_left_ram(13)(13)<="011";pacman_sprite_left_ram(13)(14)<="011";pacman_sprite_left_ram(13)(15)<="011";
	  pacman_sprite_left_ram(14)(0)<="110";pacman_sprite_left_ram(14)(1)<="011";pacman_sprite_left_ram(14)(2)<="011";pacman_sprite_left_ram(14)(3)<="011";pacman_sprite_left_ram(14)(4)<="011";pacman_sprite_left_ram(14)(5)<="011";pacman_sprite_left_ram(14)(6)<="001";pacman_sprite_left_ram(14)(7)<="001";pacman_sprite_left_ram(14)(8)<="001";pacman_sprite_left_ram(14)(9)<="001";pacman_sprite_left_ram(14)(10)<="011";pacman_sprite_left_ram(14)(11)<="011";pacman_sprite_left_ram(14)(12)<="011";pacman_sprite_left_ram(14)(13)<="011";pacman_sprite_left_ram(14)(14)<="011";pacman_sprite_left_ram(14)(15)<="011";
	  pacman_sprite_left_ram(15)(0)<="110";pacman_sprite_left_ram(15)(1)<="011";pacman_sprite_left_ram(15)(2)<="011";pacman_sprite_left_ram(15)(3)<="011";pacman_sprite_left_ram(15)(4)<="011";pacman_sprite_left_ram(15)(5)<="011";pacman_sprite_left_ram(15)(6)<="011";pacman_sprite_left_ram(15)(7)<="011";pacman_sprite_left_ram(15)(8)<="011";pacman_sprite_left_ram(15)(9)<="011";pacman_sprite_left_ram(15)(10)<="011";pacman_sprite_left_ram(15)(11)<="011";pacman_sprite_left_ram(15)(12)<="011";pacman_sprite_left_ram(15)(13)<="011";pacman_sprite_left_ram(15)(14)<="011";pacman_sprite_left_ram(15)(15)<="011";

      ghost_sprite_1_ram(0)(0)<="000";ghost_sprite_1_ram(0)(1)<="000";ghost_sprite_1_ram(0)(2)<="000";ghost_sprite_1_ram(0)(3)<="000";ghost_sprite_1_ram(0)(4)<="000";ghost_sprite_1_ram(0)(5)<="100";ghost_sprite_1_ram(0)(6)<="100";ghost_sprite_1_ram(0)(7)<="100";ghost_sprite_1_ram(0)(8)<="100";ghost_sprite_1_ram(0)(9)<="100";ghost_sprite_1_ram(0)(10)<="100";ghost_sprite_1_ram(0)(11)<="000";ghost_sprite_1_ram(0)(12)<="000";ghost_sprite_1_ram(0)(13)<="000";ghost_sprite_1_ram(0)(14)<="000";ghost_sprite_1_ram(0)(15)<="000";
	  ghost_sprite_1_ram(1)(0)<="000";ghost_sprite_1_ram(1)(1)<="000";ghost_sprite_1_ram(1)(2)<="000";ghost_sprite_1_ram(1)(3)<="000";ghost_sprite_1_ram(1)(4)<="100";ghost_sprite_1_ram(1)(5)<="100";ghost_sprite_1_ram(1)(6)<="100";ghost_sprite_1_ram(1)(7)<="100";ghost_sprite_1_ram(1)(8)<="100";ghost_sprite_1_ram(1)(9)<="100";ghost_sprite_1_ram(1)(10)<="100";ghost_sprite_1_ram(1)(11)<="100";ghost_sprite_1_ram(1)(12)<="000";ghost_sprite_1_ram(1)(13)<="000";ghost_sprite_1_ram(1)(14)<="000";ghost_sprite_1_ram(1)(15)<="000";
	  ghost_sprite_1_ram(2)(0)<="000";ghost_sprite_1_ram(2)(1)<="000";ghost_sprite_1_ram(2)(2)<="000";ghost_sprite_1_ram(2)(3)<="100";ghost_sprite_1_ram(2)(4)<="100";ghost_sprite_1_ram(2)(5)<="100";ghost_sprite_1_ram(2)(6)<="100";ghost_sprite_1_ram(2)(7)<="100";ghost_sprite_1_ram(2)(8)<="100";ghost_sprite_1_ram(2)(9)<="100";ghost_sprite_1_ram(2)(10)<="100";ghost_sprite_1_ram(2)(11)<="100";ghost_sprite_1_ram(2)(12)<="100";ghost_sprite_1_ram(2)(13)<="000";ghost_sprite_1_ram(2)(14)<="000";ghost_sprite_1_ram(2)(15)<="000";
	  ghost_sprite_1_ram(3)(0)<="000";ghost_sprite_1_ram(3)(1)<="000";ghost_sprite_1_ram(3)(2)<="100";ghost_sprite_1_ram(3)(3)<="100";ghost_sprite_1_ram(3)(4)<="100";ghost_sprite_1_ram(3)(5)<="100";ghost_sprite_1_ram(3)(6)<="100";ghost_sprite_1_ram(3)(7)<="100";ghost_sprite_1_ram(3)(8)<="100";ghost_sprite_1_ram(3)(9)<="100";ghost_sprite_1_ram(3)(10)<="100";ghost_sprite_1_ram(3)(11)<="100";ghost_sprite_1_ram(3)(12)<="100";ghost_sprite_1_ram(3)(13)<="100";ghost_sprite_1_ram(3)(14)<="000";ghost_sprite_1_ram(3)(15)<="000";
	  ghost_sprite_1_ram(4)(0)<="000";ghost_sprite_1_ram(4)(1)<="100";ghost_sprite_1_ram(4)(2)<="110";ghost_sprite_1_ram(4)(3)<="110";ghost_sprite_1_ram(4)(4)<="100";ghost_sprite_1_ram(4)(5)<="100";ghost_sprite_1_ram(4)(6)<="100";ghost_sprite_1_ram(4)(7)<="100";ghost_sprite_1_ram(4)(8)<="100";ghost_sprite_1_ram(4)(9)<="110";ghost_sprite_1_ram(4)(10)<="110";ghost_sprite_1_ram(4)(11)<="110";ghost_sprite_1_ram(4)(12)<="100";ghost_sprite_1_ram(4)(13)<="100";ghost_sprite_1_ram(4)(14)<="100";ghost_sprite_1_ram(4)(15)<="000";
	  ghost_sprite_1_ram(5)(0)<="110";ghost_sprite_1_ram(5)(1)<="110";ghost_sprite_1_ram(5)(2)<="110";ghost_sprite_1_ram(5)(3)<="110";ghost_sprite_1_ram(5)(4)<="110";ghost_sprite_1_ram(5)(5)<="100";ghost_sprite_1_ram(5)(6)<="100";ghost_sprite_1_ram(5)(7)<="100";ghost_sprite_1_ram(5)(8)<="110";ghost_sprite_1_ram(5)(9)<="110";ghost_sprite_1_ram(5)(10)<="110";ghost_sprite_1_ram(5)(11)<="110";ghost_sprite_1_ram(5)(12)<="110";ghost_sprite_1_ram(5)(13)<="100";ghost_sprite_1_ram(5)(14)<="100";ghost_sprite_1_ram(5)(15)<="000";
	  ghost_sprite_1_ram(6)(0)<="110";ghost_sprite_1_ram(6)(1)<="110";ghost_sprite_1_ram(6)(2)<="000";ghost_sprite_1_ram(6)(3)<="110";ghost_sprite_1_ram(6)(4)<="110";ghost_sprite_1_ram(6)(5)<="100";ghost_sprite_1_ram(6)(6)<="100";ghost_sprite_1_ram(6)(7)<="100";ghost_sprite_1_ram(6)(8)<="110";ghost_sprite_1_ram(6)(9)<="110";ghost_sprite_1_ram(6)(10)<="000";ghost_sprite_1_ram(6)(11)<="110";ghost_sprite_1_ram(6)(12)<="110";ghost_sprite_1_ram(6)(13)<="100";ghost_sprite_1_ram(6)(14)<="100";ghost_sprite_1_ram(6)(15)<="000";
	  ghost_sprite_1_ram(7)(0)<="110";ghost_sprite_1_ram(7)(1)<="000";ghost_sprite_1_ram(7)(2)<="000";ghost_sprite_1_ram(7)(3)<="000";ghost_sprite_1_ram(7)(4)<="110";ghost_sprite_1_ram(7)(5)<="100";ghost_sprite_1_ram(7)(6)<="100";ghost_sprite_1_ram(7)(7)<="100";ghost_sprite_1_ram(7)(8)<="110";ghost_sprite_1_ram(7)(9)<="000";ghost_sprite_1_ram(7)(10)<="000";ghost_sprite_1_ram(7)(11)<="000";ghost_sprite_1_ram(7)(12)<="110";ghost_sprite_1_ram(7)(13)<="100";ghost_sprite_1_ram(7)(14)<="100";ghost_sprite_1_ram(7)(15)<="000";
	  ghost_sprite_1_ram(8)(0)<="000";ghost_sprite_1_ram(8)(1)<="000";ghost_sprite_1_ram(8)(2)<="000";ghost_sprite_1_ram(8)(3)<="000";ghost_sprite_1_ram(8)(4)<="100";ghost_sprite_1_ram(8)(5)<="100";ghost_sprite_1_ram(8)(6)<="100";ghost_sprite_1_ram(8)(7)<="100";ghost_sprite_1_ram(8)(8)<="100";ghost_sprite_1_ram(8)(9)<="000";ghost_sprite_1_ram(8)(10)<="000";ghost_sprite_1_ram(8)(11)<="000";ghost_sprite_1_ram(8)(12)<="100";ghost_sprite_1_ram(8)(13)<="100";ghost_sprite_1_ram(8)(14)<="100";ghost_sprite_1_ram(8)(15)<="000";
	  ghost_sprite_1_ram(9)(0)<="000";ghost_sprite_1_ram(9)(1)<="100";ghost_sprite_1_ram(9)(2)<="000";ghost_sprite_1_ram(9)(3)<="100";ghost_sprite_1_ram(9)(4)<="100";ghost_sprite_1_ram(9)(5)<="100";ghost_sprite_1_ram(9)(6)<="100";ghost_sprite_1_ram(9)(7)<="100";ghost_sprite_1_ram(9)(8)<="100";ghost_sprite_1_ram(9)(9)<="100";ghost_sprite_1_ram(9)(10)<="000";ghost_sprite_1_ram(9)(11)<="100";ghost_sprite_1_ram(9)(12)<="100";ghost_sprite_1_ram(9)(13)<="100";ghost_sprite_1_ram(9)(14)<="100";ghost_sprite_1_ram(9)(15)<="000";
	  ghost_sprite_1_ram(10)(0)<="000";ghost_sprite_1_ram(10)(1)<="100";ghost_sprite_1_ram(10)(2)<="100";ghost_sprite_1_ram(10)(3)<="100";ghost_sprite_1_ram(10)(4)<="100";ghost_sprite_1_ram(10)(5)<="100";ghost_sprite_1_ram(10)(6)<="100";ghost_sprite_1_ram(10)(7)<="100";ghost_sprite_1_ram(10)(8)<="100";ghost_sprite_1_ram(10)(9)<="100";ghost_sprite_1_ram(10)(10)<="100";ghost_sprite_1_ram(10)(11)<="100";ghost_sprite_1_ram(10)(12)<="100";ghost_sprite_1_ram(10)(13)<="100";ghost_sprite_1_ram(10)(14)<="100";ghost_sprite_1_ram(10)(15)<="000";
	  ghost_sprite_1_ram(11)(0)<="000";ghost_sprite_1_ram(11)(1)<="100";ghost_sprite_1_ram(11)(2)<="100";ghost_sprite_1_ram(11)(3)<="100";ghost_sprite_1_ram(11)(4)<="100";ghost_sprite_1_ram(11)(5)<="100";ghost_sprite_1_ram(11)(6)<="100";ghost_sprite_1_ram(11)(7)<="100";ghost_sprite_1_ram(11)(8)<="100";ghost_sprite_1_ram(11)(9)<="100";ghost_sprite_1_ram(11)(10)<="100";ghost_sprite_1_ram(11)(11)<="100";ghost_sprite_1_ram(11)(12)<="100";ghost_sprite_1_ram(11)(13)<="100";ghost_sprite_1_ram(11)(14)<="100";ghost_sprite_1_ram(11)(15)<="000";
	  ghost_sprite_1_ram(12)(0)<="000";ghost_sprite_1_ram(12)(1)<="100";ghost_sprite_1_ram(12)(2)<="100";ghost_sprite_1_ram(12)(3)<="100";ghost_sprite_1_ram(12)(4)<="100";ghost_sprite_1_ram(12)(5)<="100";ghost_sprite_1_ram(12)(6)<="100";ghost_sprite_1_ram(12)(7)<="100";ghost_sprite_1_ram(12)(8)<="100";ghost_sprite_1_ram(12)(9)<="100";ghost_sprite_1_ram(12)(10)<="100";ghost_sprite_1_ram(12)(11)<="100";ghost_sprite_1_ram(12)(12)<="100";ghost_sprite_1_ram(12)(13)<="100";ghost_sprite_1_ram(12)(14)<="100";ghost_sprite_1_ram(12)(15)<="000";
	  ghost_sprite_1_ram(13)(0)<="000";ghost_sprite_1_ram(13)(1)<="100";ghost_sprite_1_ram(13)(2)<="100";ghost_sprite_1_ram(13)(3)<="100";ghost_sprite_1_ram(13)(4)<="100";ghost_sprite_1_ram(13)(5)<="100";ghost_sprite_1_ram(13)(6)<="100";ghost_sprite_1_ram(13)(7)<="100";ghost_sprite_1_ram(13)(8)<="100";ghost_sprite_1_ram(13)(9)<="100";ghost_sprite_1_ram(13)(10)<="100";ghost_sprite_1_ram(13)(11)<="100";ghost_sprite_1_ram(13)(12)<="100";ghost_sprite_1_ram(13)(13)<="100";ghost_sprite_1_ram(13)(14)<="100";ghost_sprite_1_ram(13)(15)<="000";
	  ghost_sprite_1_ram(14)(0)<="000";ghost_sprite_1_ram(14)(1)<="100";ghost_sprite_1_ram(14)(2)<="100";ghost_sprite_1_ram(14)(3)<="100";ghost_sprite_1_ram(14)(4)<="000";ghost_sprite_1_ram(14)(5)<="100";ghost_sprite_1_ram(14)(6)<="100";ghost_sprite_1_ram(14)(7)<="100";ghost_sprite_1_ram(14)(8)<="000";ghost_sprite_1_ram(14)(9)<="100";ghost_sprite_1_ram(14)(10)<="100";ghost_sprite_1_ram(14)(11)<="100";ghost_sprite_1_ram(14)(12)<="000";ghost_sprite_1_ram(14)(13)<="100";ghost_sprite_1_ram(14)(14)<="100";ghost_sprite_1_ram(14)(15)<="000";	  
	--ghost_sprite_1_ram(15)(0)<="000";ghost_sprite_1_ram(15)(1)<="000";ghost_sprite_1_ram(15)(2)<="000";ghost_sprite_1_ram(15)(3)<="000";ghost_sprite_1_ram(15)(4)<="000";ghost_sprite_1_ram(15)(5)<="000";ghost_sprite_1_ram(15)(6)<="000";ghost_sprite_1_ram(15)(7)<="000";ghost_sprite_1_ram(15)(8)<="000";ghost_sprite_1_ram(15)(9)<="000";ghost_sprite_1_ram(15)(10)<="000";ghost_sprite_1_ram(15)(11)<="000";ghost_sprite_1_ram(15)(12)<="000";ghost_sprite_1_ram(15)(13)<="000";ghost_sprite_1_ram(15)(14)<="000";ghost_sprite_1_ram(15)(15)<="000";
      ghost_sprite_1_ram(15)(0)<="100";ghost_sprite_1_ram(15)(1)<="100";ghost_sprite_1_ram(15)(2)<="000";ghost_sprite_1_ram(15)(3)<="000";ghost_sprite_1_ram(15)(4)<="000";ghost_sprite_1_ram(15)(5)<="100";ghost_sprite_1_ram(15)(6)<="000";ghost_sprite_1_ram(15)(7)<="000";ghost_sprite_1_ram(15)(8)<="000";ghost_sprite_1_ram(15)(9)<="100";ghost_sprite_1_ram(15)(10)<="000";ghost_sprite_1_ram(15)(11)<="000";ghost_sprite_1_ram(15)(12)<="100";ghost_sprite_1_ram(15)(13)<="100";ghost_sprite_1_ram(15)(14)<="000";ghost_sprite_1_ram(15)(15)<="000";

--      ghost_sprite_2_ram(0)(0)<="000";ghost_sprite_2_ram(0)(1)<="000";ghost_sprite_2_ram(0)(2)<="000";ghost_sprite_2_ram(0)(3)<="000";ghost_sprite_2_ram(0)(4)<="000";ghost_sprite_2_ram(0)(5)<="100";ghost_sprite_2_ram(0)(6)<="100";ghost_sprite_2_ram(0)(7)<="100";ghost_sprite_2_ram(0)(8)<="100";ghost_sprite_2_ram(0)(9)<="100";ghost_sprite_2_ram(0)(10)<="100";ghost_sprite_2_ram(0)(11)<="000";ghost_sprite_2_ram(0)(12)<="000";ghost_sprite_2_ram(0)(13)<="000";ghost_sprite_2_ram(0)(14)<="000";ghost_sprite_2_ram(0)(15)<="000";
--	  ghost_sprite_2_ram(1)(0)<="000";ghost_sprite_2_ram(1)(1)<="000";ghost_sprite_2_ram(1)(2)<="000";ghost_sprite_2_ram(1)(3)<="000";ghost_sprite_2_ram(1)(4)<="100";ghost_sprite_2_ram(1)(5)<="100";ghost_sprite_2_ram(1)(6)<="100";ghost_sprite_2_ram(1)(7)<="100";ghost_sprite_2_ram(1)(8)<="100";ghost_sprite_2_ram(1)(9)<="100";ghost_sprite_2_ram(1)(10)<="100";ghost_sprite_2_ram(1)(11)<="100";ghost_sprite_2_ram(1)(12)<="011";ghost_sprite_2_ram(1)(13)<="000";ghost_sprite_2_ram(1)(14)<="000";ghost_sprite_2_ram(1)(15)<="000";
--	  ghost_sprite_2_ram(2)(0)<="000";ghost_sprite_2_ram(2)(1)<="000";ghost_sprite_2_ram(2)(2)<="000";ghost_sprite_2_ram(2)(3)<="100";ghost_sprite_2_ram(2)(4)<="100";ghost_sprite_2_ram(2)(5)<="100";ghost_sprite_2_ram(2)(6)<="100";ghost_sprite_2_ram(2)(7)<="100";ghost_sprite_2_ram(2)(8)<="100";ghost_sprite_2_ram(2)(9)<="100";ghost_sprite_2_ram(2)(10)<="100";ghost_sprite_2_ram(2)(11)<="100";ghost_sprite_2_ram(2)(12)<="100";ghost_sprite_2_ram(2)(13)<="000";ghost_sprite_2_ram(2)(14)<="000";ghost_sprite_2_ram(2)(15)<="000";
--	  ghost_sprite_2_ram(3)(0)<="000";ghost_sprite_2_ram(3)(1)<="000";ghost_sprite_2_ram(3)(2)<="100";ghost_sprite_2_ram(3)(3)<="100";ghost_sprite_2_ram(3)(4)<="100";ghost_sprite_2_ram(3)(5)<="100";ghost_sprite_2_ram(3)(6)<="100";ghost_sprite_2_ram(3)(7)<="100";ghost_sprite_2_ram(3)(8)<="100";ghost_sprite_2_ram(3)(9)<="100";ghost_sprite_2_ram(3)(10)<="100";ghost_sprite_2_ram(3)(11)<="100";ghost_sprite_2_ram(3)(12)<="100";ghost_sprite_2_ram(3)(13)<="100";ghost_sprite_2_ram(3)(14)<="000";ghost_sprite_2_ram(3)(15)<="000";
--	  ghost_sprite_2_ram(4)(0)<="000";ghost_sprite_2_ram(4)(1)<="100";ghost_sprite_2_ram(4)(2)<="110";ghost_sprite_2_ram(4)(3)<="110";ghost_sprite_2_ram(4)(4)<="100";ghost_sprite_2_ram(4)(5)<="100";ghost_sprite_2_ram(4)(6)<="100";ghost_sprite_2_ram(4)(7)<="100";ghost_sprite_2_ram(4)(8)<="100";ghost_sprite_2_ram(4)(9)<="110";ghost_sprite_2_ram(4)(10)<="110";ghost_sprite_2_ram(4)(11)<="110";ghost_sprite_2_ram(4)(12)<="100";ghost_sprite_2_ram(4)(13)<="100";ghost_sprite_2_ram(4)(14)<="100";ghost_sprite_2_ram(4)(15)<="000";
--	  ghost_sprite_2_ram(5)(0)<="110";ghost_sprite_2_ram(5)(1)<="110";ghost_sprite_2_ram(5)(2)<="110";ghost_sprite_2_ram(5)(3)<="110";ghost_sprite_2_ram(5)(4)<="110";ghost_sprite_2_ram(5)(5)<="100";ghost_sprite_2_ram(5)(6)<="100";ghost_sprite_2_ram(5)(7)<="100";ghost_sprite_2_ram(5)(8)<="110";ghost_sprite_2_ram(5)(9)<="110";ghost_sprite_2_ram(5)(10)<="110";ghost_sprite_2_ram(5)(11)<="110";ghost_sprite_2_ram(5)(12)<="110";ghost_sprite_2_ram(5)(13)<="100";ghost_sprite_2_ram(5)(14)<="100";ghost_sprite_2_ram(5)(15)<="000";
--	  ghost_sprite_2_ram(6)(0)<="110";ghost_sprite_2_ram(6)(1)<="110";ghost_sprite_2_ram(6)(2)<="000";ghost_sprite_2_ram(6)(3)<="110";ghost_sprite_2_ram(6)(4)<="110";ghost_sprite_2_ram(6)(5)<="100";ghost_sprite_2_ram(6)(6)<="100";ghost_sprite_2_ram(6)(7)<="100";ghost_sprite_2_ram(6)(8)<="110";ghost_sprite_2_ram(6)(9)<="110";ghost_sprite_2_ram(6)(10)<="000";ghost_sprite_2_ram(6)(11)<="110";ghost_sprite_2_ram(6)(12)<="110";ghost_sprite_2_ram(6)(13)<="100";ghost_sprite_2_ram(6)(14)<="100";ghost_sprite_2_ram(6)(15)<="000";
--	  ghost_sprite_2_ram(7)(0)<="110";ghost_sprite_2_ram(7)(1)<="000";ghost_sprite_2_ram(7)(2)<="000";ghost_sprite_2_ram(7)(3)<="000";ghost_sprite_2_ram(7)(4)<="110";ghost_sprite_2_ram(7)(5)<="100";ghost_sprite_2_ram(7)(6)<="100";ghost_sprite_2_ram(7)(7)<="100";ghost_sprite_2_ram(7)(8)<="110";ghost_sprite_2_ram(7)(9)<="000";ghost_sprite_2_ram(7)(10)<="000";ghost_sprite_2_ram(7)(11)<="000";ghost_sprite_2_ram(7)(12)<="110";ghost_sprite_2_ram(7)(13)<="100";ghost_sprite_2_ram(7)(14)<="100";ghost_sprite_2_ram(7)(15)<="000";
--	  ghost_sprite_2_ram(8)(0)<="000";ghost_sprite_2_ram(8)(1)<="000";ghost_sprite_2_ram(8)(2)<="000";ghost_sprite_2_ram(8)(3)<="000";ghost_sprite_2_ram(8)(4)<="100";ghost_sprite_2_ram(8)(5)<="100";ghost_sprite_2_ram(8)(6)<="100";ghost_sprite_2_ram(8)(7)<="100";ghost_sprite_2_ram(8)(8)<="100";ghost_sprite_2_ram(8)(9)<="000";ghost_sprite_2_ram(8)(10)<="000";ghost_sprite_2_ram(8)(11)<="000";ghost_sprite_2_ram(8)(12)<="100";ghost_sprite_2_ram(8)(13)<="100";ghost_sprite_2_ram(8)(14)<="100";ghost_sprite_2_ram(8)(15)<="000";
--	  ghost_sprite_2_ram(9)(0)<="000";ghost_sprite_2_ram(9)(1)<="100";ghost_sprite_2_ram(9)(2)<="000";ghost_sprite_2_ram(9)(3)<="100";ghost_sprite_2_ram(9)(4)<="100";ghost_sprite_2_ram(9)(5)<="100";ghost_sprite_2_ram(9)(6)<="100";ghost_sprite_2_ram(9)(7)<="100";ghost_sprite_2_ram(9)(8)<="100";ghost_sprite_2_ram(9)(9)<="100";ghost_sprite_2_ram(9)(10)<="000";ghost_sprite_2_ram(9)(11)<="100";ghost_sprite_2_ram(9)(12)<="100";ghost_sprite_2_ram(9)(13)<="100";ghost_sprite_2_ram(9)(14)<="100";ghost_sprite_2_ram(9)(15)<="000";
--	  ghost_sprite_2_ram(10)(0)<="000";ghost_sprite_2_ram(10)(1)<="100";ghost_sprite_2_ram(10)(2)<="100";ghost_sprite_2_ram(10)(3)<="100";ghost_sprite_2_ram(10)(4)<="100";ghost_sprite_2_ram(10)(5)<="100";ghost_sprite_2_ram(10)(6)<="100";ghost_sprite_2_ram(10)(7)<="100";ghost_sprite_2_ram(10)(8)<="100";ghost_sprite_2_ram(10)(9)<="100";ghost_sprite_2_ram(10)(10)<="100";ghost_sprite_2_ram(10)(11)<="100";ghost_sprite_2_ram(10)(12)<="100";ghost_sprite_2_ram(10)(13)<="100";ghost_sprite_2_ram(10)(14)<="100";ghost_sprite_2_ram(10)(15)<="000";
--	  ghost_sprite_2_ram(11)(0)<="000";ghost_sprite_2_ram(11)(1)<="100";ghost_sprite_2_ram(11)(2)<="100";ghost_sprite_2_ram(11)(3)<="100";ghost_sprite_2_ram(11)(4)<="100";ghost_sprite_2_ram(11)(5)<="100";ghost_sprite_2_ram(11)(6)<="100";ghost_sprite_2_ram(11)(7)<="100";ghost_sprite_2_ram(11)(8)<="100";ghost_sprite_2_ram(11)(9)<="100";ghost_sprite_2_ram(11)(10)<="100";ghost_sprite_2_ram(11)(11)<="100";ghost_sprite_2_ram(11)(12)<="100";ghost_sprite_2_ram(11)(13)<="100";ghost_sprite_2_ram(11)(14)<="100";ghost_sprite_2_ram(11)(15)<="000";
--	  ghost_sprite_2_ram(12)(0)<="000";ghost_sprite_2_ram(12)(1)<="100";ghost_sprite_2_ram(12)(2)<="100";ghost_sprite_2_ram(12)(3)<="100";ghost_sprite_2_ram(12)(4)<="100";ghost_sprite_2_ram(12)(5)<="100";ghost_sprite_2_ram(12)(6)<="100";ghost_sprite_2_ram(12)(7)<="100";ghost_sprite_2_ram(12)(8)<="100";ghost_sprite_2_ram(12)(9)<="100";ghost_sprite_2_ram(12)(10)<="100";ghost_sprite_2_ram(12)(11)<="100";ghost_sprite_2_ram(12)(12)<="100";ghost_sprite_2_ram(12)(13)<="100";ghost_sprite_2_ram(12)(14)<="100";ghost_sprite_2_ram(12)(15)<="000";
--	  ghost_sprite_2_ram(13)(0)<="000";ghost_sprite_2_ram(13)(1)<="100";ghost_sprite_2_ram(13)(2)<="100";ghost_sprite_2_ram(13)(3)<="100";ghost_sprite_2_ram(13)(4)<="100";ghost_sprite_2_ram(13)(5)<="100";ghost_sprite_2_ram(13)(6)<="100";ghost_sprite_2_ram(13)(7)<="100";ghost_sprite_2_ram(13)(8)<="100";ghost_sprite_2_ram(13)(9)<="100";ghost_sprite_2_ram(13)(10)<="100";ghost_sprite_2_ram(13)(11)<="100";ghost_sprite_2_ram(13)(12)<="100";ghost_sprite_2_ram(13)(13)<="100";ghost_sprite_2_ram(13)(14)<="100";ghost_sprite_2_ram(13)(15)<="000";
--	  ghost_sprite_2_ram(14)(0)<="000";ghost_sprite_2_ram(14)(1)<="100";ghost_sprite_2_ram(14)(2)<="100";ghost_sprite_2_ram(14)(3)<="100";ghost_sprite_2_ram(14)(4)<="000";ghost_sprite_2_ram(14)(5)<="100";ghost_sprite_2_ram(14)(6)<="100";ghost_sprite_2_ram(14)(7)<="100";ghost_sprite_2_ram(14)(8)<="000";ghost_sprite_2_ram(14)(9)<="100";ghost_sprite_2_ram(14)(10)<="100";ghost_sprite_2_ram(14)(11)<="100";ghost_sprite_2_ram(14)(12)<="000";ghost_sprite_2_ram(14)(13)<="100";ghost_sprite_2_ram(14)(14)<="100";ghost_sprite_2_ram(14)(15)<="000";	 
--	-- ghost_sprite_2_ram(15)(0)<="000";ghost_sprite_2_ram(15)(1)<="000";ghost_sprite_2_ram(15)(2)<="000";ghost_sprite_2_ram(15)(3)<="000";ghost_sprite_2_ram(15)(4)<="000";ghost_sprite_2_ram(15)(5)<="000";ghost_sprite_2_ram(15)(6)<="000";ghost_sprite_2_ram(15)(7)<="000";ghost_sprite_2_ram(15)(8)<="000";ghost_sprite_2_ram(15)(9)<="000";ghost_sprite_2_ram(15)(10)<="000";ghost_sprite_2_ram(15)(11)<="000";ghost_sprite_2_ram(15)(12)<="000";ghost_sprite_2_ram(15)(13)<="000";ghost_sprite_2_ram(15)(14)<="000";ghost_sprite_2_ram(15)(15)<="000";
--      ghost_sprite_2_ram(15)(0)<="000";ghost_sprite_2_ram(15)(1)<="000";ghost_sprite_2_ram(15)(2)<="100";ghost_sprite_2_ram(15)(3)<="100";ghost_sprite_2_ram(15)(4)<="000";ghost_sprite_2_ram(15)(5)<="000";ghost_sprite_2_ram(15)(6)<="000";ghost_sprite_2_ram(15)(7)<="100";ghost_sprite_2_ram(15)(8)<="000";ghost_sprite_2_ram(15)(9)<="000";ghost_sprite_2_ram(15)(10)<="000";ghost_sprite_2_ram(15)(11)<="100";ghost_sprite_2_ram(15)(12)<="100";ghost_sprite_2_ram(15)(13)<="000";ghost_sprite_2_ram(15)(14)<="100";ghost_sprite_2_ram(15)(15)<="100";

      square_sprite_ram(0)(0)<="110";square_sprite_ram(0)(1)<="110";square_sprite_ram(0)(2)<="110";square_sprite_ram(0)(3)<="110";square_sprite_ram(0)(4)<="110";square_sprite_ram(0)(5)<="110";square_sprite_ram(0)(6)<="110";square_sprite_ram(0)(7)<="110";square_sprite_ram(0)(8)<="110";square_sprite_ram(0)(9)<="110";square_sprite_ram(0)(10)<="110";square_sprite_ram(0)(11)<="110";square_sprite_ram(0)(12)<="110";square_sprite_ram(0)(13)<="110";square_sprite_ram(0)(14)<="110";square_sprite_ram(0)(15)<="110";
	  square_sprite_ram(1)(0)<="110";square_sprite_ram(1)(1)<="011";square_sprite_ram(1)(2)<="011";square_sprite_ram(1)(3)<="011";square_sprite_ram(1)(4)<="011";square_sprite_ram(1)(5)<="011";square_sprite_ram(1)(6)<="011";square_sprite_ram(1)(7)<="011";square_sprite_ram(1)(8)<="011";square_sprite_ram(1)(9)<="011";square_sprite_ram(1)(10)<="011";square_sprite_ram(1)(11)<="011";square_sprite_ram(1)(12)<="011";square_sprite_ram(1)(13)<="011";square_sprite_ram(1)(14)<="011";square_sprite_ram(1)(15)<="011";
	  square_sprite_ram(2)(0)<="110";square_sprite_ram(2)(1)<="011";square_sprite_ram(2)(2)<="011";square_sprite_ram(2)(3)<="011";square_sprite_ram(2)(4)<="011";square_sprite_ram(2)(5)<="011";square_sprite_ram(2)(6)<="011";square_sprite_ram(2)(7)<="011";square_sprite_ram(2)(8)<="011";square_sprite_ram(2)(9)<="011";square_sprite_ram(2)(10)<="011";square_sprite_ram(2)(11)<="011";square_sprite_ram(2)(12)<="011";square_sprite_ram(2)(13)<="011";square_sprite_ram(2)(14)<="011";square_sprite_ram(2)(15)<="011";
	  square_sprite_ram(3)(0)<="110";square_sprite_ram(3)(1)<="011";square_sprite_ram(3)(2)<="011";square_sprite_ram(3)(3)<="011";square_sprite_ram(3)(4)<="011";square_sprite_ram(3)(5)<="011";square_sprite_ram(3)(6)<="011";square_sprite_ram(3)(7)<="011";square_sprite_ram(3)(8)<="011";square_sprite_ram(3)(9)<="011";square_sprite_ram(3)(10)<="011";square_sprite_ram(3)(11)<="011";square_sprite_ram(3)(12)<="011";square_sprite_ram(3)(13)<="011";square_sprite_ram(3)(14)<="011";square_sprite_ram(3)(15)<="011";
	  square_sprite_ram(4)(0)<="110";square_sprite_ram(4)(1)<="011";square_sprite_ram(4)(2)<="011";square_sprite_ram(4)(3)<="011";square_sprite_ram(4)(4)<="011";square_sprite_ram(4)(5)<="011";square_sprite_ram(4)(6)<="011";square_sprite_ram(4)(7)<="011";square_sprite_ram(4)(8)<="011";square_sprite_ram(4)(9)<="011";square_sprite_ram(4)(10)<="011";square_sprite_ram(4)(11)<="011";square_sprite_ram(4)(12)<="011";square_sprite_ram(4)(13)<="011";square_sprite_ram(4)(14)<="011";square_sprite_ram(4)(15)<="011";
	  square_sprite_ram(5)(0)<="110";square_sprite_ram(5)(1)<="011";square_sprite_ram(5)(2)<="011";square_sprite_ram(5)(3)<="011";square_sprite_ram(5)(4)<="011";square_sprite_ram(5)(5)<="011";square_sprite_ram(5)(6)<="011";square_sprite_ram(5)(7)<="011";square_sprite_ram(5)(8)<="011";square_sprite_ram(5)(9)<="011";square_sprite_ram(5)(10)<="011";square_sprite_ram(5)(11)<="011";square_sprite_ram(5)(12)<="011";square_sprite_ram(5)(13)<="011";square_sprite_ram(5)(14)<="011";square_sprite_ram(5)(15)<="011";
	  square_sprite_ram(6)(0)<="110";square_sprite_ram(6)(1)<="011";square_sprite_ram(6)(2)<="011";square_sprite_ram(6)(3)<="011";square_sprite_ram(6)(4)<="011";square_sprite_ram(6)(5)<="011";square_sprite_ram(6)(6)<="011";square_sprite_ram(6)(7)<="011";square_sprite_ram(6)(8)<="011";square_sprite_ram(6)(9)<="011";square_sprite_ram(6)(10)<="011";square_sprite_ram(6)(11)<="011";square_sprite_ram(6)(12)<="011";square_sprite_ram(6)(13)<="011";square_sprite_ram(6)(14)<="011";square_sprite_ram(6)(15)<="011";
	  square_sprite_ram(7)(0)<="110";square_sprite_ram(7)(1)<="011";square_sprite_ram(7)(2)<="011";square_sprite_ram(7)(3)<="011";square_sprite_ram(7)(4)<="011";square_sprite_ram(7)(5)<="011";square_sprite_ram(7)(6)<="011";square_sprite_ram(7)(7)<="011";square_sprite_ram(7)(8)<="011";square_sprite_ram(7)(9)<="011";square_sprite_ram(7)(10)<="011";square_sprite_ram(7)(11)<="011";square_sprite_ram(7)(12)<="011";square_sprite_ram(7)(13)<="011";square_sprite_ram(7)(14)<="011";square_sprite_ram(7)(15)<="011";
	  square_sprite_ram(8)(0)<="110";square_sprite_ram(8)(1)<="011";square_sprite_ram(8)(2)<="011";square_sprite_ram(8)(3)<="011";square_sprite_ram(8)(4)<="011";square_sprite_ram(8)(5)<="011";square_sprite_ram(8)(6)<="011";square_sprite_ram(8)(7)<="011";square_sprite_ram(8)(8)<="011";square_sprite_ram(8)(9)<="011";square_sprite_ram(8)(10)<="011";square_sprite_ram(8)(11)<="011";square_sprite_ram(8)(12)<="011";square_sprite_ram(8)(13)<="011";square_sprite_ram(8)(14)<="011";square_sprite_ram(8)(15)<="011";
	  square_sprite_ram(9)(0)<="110";square_sprite_ram(9)(1)<="011";square_sprite_ram(9)(2)<="011";square_sprite_ram(9)(3)<="011";square_sprite_ram(9)(4)<="011";square_sprite_ram(9)(5)<="011";square_sprite_ram(9)(6)<="011";square_sprite_ram(9)(7)<="011";square_sprite_ram(9)(8)<="011";square_sprite_ram(9)(9)<="011";square_sprite_ram(9)(10)<="011";square_sprite_ram(9)(11)<="011";square_sprite_ram(9)(12)<="011";square_sprite_ram(9)(13)<="011";square_sprite_ram(9)(14)<="011";square_sprite_ram(9)(15)<="011";
	  square_sprite_ram(10)(0)<="110";square_sprite_ram(10)(1)<="011";square_sprite_ram(10)(2)<="011";square_sprite_ram(10)(3)<="011";square_sprite_ram(10)(4)<="011";square_sprite_ram(10)(5)<="011";square_sprite_ram(10)(6)<="011";square_sprite_ram(10)(7)<="011";square_sprite_ram(10)(8)<="011";square_sprite_ram(10)(9)<="011";square_sprite_ram(10)(10)<="011";square_sprite_ram(10)(11)<="011";square_sprite_ram(10)(12)<="011";square_sprite_ram(10)(13)<="011";square_sprite_ram(10)(14)<="011";square_sprite_ram(10)(15)<="011";
	  square_sprite_ram(11)(0)<="110";square_sprite_ram(11)(1)<="011";square_sprite_ram(11)(2)<="011";square_sprite_ram(11)(3)<="011";square_sprite_ram(11)(4)<="011";square_sprite_ram(11)(5)<="011";square_sprite_ram(11)(6)<="011";square_sprite_ram(11)(7)<="011";square_sprite_ram(11)(8)<="011";square_sprite_ram(11)(9)<="011";square_sprite_ram(11)(10)<="011";square_sprite_ram(11)(11)<="011";square_sprite_ram(11)(12)<="011";square_sprite_ram(11)(13)<="011";square_sprite_ram(11)(14)<="011";square_sprite_ram(11)(15)<="011";
	  square_sprite_ram(12)(0)<="110";square_sprite_ram(12)(1)<="011";square_sprite_ram(12)(2)<="011";square_sprite_ram(12)(3)<="011";square_sprite_ram(12)(4)<="011";square_sprite_ram(12)(5)<="011";square_sprite_ram(12)(6)<="011";square_sprite_ram(12)(7)<="011";square_sprite_ram(12)(8)<="011";square_sprite_ram(12)(9)<="011";square_sprite_ram(12)(10)<="011";square_sprite_ram(12)(11)<="011";square_sprite_ram(12)(12)<="011";square_sprite_ram(12)(13)<="011";square_sprite_ram(12)(14)<="011";square_sprite_ram(12)(15)<="011";
	  square_sprite_ram(13)(0)<="110";square_sprite_ram(13)(1)<="011";square_sprite_ram(13)(2)<="011";square_sprite_ram(13)(3)<="011";square_sprite_ram(13)(4)<="011";square_sprite_ram(13)(5)<="011";square_sprite_ram(13)(6)<="011";square_sprite_ram(13)(7)<="011";square_sprite_ram(13)(8)<="011";square_sprite_ram(13)(9)<="011";square_sprite_ram(13)(10)<="011";square_sprite_ram(13)(11)<="011";square_sprite_ram(13)(12)<="011";square_sprite_ram(13)(13)<="011";square_sprite_ram(13)(14)<="011";square_sprite_ram(13)(15)<="011";
	  square_sprite_ram(14)(0)<="110";square_sprite_ram(14)(1)<="011";square_sprite_ram(14)(2)<="011";square_sprite_ram(14)(3)<="011";square_sprite_ram(14)(4)<="011";square_sprite_ram(14)(5)<="011";square_sprite_ram(14)(6)<="011";square_sprite_ram(14)(7)<="011";square_sprite_ram(14)(8)<="011";square_sprite_ram(14)(9)<="011";square_sprite_ram(14)(10)<="011";square_sprite_ram(14)(11)<="011";square_sprite_ram(14)(12)<="011";square_sprite_ram(14)(13)<="011";square_sprite_ram(14)(14)<="011";square_sprite_ram(14)(15)<="011";
	  square_sprite_ram(15)(0)<="110";square_sprite_ram(15)(1)<="011";square_sprite_ram(15)(2)<="011";square_sprite_ram(15)(3)<="011";square_sprite_ram(15)(4)<="011";square_sprite_ram(15)(5)<="011";square_sprite_ram(15)(6)<="011";square_sprite_ram(15)(7)<="011";square_sprite_ram(15)(8)<="011";square_sprite_ram(15)(9)<="011";square_sprite_ram(15)(10)<="011";square_sprite_ram(15)(11)<="011";square_sprite_ram(15)(12)<="011";square_sprite_ram(15)(13)<="011";square_sprite_ram(15)(14)<="011";square_sprite_ram(15)(15)<="011";

      black_sprite_ram(0)(0)<="000";black_sprite_ram(0)(1)<="000";black_sprite_ram(0)(2)<="000";black_sprite_ram(0)(3)<="000";black_sprite_ram(0)(4)<="000";black_sprite_ram(0)(5)<="000";black_sprite_ram(0)(6)<="000";black_sprite_ram(0)(7)<="000";black_sprite_ram(0)(8)<="000";black_sprite_ram(0)(9)<="000";black_sprite_ram(0)(10)<="000";black_sprite_ram(0)(11)<="000";black_sprite_ram(0)(12)<="000";black_sprite_ram(0)(13)<="000";black_sprite_ram(0)(14)<="000";black_sprite_ram(0)(15)<="000";
	  black_sprite_ram(1)(0)<="000";black_sprite_ram(1)(1)<="000";black_sprite_ram(1)(2)<="000";black_sprite_ram(1)(3)<="000";black_sprite_ram(1)(4)<="000";black_sprite_ram(1)(5)<="000";black_sprite_ram(1)(6)<="000";black_sprite_ram(1)(7)<="000";black_sprite_ram(1)(8)<="000";black_sprite_ram(1)(9)<="000";black_sprite_ram(1)(10)<="000";black_sprite_ram(1)(11)<="000";black_sprite_ram(1)(12)<="000";black_sprite_ram(1)(13)<="000";black_sprite_ram(1)(14)<="000";black_sprite_ram(1)(15)<="000";
	  black_sprite_ram(2)(0)<="000";black_sprite_ram(2)(1)<="000";black_sprite_ram(2)(2)<="000";black_sprite_ram(2)(3)<="000";black_sprite_ram(2)(4)<="000";black_sprite_ram(2)(5)<="000";black_sprite_ram(2)(6)<="000";black_sprite_ram(2)(7)<="000";black_sprite_ram(2)(8)<="000";black_sprite_ram(2)(9)<="000";black_sprite_ram(2)(10)<="000";black_sprite_ram(2)(11)<="000";black_sprite_ram(2)(12)<="000";black_sprite_ram(2)(13)<="000";black_sprite_ram(2)(14)<="000";black_sprite_ram(2)(15)<="000";
	  black_sprite_ram(3)(0)<="000";black_sprite_ram(3)(1)<="000";black_sprite_ram(3)(2)<="000";black_sprite_ram(3)(3)<="000";black_sprite_ram(3)(4)<="000";black_sprite_ram(3)(5)<="000";black_sprite_ram(3)(6)<="000";black_sprite_ram(3)(7)<="000";black_sprite_ram(3)(8)<="000";black_sprite_ram(3)(9)<="000";black_sprite_ram(3)(10)<="000";black_sprite_ram(3)(11)<="000";black_sprite_ram(3)(12)<="000";black_sprite_ram(3)(13)<="000";black_sprite_ram(3)(14)<="000";black_sprite_ram(3)(15)<="000";
	  black_sprite_ram(4)(0)<="000";black_sprite_ram(4)(1)<="000";black_sprite_ram(4)(2)<="000";black_sprite_ram(4)(3)<="000";black_sprite_ram(4)(4)<="000";black_sprite_ram(4)(5)<="000";black_sprite_ram(4)(6)<="000";black_sprite_ram(4)(7)<="000";black_sprite_ram(4)(8)<="000";black_sprite_ram(4)(9)<="000";black_sprite_ram(4)(10)<="000";black_sprite_ram(4)(11)<="000";black_sprite_ram(4)(12)<="000";black_sprite_ram(4)(13)<="000";black_sprite_ram(4)(14)<="000";black_sprite_ram(4)(15)<="000";
	  black_sprite_ram(5)(0)<="000";black_sprite_ram(5)(1)<="000";black_sprite_ram(5)(2)<="000";black_sprite_ram(5)(3)<="000";black_sprite_ram(5)(4)<="000";black_sprite_ram(5)(5)<="000";black_sprite_ram(5)(6)<="000";black_sprite_ram(5)(7)<="000";black_sprite_ram(5)(8)<="000";black_sprite_ram(5)(9)<="000";black_sprite_ram(5)(10)<="000";black_sprite_ram(5)(11)<="000";black_sprite_ram(5)(12)<="000";black_sprite_ram(5)(13)<="000";black_sprite_ram(5)(14)<="000";black_sprite_ram(5)(15)<="000";
	  black_sprite_ram(6)(0)<="000";black_sprite_ram(6)(1)<="000";black_sprite_ram(6)(2)<="000";black_sprite_ram(6)(3)<="000";black_sprite_ram(6)(4)<="000";black_sprite_ram(6)(5)<="000";black_sprite_ram(6)(6)<="000";black_sprite_ram(6)(7)<="000";black_sprite_ram(6)(8)<="000";black_sprite_ram(6)(9)<="000";black_sprite_ram(6)(10)<="000";black_sprite_ram(6)(11)<="000";black_sprite_ram(6)(12)<="000";black_sprite_ram(6)(13)<="000";black_sprite_ram(6)(14)<="000";black_sprite_ram(6)(15)<="000";
	  black_sprite_ram(7)(0)<="000";black_sprite_ram(7)(1)<="000";black_sprite_ram(7)(2)<="000";black_sprite_ram(7)(3)<="000";black_sprite_ram(7)(4)<="000";black_sprite_ram(7)(5)<="000";black_sprite_ram(7)(6)<="000";black_sprite_ram(7)(7)<="000";black_sprite_ram(7)(8)<="000";black_sprite_ram(7)(9)<="000";black_sprite_ram(7)(10)<="000";black_sprite_ram(7)(11)<="000";black_sprite_ram(7)(12)<="000";black_sprite_ram(7)(13)<="000";black_sprite_ram(7)(14)<="000";black_sprite_ram(7)(15)<="000";
	  black_sprite_ram(8)(0)<="000";black_sprite_ram(8)(1)<="000";black_sprite_ram(8)(2)<="000";black_sprite_ram(8)(3)<="000";black_sprite_ram(8)(4)<="000";black_sprite_ram(8)(5)<="000";black_sprite_ram(8)(6)<="000";black_sprite_ram(8)(7)<="000";black_sprite_ram(8)(8)<="000";black_sprite_ram(8)(9)<="000";black_sprite_ram(8)(10)<="000";black_sprite_ram(8)(11)<="000";black_sprite_ram(8)(12)<="000";black_sprite_ram(8)(13)<="000";black_sprite_ram(8)(14)<="000";black_sprite_ram(8)(15)<="000";
	  black_sprite_ram(9)(0)<="000";black_sprite_ram(9)(1)<="000";black_sprite_ram(9)(2)<="000";black_sprite_ram(9)(3)<="000";black_sprite_ram(9)(4)<="000";black_sprite_ram(9)(5)<="000";black_sprite_ram(9)(6)<="000";black_sprite_ram(9)(7)<="000";black_sprite_ram(9)(8)<="000";black_sprite_ram(9)(9)<="000";black_sprite_ram(9)(10)<="000";black_sprite_ram(9)(11)<="000";black_sprite_ram(9)(12)<="000";black_sprite_ram(9)(13)<="000";black_sprite_ram(9)(14)<="000";black_sprite_ram(9)(15)<="000";
	  black_sprite_ram(10)(0)<="000";black_sprite_ram(10)(1)<="000";black_sprite_ram(10)(2)<="000";black_sprite_ram(10)(3)<="000";black_sprite_ram(10)(4)<="000";black_sprite_ram(10)(5)<="000";black_sprite_ram(10)(6)<="000";black_sprite_ram(10)(7)<="000";black_sprite_ram(10)(8)<="000";black_sprite_ram(10)(9)<="000";black_sprite_ram(10)(10)<="000";black_sprite_ram(10)(11)<="000";black_sprite_ram(10)(12)<="000";black_sprite_ram(10)(13)<="000";black_sprite_ram(10)(14)<="000";black_sprite_ram(10)(15)<="000";
	  black_sprite_ram(11)(0)<="000";black_sprite_ram(11)(1)<="000";black_sprite_ram(11)(2)<="000";black_sprite_ram(11)(3)<="000";black_sprite_ram(11)(4)<="000";black_sprite_ram(11)(5)<="000";black_sprite_ram(11)(6)<="000";black_sprite_ram(11)(7)<="000";black_sprite_ram(11)(8)<="000";black_sprite_ram(11)(9)<="000";black_sprite_ram(11)(10)<="000";black_sprite_ram(11)(11)<="000";black_sprite_ram(11)(12)<="000";black_sprite_ram(11)(13)<="000";black_sprite_ram(11)(14)<="000";black_sprite_ram(11)(15)<="000";
	  black_sprite_ram(12)(0)<="000";black_sprite_ram(12)(1)<="000";black_sprite_ram(12)(2)<="000";black_sprite_ram(12)(3)<="000";black_sprite_ram(12)(4)<="000";black_sprite_ram(12)(5)<="000";black_sprite_ram(12)(6)<="000";black_sprite_ram(12)(7)<="000";black_sprite_ram(12)(8)<="000";black_sprite_ram(12)(9)<="000";black_sprite_ram(12)(10)<="000";black_sprite_ram(12)(11)<="000";black_sprite_ram(12)(12)<="000";black_sprite_ram(12)(13)<="000";black_sprite_ram(12)(14)<="000";black_sprite_ram(12)(15)<="000";
	  black_sprite_ram(13)(0)<="000";black_sprite_ram(13)(1)<="000";black_sprite_ram(13)(2)<="000";black_sprite_ram(13)(3)<="000";black_sprite_ram(13)(4)<="000";black_sprite_ram(13)(5)<="000";black_sprite_ram(13)(6)<="000";black_sprite_ram(13)(7)<="000";black_sprite_ram(13)(8)<="000";black_sprite_ram(13)(9)<="000";black_sprite_ram(13)(10)<="000";black_sprite_ram(13)(11)<="000";black_sprite_ram(13)(12)<="000";black_sprite_ram(13)(13)<="000";black_sprite_ram(13)(14)<="000";black_sprite_ram(13)(15)<="000";
	  black_sprite_ram(14)(0)<="000";black_sprite_ram(14)(1)<="000";black_sprite_ram(14)(2)<="000";black_sprite_ram(14)(3)<="000";black_sprite_ram(14)(4)<="000";black_sprite_ram(14)(5)<="000";black_sprite_ram(14)(6)<="000";black_sprite_ram(14)(7)<="000";black_sprite_ram(14)(8)<="000";black_sprite_ram(14)(9)<="000";black_sprite_ram(14)(10)<="000";black_sprite_ram(14)(11)<="000";black_sprite_ram(14)(12)<="000";black_sprite_ram(14)(13)<="000";black_sprite_ram(14)(14)<="000";black_sprite_ram(14)(15)<="000";
	  black_sprite_ram(15)(0)<="000";black_sprite_ram(15)(1)<="000";black_sprite_ram(15)(2)<="000";black_sprite_ram(15)(3)<="000";black_sprite_ram(15)(4)<="000";black_sprite_ram(15)(5)<="000";black_sprite_ram(15)(6)<="000";black_sprite_ram(15)(7)<="000";black_sprite_ram(15)(8)<="000";black_sprite_ram(15)(9)<="000";black_sprite_ram(15)(10)<="000";black_sprite_ram(15)(11)<="000";black_sprite_ram(15)(12)<="000";black_sprite_ram(15)(13)<="000";black_sprite_ram(15)(14)<="000";black_sprite_ram(15)(15)<="000";

----------------------------THE FOLLOWING PART IS NOT REVISED YET---------------------------------

--	  if avs_s1_reset_n = '0' then
--        avs_s1_readdata <= (others => '0');
--        display_address <= (others => '0');        
----        counter <= (others => '0');        
----        counter_delay <= (others => '1');
--      else
--        if avs_s1_chipselect = '1' then
--          if avs_s1_read = '1' then
--			avs_s1_readdata <= score_ram(0) & "0000000000000000000000000000";
--          elsif avs_s1_write = '1' then
--			if avs_s1_address = 0 then
--				pacman_x <= avs_s1_writedata(9 downto 0);
--				pacman_y <= avs_s1_writedata(19 downto 10);
--			elsif avs_s1_address = 1 then
--				ghost_1_x <= avs_s1_writedata(9 downto 0);
--				ghost_1_y <= avs_s1_writedata(19 downto 10);
--			elsif avs_s1_address = 2 then
--				ghost_2_x <= avs_s1_writedata(9 downto 0);
--				ghost_2_y <= avs_s1_writedata(19 downto 10);
--			elsif avs_s1_address = 3 then
--				score_ram(0) <= avs_s1_writedata(3 downto 0);
--				score_ram(1) <= avs_s1_writedata(7 downto 4);
--				score_ram(2) <= avs_s1_writedata(11 downto 8);
--				-----------------------------------------------------------------
--			--else
--				--show_dot_ram(conv_integer(avs_s1_address)-4) <= avs_s1_writedata(27 downto 0);
--			end if;
--          end if;
--        end if;
--      end if;
    end if;
 end process;

-----------------------------------------------------------------------------------------------
----------------------------------------------TRY----------------------------------------------
-----------------------------------------------------------------------------------------------
peripheral: process(clk)
  begin
     if rising_edge(clk) then
		if avs_s1_reset_n = '0' then
			avs_s1_readdata <= (others => '0');
			display_address <= (others => '0');
		else
          if avs_s1_chipselect = '1' then
             if avs_s1_write = '1' then
                 if avs_s1_address = "0000000" then  
					rhs <= avs_s1_writedata(9 downto 0);
--					rvs <= avs_s1_writedata(25 downto 16);
				 elsif avs_s1_address = "0000001" then  
					rvs <= avs_s1_writedata(9 downto 0);
					
                 elsif avs_s1_address = "0000010" then
					RAM_temp(6)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0000011" then
					RAM_temp(7)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0000100" then
					RAM_temp(8)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0000101" then
					RAM_temp(9)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0000110" then
					RAM_temp(10)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0000111" then
					RAM_temp(11)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0001000" then
					RAM_temp(12)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0001001" then
					RAM_temp(13)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0001010" then
					RAM_temp(14)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0001011" then
					RAM_temp(15)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0001100" then
					RAM_temp(16)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0001101" then
					RAM_temp(17)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0001110" then
					RAM_temp(18)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0001111" then
					RAM_temp(19)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0010000" then
					RAM_temp(20)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0010001" then
					RAM_temp(21)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0010010" then
					RAM_temp(22)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0010011" then
					RAM_temp(23)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0010100" then
					RAM_temp(24)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0010101" then
					RAM_temp(25)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0010110" then
					RAM_temp(26)(35 downto 4) <= avs_s1_writedata(31 downto 0);
				 elsif avs_s1_address = "0010111" then
					RAM_temp(27)(35 downto 4) <= avs_s1_writedata(31 downto 0);
					
				 elsif avs_s1_address = "0011001" then
					ghost1_rhs <= avs_s1_writedata(9 downto 0);
				 elsif avs_s1_address = "0011010" then
					ghost1_rvs <= avs_s1_writedata(9 downto 0);
--					ghost1_rvs <= avs_s1_writedata(25 downto 16);
				 elsif avs_s1_address = "0011011" then
					ghost2_rhs <= avs_s1_writedata(9 downto 0);
				 elsif avs_s1_address = "0011100" then
					ghost2_rvs <= avs_s1_writedata(9 downto 0);
--					ghost2_rvs <= avs_s1_writedata(25 downto 16);
                 elsif avs_s1_address = "0011101" then
                    score_ram_temp_2 <= avs_s1_writedata(3 downto 0);
                 elsif avs_s1_address = "0011110" then
                    score_ram_temp_1 <= avs_s1_writedata(3 downto 0);
				 elsif avs_s1_address = "0011111" then
                    pacman_direction_temp <= avs_s1_writedata(2 downto 0);
				 elsif avs_s1_address = "0100000" then
                    record_ram_temp_2 <= avs_s1_writedata(3 downto 0);
                 elsif avs_s1_address = "0100001" then
                    record_ram_temp_1 <= avs_s1_writedata(3 downto 0);
                 end if;
             end if;
          end if;
          if EndOfLine='1' and EndOfField='1'then 
			   pacman_x<=rhs;
               pacman_y<=rvs;
			   ghost_1_x<=ghost1_rhs;
			   ghost_1_y<=ghost1_rvs;
			   ghost_2_x<=ghost2_rhs;
			   ghost_2_y<=ghost2_rvs;
			   RAM<=RAM_temp;
			   score_ram_2<=score_ram_temp_2;
			   score_ram_1<=score_ram_temp_1;
			   record_ram_2<=record_ram_temp_2;
			   record_ram_1<=record_ram_temp_1;
			   pacman_direction <= pacman_direction_temp;
          end if;
       end if;
     end if;
end process peripheral;
-------------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------------

	process (clk)
	begin
		if clk'event and clk = '1' then
--			show_wall_square <= maze_line_from_RAM(conv_integer(maze_x));
 wall_square_state_from_RAM <= RAM(conv_integer(square_y))(conv_integer(square_x));

			--show_wall_square <= RAM(conv_integer(square_y))(conv_integer(square_x));
		end if;
	end process;
	
  HCounter : process (clk_25, reset_n)
  begin    
    if reset_n = '1' then
      Hcount <= (others => '0');
    elsif clk_25'event and clk_25 = '1' then
      if EndOfLine = '1' then
        Hcount <= (others => '0');
      else
        Hcount <= Hcount + 1;
      end if;      
    end if;
  end process HCounter;

  EndOfLine <= '1' when Hcount = HTOTAL - 1 else '0';
 
  VCounter: process (clk_25, reset_n)
  begin
    if reset_n = '1' then
      Vcount <= (others => '0');
    elsif clk_25'event and clk_25 = '1' then
      if EndOfLine = '1' then
        if EndOfField = '1' then
          Vcount <= (others => '0');
        else
          Vcount <= Vcount + 1;
	      visible_ypos <= Vcount - VSYNC - VBACK_PORCH;
		  square_sprite_y <= visible_ypos(3 downto 0);
		  if square_y /= visible_ypos(9 downto 4) then
	  		  square_y <= visible_ypos(9 downto 4);
	          --wall_line_from_RAM <= RAM(conv_integer(square_y));
			 
		  end if;
        end if;
      end if;
    end if;
  end process VCounter;

  EndOfField <= '1' when Vcount = VTOTAL - 1 else '0';

  -- State machines to generate HSYNC, VSYNC, HBLANK, and VBLANK

  HSyncGen : process (clk_25, reset_n)
  begin    
    if reset_n = '1' then
      vga_hsync <= '1';
    elsif clk_25'event and clk_25 = '1' then
      if EndOfLine = '1' then
        vga_hsync <= '1';
      elsif Hcount = HSYNC - 1 then
        vga_hsync <= '0';
      end if;      
    end if;
  end process HSyncGen;
  
  HBlankGen : process (clk_25, reset_n)
  begin    
    if reset_n = '1' then
      vga_hblank <= '1';
    elsif clk_25'event and clk_25 = '1' then
      if Hcount = HSYNC + HBACK_PORCH then
        vga_hblank <= '0';
      elsif Hcount = HSYNC + HBACK_PORCH + HACTIVE then
        vga_hblank <= '1';
      end if;      
    end if;
  end process HBlankGen;

  VSyncGen : process (clk_25, reset_n)
  begin    
    if reset_n = '1' then
      vga_vsync <= '1';
    elsif clk_25'event and clk_25 = '1' then
      if EndOfLine ='1' then
        if EndOfField = '1' then
          vga_vsync <= '1';
        elsif Vcount = VSYNC - 1 then
          vga_vsync <= '0';
        end if;
      end if;      
    end if;
  end process VSyncGen;

  VBlankGen : process (clk_25, reset_n)
  begin    
    if reset_n = '1' then
      vga_vblank <= '1';
    elsif clk_25'event and clk_25 = '1' then
      if EndOfLine = '1' then
        if Vcount = VSYNC + VBACK_PORCH - 1 then
          vga_vblank <= '0';
        elsif Vcount = VSYNC + VBACK_PORCH + VACTIVE - 1 then
          vga_vblank <= '1';
        end if;
      end if;      
    end if;
  end process VBlankGen;

  -- Registered video signals going to the video DAC

  VideoOut: process (clk_25, reset_n)
  begin
    if reset_n = '1' then
      VGA_R <= "0000000000";
      VGA_G <= "0000000000";
      VGA_B <= "0000000000";
    elsif clk_25'event and clk_25 = '1' then 	--it is here that we determine which sprites take precedence over each other
												--this is really important stuff!
	  if draw_pacman_0 = '1' then
--		if pacman_direction = "011" then ---left
--		VGA_R <= color_ram(conv_integer(pacman_sprite_left_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(29 downto 20);												  
--		VGA_G <= color_ram(conv_integer(pacman_sprite_left_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(19 downto 10);												  
--		VGA_B <= color_ram(conv_integer(pacman_sprite_left_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(9 downto 0);												  
--     ------------------------------------------------------------
------------------------------ADD DIFFERENT PAC MAN------------------------------------------------
----------------------------------------------------------------- 
--        elsif pacman_direction = "000" then---up
        if pacman_direction = "000" then---up
        VGA_R <= color_ram(conv_integer(pacman_sprite_up_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(29 downto 20);												  
		VGA_G <= color_ram(conv_integer(pacman_sprite_up_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(19 downto 10);												  
		VGA_B <= color_ram(conv_integer(pacman_sprite_up_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(9 downto 0);												  
     ------------------------------------------------------------
        elsif pacman_direction = "010" then---down
        VGA_R <= color_ram(conv_integer(pacman_sprite_down_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(29 downto 20);												  
		VGA_G <= color_ram(conv_integer(pacman_sprite_down_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(19 downto 10);												  
		VGA_B <= color_ram(conv_integer(pacman_sprite_down_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(9 downto 0);												  
        elsif pacman_direction = "011" then ---left
  		VGA_R <= color_ram(conv_integer(pacman_sprite_left_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(29 downto 20);												  
		VGA_G <= color_ram(conv_integer(pacman_sprite_left_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(19 downto 10);												  
		VGA_B <= color_ram(conv_integer(pacman_sprite_left_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(9 downto 0);												  
--     ------------------------------------------------------------   
------------------------------------------------------------
        elsif pacman_direction = "001" then ---right
        VGA_R <= color_ram(conv_integer(pacman_sprite_right_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(29 downto 20);												  
		VGA_G <= color_ram(conv_integer(pacman_sprite_right_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(19 downto 10);												  
		VGA_B <= color_ram(conv_integer(pacman_sprite_right_ram(conv_integer(visible_ypos)-conv_integer(pacman_y))(conv_integer(visible_xpos)-conv_integer(pacman_x))))(9 downto 0);												  
     ------------------------------------------------------------
		end if;
		
      elsif draw_ghost_1 = '1' then
        VGA_R <= color_ram(conv_integer(ghost_sprite_1_ram(conv_integer(visible_ypos)-conv_integer(ghost_1_y))(conv_integer(visible_xpos)-conv_integer(ghost_1_x))))(29 downto 20);												  
		VGA_G <= color_ram(conv_integer(ghost_sprite_1_ram(conv_integer(visible_ypos)-conv_integer(ghost_1_y))(conv_integer(visible_xpos)-conv_integer(ghost_1_x))))(19 downto 10);												  
		VGA_B <= color_ram(conv_integer(ghost_sprite_1_ram(conv_integer(visible_ypos)-conv_integer(ghost_1_y))(conv_integer(visible_xpos)-conv_integer(ghost_1_x))))(9 downto 0);												   	  
      elsif draw_ghost_2 = '1' then
        VGA_R <= color_ram(conv_integer(ghost_sprite_1_ram(conv_integer(visible_ypos)-conv_integer(ghost_2_y))(conv_integer(visible_xpos)-conv_integer(ghost_2_x))))(29 downto 20);												  
		VGA_G <= color_ram(conv_integer(ghost_sprite_1_ram(conv_integer(visible_ypos)-conv_integer(ghost_2_y))(conv_integer(visible_xpos)-conv_integer(ghost_2_x))))(19 downto 10);												  
		VGA_B <= color_ram(conv_integer(ghost_sprite_1_ram(conv_integer(visible_ypos)-conv_integer(ghost_2_y))(conv_integer(visible_xpos)-conv_integer(ghost_2_x))))(9 downto 0);

--      elsif wall_square_state_from_RAM = '0' then
--         if print_char = '1' then --if we should be printing some number or text instead of the maze:
--			VGA_R <= (others => current_char_sprite_from_RAM(conv_integer(square_sprite_y))(conv_integer(square_sprite_x)));
--			VGA_G <= (others => current_char_sprite_from_RAM(conv_integer(square_sprite_y))(conv_integer(square_sprite_x)));
--			VGA_B <= (others => current_char_sprite_from_RAM(conv_integer(square_sprite_y))(conv_integer(square_sprite_x)));
--         else
--		VGA_R <= "0000000000";
--        VGA_G <= "0000000000";
--    	VGA_B <= "0000000000";
--         end if;
--	  elsif print_char = '1' then --if we should be printing some number or text instead of the maze:
--			VGA_R <= (others => current_char_sprite_from_RAM(conv_integer(square_sprite_y))(conv_integer(square_sprite_x)));
--			VGA_G <= (others => current_char_sprite_from_RAM(conv_integer(square_sprite_y))(conv_integer(square_sprite_x)));
--			VGA_B <= (others => current_char_sprite_from_RAM(conv_integer(square_sprite_y))(conv_integer(square_sprite_x)));

--      elsif vga_hblank = '0' and vga_vblank ='0' then
--			if show_wall_square = '1' then
--			   VGA_R <= color_ram(conv_integer(square_sprite_ram(conv_integer(square_sprite_y))(conv_integer(square_sprite_x))))(29 downto 20);
--			   VGA_G <= color_ram(conv_integer(square_sprite_ram(conv_integer(square_sprite_y))(conv_integer(square_sprite_x))))(19 downto 10);
--			   VGA_B <= color_ram(conv_integer(square_sprite_ram(conv_integer(square_sprite_y))(conv_integer(square_sprite_x))))(9 downto 0);
--            else
--			   VGA_R <= "0000000000";
--               VGA_G <= "0000000000";
--    	       VGA_B <= "0000000000";
--            end if;

--      elsif show_wall_square = '1' then
--			   VGA_R <= color_ram(conv_integer(square_sprite_ram(conv_integer(square_sprite_y))(conv_integer(square_sprite_x))))(29 downto 20);
--			   VGA_G <= color_ram(conv_integer(square_sprite_ram(conv_integer(square_sprite_y))(conv_integer(square_sprite_x))))(19 downto 10);
--			   VGA_B <= color_ram(conv_integer(square_sprite_ram(conv_integer(square_sprite_y))(conv_integer(square_sprite_x))))(9 downto 0);

      elsif vga_hblank = '0' and vga_vblank ='0' then
			if print_char = '1' then --if we should be printing some number or text instead of the maze:
--			if square_y = "000011" then
  			  VGA_R <= (others => current_char_sprite_from_RAM(conv_integer(square_sprite_y))(conv_integer(square_sprite_x)));
			  VGA_G <= (others => current_char_sprite_from_RAM(conv_integer(square_sprite_y))(conv_integer(square_sprite_x)));
			  VGA_B <= (others => current_char_sprite_from_RAM(conv_integer(square_sprite_y))(conv_integer(square_sprite_x)));

--			   VGA_R <= "1111111111";
--               VGA_G <= "1111111111";
--    	       VGA_B <= "1111111111";
			elsif show_wall_square = '1' then
			   VGA_R <= color_ram(conv_integer(square_sprite_ram(conv_integer(square_sprite_y))(conv_integer(square_sprite_x))))(29 downto 20);
			   VGA_G <= color_ram(conv_integer(square_sprite_ram(conv_integer(square_sprite_y))(conv_integer(square_sprite_x))))(19 downto 10);
			   VGA_B <= color_ram(conv_integer(square_sprite_ram(conv_integer(square_sprite_y))(conv_integer(square_sprite_x))))(9 downto 0);
            else
			   VGA_R <= "0000000000";
               VGA_G <= "0000000000";
    	       VGA_B <= "0000000000";
            end if;
      else
		VGA_R <= "0000000000";
        VGA_G <= "0000000000";
    	VGA_B <= "0000000000";
      end if;
----	    VGA_R <= color_ram(conv_integer(square_sprite_ram(conv_integer(visible_ypos)-conv_integer(square_sprite_y))(conv_integer(visible_xpos)-conv_integer(square_sprite_x))))(29 downto 20);												  
----		VGA_G <= color_ram(conv_integer(square_sprite_ram(conv_integer(visible_ypos)-conv_integer(square_sprite_y))(conv_integer(visible_xpos)-conv_integer(square_sprite_x))))(19 downto 10);												  
----		VGA_B <= color_ram(conv_integer(square_sprite_ram(conv_integer(visible_ypos)-conv_integer(square_sprite_y))(conv_integer(visible_xpos)-conv_integer(square_sprite_x))))(9 downto 0);												  
--		VGA_R <= color_ram(conv_integer(square_sprite_ram(conv_integer(visible_ypos)-conv_integer(square_sprite_y))(conv_integer(visible_xpos)-conv_integer(square_sprite_x))))(29 downto 20);												  
--		VGA_G <= color_ram(conv_integer(square_sprite_ram(conv_integer(visible_ypos)-conv_integer(square_sprite_y))(conv_integer(visible_xpos)-conv_integer(square_sprite_x))))(19 downto 10);												  
--		VGA_B <= color_ram(conv_integer(square_sprite_ram(conv_integer(visible_ypos)-conv_integer(square_sprite_y))(conv_integer(visible_xpos)-conv_integer(square_sprite_x))))(9 downto 0);												  
--		end if;
--      elsif vga_hblank = '0' and vga_vblank ='0' then
--		--if wall_square_state_from_RAM = '1' then
--			if show_wall_square = '1'; then
--				VGA_R <= color_ram(conv_integer(square_sprite_ram(conv_integer(square_sprite_y))(conv_integer(square_sprite_x))))(29 downto 20);
--				VGA_G <= color_ram(conv_integer(square_sprite_ram(conv_integer(square_sprite_y))(conv_integer(square_sprite_x))))(19 downto 10);
--				VGA_B <= color_ram(conv_integer(square_sprite_ram(conv_integer(square_sprite_y))(conv_integer(square_sprite_x))))(9 downto 0);
--			elsif show_wall_square = '0' then
--		        VGA_R <= (others => current_dot_sprite_from_ram(conv_integer(sprite_y))(conv_integer(sprite_x)));
--		       -- VGA_G <= (others => current_dot_sprite_from_ram(conv_integer(sprite_y))(conv_integer(sprite_x)));
--		       - VGA_B <= "0000000000";
			--end if;
		--else
	       -- VGA_R <= "0000000000";
	        --VGA_G <= "0000000000";
    	    --VGA_B <= "0000000000";    
		--end if;
--      else
--        VGA_R <= "0000000000";
--        VGA_G <= "0000000000";
--        VGA_B <= "0000000000";    
    
    end if;
  end process VideoOut;

  VGA_CLK <= clk_25;
  VGA_HS <= not vga_hsync;
  VGA_VS <= not vga_vsync;
  VGA_SYNC <= '0';
  VGA_BLANK <= not (vga_hsync or vga_vsync);

end rtl;
