/*
 * "Hello World" example.
 *
 * This example prints 'Hello from Nios II' to the STDOUT stream. It runs on
 * the Nios II 'standard', 'full_featured', 'fast', and 'low_cost' example
 * designs. It runs with or without the MicroC/OS-II RTOS and requires a STDOUT
 * device in your system's hardware.
 * The memory footprint of this hosted application is ~69 kbytes by default
 * using the standard reference design.
 *
 * For a reduced footprint version of this template, and an explanation of how
 * to reduce the memory footprint for a given application, see the
 * "small_hello_world" template.
 *
 */

#include <io.h>
#include <system.h>
#include <stdio.h>
#include <alt_types.h>
#include <sys/time.h>
#include <sys/alt_timestamp.h>
#include <stdlib.h>
#include <time.h>

#define NONE 0
#define UP 1
#define RIGHT 2
#define DOWN 3
#define LEFT 4

#define SPACE 0
#define WALL 1
#define GHOST 2
#define TAIL 3

#define x_offset 48
#define y_offset 81

int maze_temp[24][34];
int maze_to_ram[22][32];
int pac_x;
int pac_y;
int ghost1_x;
int ghost1_y;
int ghost2_x;
int ghost2_y;
int score;
int record;
int counter;
int step;
int direction;
int ghost1_x_flag=1;
int ghost1_y_flag=-1;
int ghost2_x_flag=-1;
int ghost2_y_flag=1;
int audio_counter=0;
int freezing=0;

#define GHOST1_SPEED 1<<8
#define GHOST2_SPEED 1<<7
#define PAC_SPEED 1<<12
#define AUDIO_SPEED 1<<11
#define INIT_POWERUP_COUNTER 350

#define PAC_OFFSET 0 //adress=0,1
#define MAZE_OFFSET 8 //adress=2-23
#define GHOST_OFFSET 100 //adress=25-28
#define SCORE_OFFSET 116 //adress=29,30
#define DIRECTION_OFFSET 124 //adress=31
#define RECORD_OFFSET 128 //adress=32,33

#define IOWR_PAC(num, position) \
  IOWR_32DIRECT(DE2_VGA_RASTER_INST_BASE+PAC_OFFSET, (num)*4, position)
#define IOWR_MAZE(line, data) \
  IOWR_32DIRECT(DE2_VGA_RASTER_INST_BASE+MAZE_OFFSET, (line)*4, data)
#define IOWR_GHOST(num, position) \
  IOWR_32DIRECT(DE2_VGA_RASTER_INST_BASE+GHOST_OFFSET, (num)*4, position)

void initialize()
{
    //initialize the maze
    int i,j;
    for(i=0;i<24;i++){
        for(j=0;j<34;j++){
            if(i==0||j==0||i==23||j==33)
                maze_temp[i][j]=1;
            else
                maze_temp[i][j]=0;
            //maze_to_ram is the output maze with only 0 and 1, maze_temp is the maze only in C code
        }
    }
   
    //initialize the position of the pacman
    pac_x=0;
    pac_y=0;
   
    //initialize the position of ghosts, randomly
    srand((unsigned)time(NULL));
    ghost1_x=rand()%32+1;
    ghost1_y=rand()%22+1;
    ghost2_x=rand()%32+1;
    ghost2_y=rand()%22+1;
   
    //initialize the score
    counter=0;
    score=0;
    IOWR_32DIRECT(DE2_VGA_RASTER_INST_BASE+SCORE_OFFSET,0,score/10);
    IOWR_32DIRECT(DE2_VGA_RASTER_INST_BASE+SCORE_OFFSET,4,score%10);
   
    direction=NONE;
    
    audio_counter=0;
    IOWR_16DIRECT(TONE_GENERATOR_INST_BASE, 0, 0); //starting audio
   
    step=0;
    freezing=0;
}

void output(int a[24][34])
{
    //change the maze_temp into the maze which is made of '0' or '1'
    //IOWR_MAZE
    int i,j,k,r;
    int temp=0;
    for(i=1;i<23;i++){
        for(j=1;j<33;j++){
            if(maze_temp[i][j]%2==0)
                maze_to_ram[i-1][j-1]=0;
            else
                maze_to_ram[i-1][j-1]=1;
            //printf("%d",maze_to_ram[i-1][j-1]);
            //printf("%d",maze_temp[i][j]);
        }
        //printf("\n");
    }
    //printf("\n");
   
    for(k=0;k<22;k++){
        temp=0;
        for(r=31;r>-1;r--)
            temp=temp*2+maze_to_ram[k][r]; //convert to int
        //printf("%d\n",temp);
        IOWR_MAZE(k,temp);  
    }
//    IOWR_MAZE(2,1024*128*128); 
}

void calmaze()
{
    int counter_TAIL=0;
    int cal_direction[24][34];
    int i,j;
   
    for(i=0;i<24;i++){
        for(j=0;j<34;j++){
            if(maze_temp[i][j]==TAIL){ //TAIL to WALL
                maze_temp[i][j]=WALL;
                counter_TAIL++;
            }
//            else if(counter_TAIL!=0){
//                if(maze_temp[i][j]==SPACE||maze_temp[i][j]==GHOST) //mark else
//                    maze_temp[i][j]=5;
//            }
        }
    }
   
    if(counter_TAIL!=0){ //need to calculate
        for(i=0;i<24;i++){
            for(j=0;j<34;j++){
                if(maze_temp[i][j]==SPACE||maze_temp[i][j]==GHOST) //mark else
                    maze_temp[i][j]=5;
            }
        }
        if(maze_temp[ghost1_y][ghost1_x]%2!=0){ //it hasn't been visited
            maze_temp[ghost1_y][ghost1_x]=2; //visit it and start from it
            int i=ghost1_y;
            int j=ghost1_x;
            while(cal_direction[i][j]!=5){
                if(maze_temp[i-1][j]==5){
                    i=i-1;
                    cal_direction[i][j]=UP;
                    maze_temp[i][j]=SPACE;
                    //counter++;
                }
                else if(maze_temp[i][j+1]==5){
                    j=j+1;
                    cal_direction[i][j]=RIGHT;
                    maze_temp[i][j]=SPACE;
                    //counter++;
                }
                else if(maze_temp[i+1][j]==5){
                    i=i+1;
                    cal_direction[i][j]=DOWN;
                    maze_temp[i][j]=SPACE;
                    //counter++;
                }
                else if(maze_temp[i][j-1]==5){
                    j=j-1;
                    cal_direction[i][j]=LEFT;
                    maze_temp[i][j]=SPACE;
                    //counter++;
                }
                else{
                    if(i==ghost1_y&&j==ghost1_x) //calculation done
                        cal_direction[i][j]=5;
                    else if(cal_direction[i][j]==UP)
                        i=i+1;
                    else if(cal_direction[i][j]==RIGHT)
                        j=j-1;
                    else if(cal_direction[i][j]==DOWN)
                        i=i-1;
                    else if(cal_direction[i][j]==LEFT)
                        j=j+1;
                }
            }
        }
       
        if(maze_temp[ghost2_y][ghost2_x]%2!=0){ //it hasn't been visited
            maze_temp[ghost2_y][ghost2_x]=2; //visit it and start from it
            int i=ghost2_y;
            int j=ghost2_x;
            while(cal_direction[i][j]!=5){
                if(maze_temp[i-1][j]==5){
                    i=i-1;
                    cal_direction[i][j]=UP;
                    maze_temp[i][j]=SPACE;
                    //counter++;
                }
                else if(maze_temp[i][j+1]==5){
                    j=j+1;
                    cal_direction[i][j]=RIGHT;
                    maze_temp[i][j]=SPACE;
                    //counter++;
                }
                else if(maze_temp[i+1][j]==5){
                    i=i+1;
                    cal_direction[i][j]=DOWN;
                    maze_temp[i][j]=SPACE;
                    //counter++;
                }
                else if(maze_temp[i][j-1]==5){
                    j=j-1;
                    cal_direction[i][j]=LEFT;
                    maze_temp[i][j]=SPACE;
                    //counter++;
                }
                else{
                    if(i==ghost2_y&&j==ghost2_x) //calculation done
                        cal_direction[i][j]=5;
                    else if(cal_direction[i][j]==UP)
                        i=i+1;
                    else if(cal_direction[i][j]==RIGHT)
                        j=j-1;
                    else if(cal_direction[i][j]==DOWN)
                        i=i-1;
                    else if(cal_direction[i][j]==LEFT)
                        j=j+1;
                }
            }
        }
        IOWR_16DIRECT(TONE_GENERATOR_INST_BASE, 0, 2);
        audio_counter=0;
    }
    
    for(i=0;i<24;i++){
        for(j=0;j<34;j++){
            if(maze_temp[i][j]==5){ //5 to WALL
                maze_temp[i][j]=WALL;
            }
        }
    }
    //calculate and output score
    for(i=1;i<23;i++){
        for(j=1;j<33;j++){
            if(maze_temp[i][j]==WALL){ //5 to WALL
                counter++;
            }
        }
    }
    score=counter*100/704;
    printf("score is %d\n",score);
    printf("record is %d\n",record);
    if(record<score){
        record=score;
        IOWR_32DIRECT(DE2_VGA_RASTER_INST_BASE+RECORD_OFFSET,0,score/10);
        IOWR_32DIRECT(DE2_VGA_RASTER_INST_BASE+RECORD_OFFSET,4,score%10);
    }
    counter=0;
    IOWR_32DIRECT(DE2_VGA_RASTER_INST_BASE+SCORE_OFFSET,0,score/10);
    IOWR_32DIRECT(DE2_VGA_RASTER_INST_BASE+SCORE_OFFSET,4,score%10);
}

int main()
{   
    int pac_counter=0;
    int ghost1_counter=0;
    int ghost2_counter=0;
    int sub1_counter=0;
    int sub2_counter=0;

    int pac_speed=PAC_SPEED;
    int ghost1_speed=GHOST1_SPEED;
    int ghost2_speed=GHOST2_SPEED;
   
    unsigned char code;
    unsigned char precode;
   
    initialize(); //start
   
    for(;;){
        
        if(freezing==0){
    
        pac_counter++;
        ghost1_counter++;
        ghost2_counter++;
        audio_counter++;
   
        pac_counter%=pac_speed;
        ghost1_counter%=ghost1_speed;
        ghost2_counter%=ghost2_speed;
        audio_counter%=AUDIO_SPEED;
        
        if(audio_counter==0){
            IOWR_16DIRECT(TONE_GENERATOR_INST_BASE, 0, 5);
        }
       
        if(ghost1_counter==0){ //ghosts move
            sub1_counter++;
            sub1_counter%=16;
            if(maze_temp[ghost1_y][ghost1_x+1]==TAIL||maze_temp[ghost1_y][ghost1_x-1]==TAIL||maze_temp[ghost1_y+1][ghost1_x]==TAIL||maze_temp[ghost1_y-1][ghost1_x]==TAIL||maze_temp[ghost1_y-1][ghost1_x+1]==TAIL||maze_temp[ghost1_y+1][ghost1_x-1]==TAIL||maze_temp[ghost1_y+1][ghost1_x+1]==TAIL||maze_temp[ghost1_y-1][ghost1_x-1]==TAIL)
                //initialize(); //game over
                freezing=1;
            else{

                if(maze_temp[ghost1_y][ghost1_x+1]==WALL||maze_temp[ghost1_y][ghost1_x+1]==TAIL||maze_temp[ghost1_y][ghost1_x+1]==5)
                    ghost1_x_flag=-1;
                if(maze_temp[ghost1_y][ghost1_x-1]==WALL||maze_temp[ghost1_y][ghost1_x-1]==TAIL||maze_temp[ghost1_y][ghost1_x-1]==5)
                    ghost1_x_flag=1;
                if(maze_temp[ghost1_y-1][ghost1_x]==WALL||maze_temp[ghost1_y-1][ghost1_x]==TAIL||maze_temp[ghost1_y-1][ghost1_x]==5)
                    ghost1_y_flag=1;
                if(maze_temp[ghost1_y+1][ghost1_x]==WALL||maze_temp[ghost1_y+1][ghost1_x]==TAIL||maze_temp[ghost1_y+1][ghost1_x]==5)
                    ghost1_y_flag=-1;
                if(maze_temp[ghost1_y][ghost1_x+1]!=WALL&&maze_temp[ghost1_y][ghost1_x-1]!=WALL&&maze_temp[ghost1_y-1][ghost1_x]!=WALL&&maze_temp[ghost1_y+1][ghost1_x]!=WALL){
                    if((maze_temp[ghost1_y+1][ghost1_x+1]==WALL&&ghost1_x_flag==1&&ghost1_y_flag==1)||(maze_temp[ghost1_y+1][ghost1_x+1]==GHOST&&ghost1_x_flag==1&&ghost1_y_flag==1)){
                        ghost1_x_flag=-1;
                        ghost1_y_flag=-1;
                    }
                    if((maze_temp[ghost1_y-1][ghost1_x-1]==WALL&&ghost1_x_flag==-1&&ghost1_y_flag==-1)||(maze_temp[ghost1_y-1][ghost1_x-1]==GHOST&&ghost1_x_flag==-1&&ghost1_y_flag==-1)){
                        ghost1_x_flag=1;
                        ghost1_y_flag=1;
                    }
                    if((maze_temp[ghost1_y-1][ghost1_x+1]==WALL&&ghost1_x_flag==1&&ghost1_y_flag==-1)||(maze_temp[ghost1_y-1][ghost1_x+1]==GHOST&&ghost1_x_flag==1&&ghost1_y_flag==-1)){
                        ghost1_x_flag=-1;
                        ghost1_y_flag=1;
                    }
                    if((maze_temp[ghost1_y+1][ghost1_x-1]==WALL&&ghost1_x_flag==-1&&ghost1_y_flag==1)||(maze_temp[ghost1_y+1][ghost1_x-1]==GHOST&&ghost1_x_flag==-1&&ghost1_y_flag==1)){
                        ghost1_x_flag=1;
                        ghost1_y_flag=-1;
                    }
                }
                
                if(sub1_counter==0){
                    ghost1_x=ghost1_x+ghost1_x_flag;
                    ghost1_y=ghost1_y+ghost1_y_flag;
                    maze_temp[ghost1_y-ghost1_y_flag][ghost1_x-ghost1_x_flag]=SPACE;
                    maze_temp[ghost1_y][ghost1_x]=GHOST;
                }
                    //IOWR_GHOST(1,ghost1_x*16+x_offset+(ghost1_y*16+y_offset)<<16);
                    IOWR_GHOST(0,ghost1_x*16+ghost1_x_flag*sub1_counter+x_offset);
                    IOWR_GHOST(1,ghost1_y*16+ghost1_y_flag*sub1_counter+y_offset);
            }
        }
        
        if(ghost2_counter==0){
            sub2_counter++;
            sub2_counter%=16;
            if(maze_temp[ghost2_y][ghost2_x+1]==TAIL||maze_temp[ghost2_y][ghost2_x-1]==TAIL||maze_temp[ghost2_y+1][ghost2_x]==TAIL||maze_temp[ghost2_y-1][ghost2_x]==TAIL||maze_temp[ghost2_y-1][ghost2_x+1]==TAIL||maze_temp[ghost2_y+1][ghost2_x-1]==TAIL||maze_temp[ghost2_y+1][ghost2_x+1]==TAIL||maze_temp[ghost2_y-1][ghost2_x-1]==TAIL)
                //initialize(); //game over
                freezing=1;
            else{
                if(maze_temp[ghost2_y][ghost2_x+1]==WALL||maze_temp[ghost2_y][ghost2_x+1]==TAIL||maze_temp[ghost2_y][ghost2_x+1]==5)
                    ghost2_x_flag=-1;
                if(maze_temp[ghost2_y][ghost2_x-1]==WALL||maze_temp[ghost2_y][ghost2_x-1]==TAIL||maze_temp[ghost2_y][ghost2_x-1]==5)
                    ghost2_x_flag=1;
                if(maze_temp[ghost2_y-1][ghost2_x]==WALL||maze_temp[ghost2_y-1][ghost2_x]==TAIL||maze_temp[ghost2_y-1][ghost2_x]==5)
                    ghost2_y_flag=1;
                if(maze_temp[ghost2_y+1][ghost2_x]==WALL||maze_temp[ghost2_y+1][ghost2_x]==TAIL||maze_temp[ghost2_y+1][ghost2_x]==5)
                    ghost2_y_flag=-1;
                if(maze_temp[ghost2_y][ghost2_x+1]!=WALL&&maze_temp[ghost2_y][ghost2_x-1]!=WALL&&maze_temp[ghost2_y-1][ghost2_x]!=WALL&&maze_temp[ghost2_y+1][ghost2_x]!=WALL){
                    if((maze_temp[ghost2_y+1][ghost2_x+1]==WALL&&ghost2_x_flag==1&&ghost2_y_flag==1)||(maze_temp[ghost2_y+1][ghost2_x+1]==GHOST&&ghost2_x_flag==1&&ghost2_y_flag==1)){
                        ghost2_x_flag=-1;
                        ghost2_y_flag=-1;
                    }
                    if((maze_temp[ghost2_y-1][ghost2_x-1]==WALL&&ghost2_x_flag==-1&&ghost2_y_flag==-1)||(maze_temp[ghost2_y-1][ghost2_x-1]==GHOST&&ghost2_x_flag==-1&&ghost2_y_flag==-1)){
                        ghost2_x_flag=1;
                        ghost2_y_flag=1;
                    }
                    if((maze_temp[ghost2_y-1][ghost2_x+1]==WALL&&ghost2_x_flag==1&&ghost2_y_flag==-1)||(maze_temp[ghost2_y-1][ghost2_x+1]==GHOST&&ghost2_x_flag==1&&ghost2_y_flag==-1)){
                        ghost2_x_flag=-1;
                        ghost2_y_flag=1;
                    }
                    if((maze_temp[ghost2_y+1][ghost2_x-1]==WALL&&ghost2_x_flag==-1&&ghost2_y_flag==1)||(maze_temp[ghost2_y+1][ghost2_x-1]==GHOST&&ghost2_x_flag==-1&&ghost2_y_flag==1)){
                        ghost2_x_flag=1;
                        ghost2_y_flag=-1;
                    }
                }
                if(sub2_counter==0){
                    ghost2_x=ghost2_x+ghost2_x_flag;
                    ghost2_y=ghost2_y+ghost2_y_flag;
                    maze_temp[ghost2_y-ghost2_y_flag][ghost2_x-ghost2_x_flag]=SPACE;
                    maze_temp[ghost2_y][ghost2_x]=GHOST;
                }
                //IOWR_GHOST(2,ghost2_x*16+x_offset+(ghost2_y*16+y_offset)<<16);
                IOWR_GHOST(2,ghost2_x*16+ghost2_x_flag*sub2_counter+x_offset);
                IOWR_GHOST(3,ghost2_y*16+ghost2_y_flag*sub2_counter+y_offset);
            }       
        }
        
        if(pac_counter==0){
            
            //input
            //the direction is decided by pressed botton and the last direction
            //we do not change into an opposite direction or a current direction
            //while(!IORD_8DIRECT(PS2_BASE,0));
            if(!IORD_8DIRECT(DE2_PS2_INST_BASE,0)) code=0;
            else{
                //if(precode==240||precode==224) code=0;
                //else code = IORD_8DIRECT(DE2_PS2_INST_BASE,4);
                //precode=code;
                //printf("%d\n",code);
                code = IORD_8DIRECT(DE2_PS2_INST_BASE,4);
            }
       
            switch(code){
           
            case 117: //UP BUTTON
                if(direction==UP||direction==DOWN) break;
                else{
                    direction=UP;
                    IOWR_32DIRECT(DE2_VGA_RASTER_INST_BASE+DIRECTION_OFFSET,0,0);
                }
                break;
       
            case 116: //RIGHT BUTTON
                if(direction==RIGHT||direction==LEFT) break;
                else{
                    direction=RIGHT;
                    IOWR_32DIRECT(DE2_VGA_RASTER_INST_BASE+DIRECTION_OFFSET,0,1);
                }
                break;
       
            case 114: //DOWN BUTTON
                if(direction==UP||direction==DOWN) break;
                else{
                    direction=DOWN;
                    IOWR_32DIRECT(DE2_VGA_RASTER_INST_BASE+DIRECTION_OFFSET,0,2);
                }
                break;
       
            case 107: //LEFT BUTTON
                if(direction==RIGHT||direction==LEFT) break;
                else{
                    direction=LEFT;
                    IOWR_32DIRECT(DE2_VGA_RASTER_INST_BASE+DIRECTION_OFFSET,0,3);
                }
                break;
           
            default:
                break;
            }
       
            switch(direction){

            case UP:
                if(pac_y-1<0) //out of wall, do nothing
                    direction=NONE;
                else if(maze_temp[pac_y-1][pac_x]==TAIL||maze_temp[pac_y-1][pac_x]==GHOST) //eat its own tail or got the ghost, loose
                    //initialize();
                    freezing=1;
                else if(maze_temp[pac_y-1][pac_x]==WALL){ //get to the safe wall
                    pac_y=pac_y-1;
                    calmaze();
                    direction=NONE;
                }
                else if(maze_temp[pac_y-1][pac_x]==SPACE){ //into space, keep ahead
                    pac_y=pac_y-1;
                    audio_counter=0;
                    IOWR_16DIRECT(TONE_GENERATOR_INST_BASE, 0, 1);
                    direction=UP;
                    maze_temp[pac_y][pac_x]=TAIL;
                }
                break;

            case RIGHT:
                if(pac_x+1>33) //out of wall, do nothing
                    direction=NONE;
                else if(maze_temp[pac_y][pac_x+1]==TAIL||maze_temp[pac_y][pac_x+1]==GHOST) //eat its own tail or got the ghost, loose
                    //initialize();
                    freezing=1;
                else if(maze_temp[pac_y][pac_x+1]==WALL){ //get to the safe wall
                    pac_x=pac_x+1;
                    calmaze();
                    direction=NONE;
                }
                else if(maze_temp[pac_y][pac_x+1]==SPACE){ //into space, keep ahead
                    pac_x=pac_x+1;
                    audio_counter=0;
                    IOWR_16DIRECT(TONE_GENERATOR_INST_BASE, 0, 1);
                    direction=RIGHT;
                    maze_temp[pac_y][pac_x]=TAIL;
                }
                break;
 
            case DOWN:
                if(pac_y+1>23) //out of wall, do nothing
                    direction=NONE;
                else if(maze_temp[pac_y+1][pac_x]==TAIL||maze_temp[pac_y+1][pac_x]==GHOST) //eat its own tail or got the ghost, loose
                    //initialize();
                    freezing=1;
                else if(maze_temp[pac_y+1][pac_x]==WALL){ //get to the safe wall
                    pac_y=pac_y+1;
                    calmaze();
                    direction=NONE;
                }
                else if(maze_temp[pac_y+1][pac_x]==SPACE){ //into space, keep ahead
                    pac_y=pac_y+1;
                    audio_counter=0;
                    IOWR_16DIRECT(TONE_GENERATOR_INST_BASE, 0, 1);
                    direction=DOWN;
                    maze_temp[pac_y][pac_x]=TAIL;
                }
                break;

            case LEFT:
                if(pac_x-1<0) //out of wall, do nothing
                    direction=NONE;
                else if(maze_temp[pac_y][pac_x-1]==TAIL||maze_temp[pac_y][pac_x-1]==GHOST) //eat its own tail or got the ghost, loose
                    //initialize();
                    freezing=1;
                else if(maze_temp[pac_y][pac_x-1]==WALL){ //get to the safe wall
                    pac_x=pac_x-1;
                    calmaze();
                    direction=NONE;
                }
                else if(maze_temp[pac_y][pac_x-1]==SPACE){ //into space, keep ahead
                    pac_x=pac_x-1;
                    audio_counter=0;
                    IOWR_16DIRECT(TONE_GENERATOR_INST_BASE, 0, 1);
                    direction=LEFT;
                    maze_temp[pac_y][pac_x]=TAIL;
                }
                break;

            default:
                break;
            }
            //IOWR_PAC(0,pac_x*16+x_offset+(pac_y*16+y_offset)<<16);
            IOWR_PAC(0,pac_x*16+x_offset);
            IOWR_PAC(1,pac_y*16+y_offset); 
            output(maze_temp);
        }
    }
    
    else{
        if(!IORD_8DIRECT(DE2_PS2_INST_BASE,0)) code=0;
        else{
            code = IORD_8DIRECT(DE2_PS2_INST_BASE,4);
            //printf("%d\n",code);
        }
        
        switch(code){
            
        case 90:
            initialize();
        }
    }
    
    }
    return 0;
}
